@@ -20,31 +20,25 @@ import javax.sql.DataSource;
 
 /**
  * <p>
- * Definition of a properties interface for parameters of a database
- * configuration.
+ * Definition of a properties interface for parameters of a database configuration.
  * </p>
  * <p>
- * The properties defined by this interface are used to configure a
- * {@code DatabaseConfiguration} instance. They mainly specify the database
- * tables containing configuration properties. Note that many properties are
- * mandatory; they must be provided, otherwise the builder for database
- * configurations throws an exception.
+ * The properties defined by this interface are used to configure a {@code DatabaseConfiguration} instance. They mainly
+ * specify the database tables containing configuration properties. Note that many properties are mandatory; they must
+ * be provided, otherwise the builder for database configurations throws an exception.
  * </p>
  * <p>
- * <strong>Important note:</strong> This interface is not intended to be
- * implemented by client code! It defines a set of available properties and may
- * be extended even in minor releases.
+ * <strong>Important note:</strong> This interface is not intended to be implemented by client code! It defines a set of
+ * available properties and may be extended even in minor releases.
  * </p>
  *
  * @since 2.0
  * @param <T> the type of the result of all set methods for method chaining
  */
-public interface DatabaseBuilderProperties<T>
-{
+public interface DatabaseBuilderProperties<T> {
     /**
-     * Sets the data source for the database configuration. All database
-     * connections are obtained from this data source. This is a mandatory
-     * property.
+     * Sets the data source for the database configuration. All database connections are obtained from this data source.
+     * This is a mandatory property.
      *
      * @param src the data source for the database configuration
      * @return a reference to this object for method chaining
@@ -52,9 +46,8 @@ public interface DatabaseBuilderProperties<T>
     T setDataSource(DataSource src);
 
     /**
-     * Sets the name of the table containing configuration data. Database
-     * configuration will access this database table. This is a mandatory
-     * property.
+     * Sets the name of the table containing configuration data. Database configuration will access this database table.
+     * This is a mandatory property.
      *
      * @param tname the name of the table with configuration data
      * @return a reference to this object for method chaining
@@ -62,8 +55,7 @@ public interface DatabaseBuilderProperties<T>
     T setTable(String tname);
 
     /**
-     * Sets the name of the table column containing configuration keys. This is
-     * a mandatory property.
+     * Sets the name of the table column containing configuration keys. This is a mandatory property.
      *
      * @param name the column name
      * @return a reference to this object for method chaining
@@ -71,8 +63,7 @@ public interface DatabaseBuilderProperties<T>
     T setKeyColumn(String name);
 
     /**
-     * Sets the name of the table column containing the configuration property
-     * value. This is a mandatory property.
+     * Sets the name of the table column containing the configuration property value. This is a mandatory property.
      *
      * @param name the column name
      * @return a reference to this object for method chaining
@@ -80,10 +71,9 @@ public interface DatabaseBuilderProperties<T>
     T setValueColumn(String name);
 
     /**
-     * Sets the name of the table column containing the configuration name. This
-     * property is needed if a single database table contains the data of
-     * multiple configuration instances. Then this column is used as
-     * discriminator to select a specific configuration instance.
+     * Sets the name of the table column containing the configuration name. This property is needed if a single database
+     * table contains the data of multiple configuration instances. Then this column is used as discriminator to select a
+     * specific configuration instance.
      *
      * @param name the column name
      * @return a reference to this method for method chaining
@@ -91,11 +81,9 @@ public interface DatabaseBuilderProperties<T>
     T setConfigurationNameColumn(String name);
 
     /**
-     * Sets the name of this configuration instance. This property is needed if
-     * a single database table contains the data of multiple configuration
-     * instances. Then SQL statements generated by the configuration contain an
-     * additional constraint filtering the configuration name column for this
-     * name.
+     * Sets the name of this configuration instance. This property is needed if a single database table contains the data of
+     * multiple configuration instances. Then SQL statements generated by the configuration contain an additional constraint
+     * filtering the configuration name column for this name.
      *
      * @param name the name of this configuration instance
      * @return a reference to this object for method chaining
@@ -103,8 +91,8 @@ public interface DatabaseBuilderProperties<T>
     T setConfigurationName(String name);
 
     /**
-     * Enables or disable auto commit mode. If enabled, the database
-     * configuration instance performs a commit after each database update.
+     * Enables or disable auto commit mode. If enabled, the database configuration instance performs a commit after each
+     * database update.
      *
      * @param f the value of the auto commit flag
      * @return a reference to this object for method chaining
