@@ -28,23 +28,19 @@ import org.apache.commons.configuration2.beanutils.BeanHelper;
 
 /**
  * <p>
- * An implementation of the {@code DynaBean} interfaces which wraps multiple
- * other beans.
+ * An implementation of the {@code DynaBean} interfaces which wraps multiple other beans.
  * </p>
  * <p>
- * An instance of this class is constructed with a collection of beans to be
- * wrapped. When reading or writing a property the wrapped bean which defines
- * this property is determined, and the operation is executed on this bean.
+ * An instance of this class is constructed with a collection of beans to be wrapped. When reading or writing a property
+ * the wrapped bean which defines this property is determined, and the operation is executed on this bean.
  * </p>
  * <p>
- * The wrapped beans should have disjunct properties. Otherwise, it is undefined
- * which bean property is read or written.
+ * The wrapped beans should have disjunct properties. Otherwise, it is undefined which bean property is read or written.
  * </p>
  *
  * @since 2.0
  */
-class MultiWrapDynaBean implements DynaBean
-{
+class MultiWrapDynaBean implements DynaBean {
     /** Stores the class of this DynaBean. */
     private final DynaClass dynaClass;
 
@@ -52,26 +48,21 @@ class MultiWrapDynaBean implements DynaBean
     private final Map<String, DynaBean> propsToBeans;
 
     /**
-     * Creates a new instance of {@code MultiWrapDynaBean} and initializes it
-     * with the given collections of beans to be wrapped.
+     * Creates a new instance of {@code MultiWrapDynaBean} and initializes it with the given collections of beans to be
+     * wrapped.
      *
      * @param beans the wrapped beans
      */
-    public MultiWrapDynaBean(final Collection<?> beans)
-    {
+    public MultiWrapDynaBean(final Collection<?> beans) {
         propsToBeans = new HashMap<>();
-        final Collection<DynaClass> beanClasses =
-                new ArrayList<>(beans.size());
+        final Collection<DynaClass> beanClasses = new ArrayList<>(beans.size());
 
-        for (final Object bean : beans)
-        {
+        for (final Object bean : beans) {
             final DynaBean dynaBean = createDynaBean(bean);
             final DynaClass beanClass = dynaBean.getDynaClass();
-            for (final DynaProperty prop : beanClass.getDynaProperties())
-            {
+            for (final DynaProperty prop : beanClass.getDynaProperties()) {
                 // ensure an order of properties
-                if (!propsToBeans.containsKey(prop.getName()))
-                {
+                if (!propsToBeans.containsKey(prop.getName())) {
                     propsToBeans.put(prop.getName(), dynaBean);
                 }
             }
@@ -82,88 +73,71 @@ class MultiWrapDynaBean implements DynaBean
     }
 
     /**
-     * {@inheritDoc} This operation is not supported by the {@code WrapDynaBean}
-     * objects used internally by this class. Therefore, just an exception is
-     * thrown.
+     * {@inheritDoc} This operation is not supported by the {@code WrapDynaBean} objects used internally by this class.
+     * Therefore, just an exception is thrown.
      */
     @Override
-    public boolean contains(final String name, final String key)
-    {
-        throw new UnsupportedOperationException(
-                "contains() operation not supported!");
+    public boolean contains(final String name, final String key) {
+        throw new UnsupportedOperationException("contains() operation not supported!");
     }
 
     @Override
-    public Object get(final String name)
-    {
+    public Object get(final String name) {
         return fetchBean(name).get(name);
     }
 
     @Override
-    public Object get(final String name, final int index)
-    {
+    public Object get(final String name, final int index) {
         return fetchBean(name).get(name, index);
     }
 
     @Override
-    public Object get(final String name, final String key)
-    {
+    public Object get(final String name, final String key) {
         return fetchBean(name).get(name, key);
     }
 
     /**
-     * {@inheritDoc} This implementation returns an instance of
-     * {@code MultiWrapDynaClass}.
+     * {@inheritDoc} This implementation returns an instance of {@code MultiWrapDynaClass}.
      */
     @Override
-    public DynaClass getDynaClass()
-    {
+    public DynaClass getDynaClass() {
         return dynaClass;
     }
 
     /**
-     * {@inheritDoc} This operation is not supported by the {@code WrapDynaBean}
-     * objects used internally by this class. Therefore, just an exception is
-     * thrown.
+     * {@inheritDoc} This operation is not supported by the {@code WrapDynaBean} objects used internally by this class.
+     * Therefore, just an exception is thrown.
      */
     @Override
-    public void remove(final String name, final String key)
-    {
-        throw new UnsupportedOperationException(
-                "remove() operation not supported!");
+    public void remove(final String name, final String key) {
+        throw new UnsupportedOperationException("remove() operation not supported!");
     }
 
     @Override
-    public void set(final String name, final Object value)
-    {
+    public void set(final String name, final Object value) {
         fetchBean(name).set(name, value);
     }
 
     @Override
-    public void set(final String name, final int index, final Object value)
-    {
+    public void set(final String name, final int index, final Object value) {
         fetchBean(name).set(name, index, value);
     }
 
     @Override
-    public void set(final String name, final String key, final Object value)
-    {
+    public void set(final String name, final String key, final Object value) {
         fetchBean(name).set(name, key, value);
     }
 
     /**
-     * Returns the bean instance to which the given property belongs. If no such
-     * bean is found, an arbitrary bean is returned. (This causes the operation
-     * on this bean to fail with a meaningful error message.)
+     * Returns the bean instance to which the given property belongs. If no such bean is found, an arbitrary bean is
+     * returned. (This causes the operation on this bean to fail with a meaningful error message.)
      *
      * @param property the property name
      * @return the bean defining this property
      */
-    private DynaBean fetchBean(final String property)
-    {
+    private DynaBean fetchBean(final String property) {
         DynaBean dynaBean = propsToBeans.get(property);
-        if (dynaBean == null)
-        {
+        if (dynaBean == null) {
             dynaBean = propsToBeans.values().iterator().next();
         }
         return dynaBean;
@@ -175,10 +149,8 @@ class MultiWrapDynaBean implements DynaBean
      * @param bean the bean
      * @return the {@code DynaBean} for this bean
      */
-    private static DynaBean createDynaBean(final Object bean)
-    {
-        if (bean instanceof DynaBean)
-        {
+    private static DynaBean createDynaBean(final Object bean) {
+        if (bean instanceof DynaBean) {
             return (DynaBean) bean;
         }
         return BeanHelper.createWrapDynaBean(bean);
