@@ -27,16 +27,14 @@ import org.apache.commons.beanutils.DynaProperty;
 
 /**
  * <p>
- * An implementation of {@code DynaClass} which combines the properties of
- * multiple other {@code DynaClass} instances.
+ * An implementation of {@code DynaClass} which combines the properties of multiple other {@code DynaClass} instances.
  * </p>
  *
  * @since 2.0
  */
-class MultiWrapDynaClass implements DynaClass
-{
+class MultiWrapDynaClass implements DynaClass {
     /** An empty array for converting the properties collection to an array. */
-    private static final DynaProperty[] EMPTY_PROPS = new DynaProperty[0];
+    private static final DynaProperty[] EMPTY_PROPS = {};
 
     /** A collection with all properties of this class. */
     private final Collection<DynaProperty> properties;
@@ -45,13 +43,11 @@ class MultiWrapDynaClass implements DynaClass
     private final Map<String, DynaProperty> namedProperties;
 
     /**
-     * Creates a new instance of {@code MultiWrapDynaClass} and initializes it
-     * with the collection of classes to be wrapped.
+     * Creates a new instance of {@code MultiWrapDynaClass} and initializes it with the collection of classes to be wrapped.
      *
      * @param wrappedCls the collection with wrapped classes
      */
-    public MultiWrapDynaClass(final Collection<? extends DynaClass> wrappedCls)
-    {
+    public MultiWrapDynaClass(final Collection<? extends DynaClass> wrappedCls) {
         properties = new LinkedList<>();
         namedProperties = new HashMap<>();
         initProperties(wrappedCls);
@@ -61,33 +57,27 @@ class MultiWrapDynaClass implements DynaClass
      * {@inheritDoc} The name of this class is not relevant.
      */
     @Override
-    public String getName()
-    {
+    public String getName() {
         return null;
     }
 
     @Override
-    public DynaProperty getDynaProperty(final String name)
-    {
+    public DynaProperty getDynaProperty(final String name) {
         return namedProperties.get(name);
     }
 
     @Override
-    public DynaProperty[] getDynaProperties()
-    {
+    public DynaProperty[] getDynaProperties() {
         return properties.toArray(EMPTY_PROPS);
     }
 
     /**
-     * {@inheritDoc} This implementation always throws an exception because it
-     * is not possible to instantiate a bean of multiple classes.
+     * {@inheritDoc} This implementation always throws an exception because it is not possible to instantiate a bean of
+     * multiple classes.
      */
     @Override
-    public DynaBean newInstance() throws IllegalAccessException,
-            InstantiationException
-    {
-        throw new UnsupportedOperationException(
-                "Cannot create an instance of MultiWrapDynaBean!");
+    public DynaBean newInstance() throws IllegalAccessException, InstantiationException {
+        throw new UnsupportedOperationException("Cannot create an instance of MultiWrapDynaBean!");
     }
 
     /**
@@ -95,13 +85,10 @@ class MultiWrapDynaClass implements DynaClass
      *
      * @param wrappedCls the collection with the wrapped classes
      */
-    private void initProperties(final Collection<? extends DynaClass> wrappedCls)
-    {
-        for (final DynaClass cls : wrappedCls)
-        {
+    private void initProperties(final Collection<? extends DynaClass> wrappedCls) {
+        for (final DynaClass cls : wrappedCls) {
             final DynaProperty[] props = cls.getDynaProperties();
-            for (final DynaProperty p : props)
-            {
+            for (final DynaProperty p : props) {
                 properties.add(p);
                 namedProperties.put(p.getName(), p);
             }
