@@ -22,20 +22,16 @@ import org.apache.commons.configuration2.builder.FileBasedBuilderProperties;
 
 /**
  * <p>
- * Definition of a parameters interface providing a fluent API for setting all
- * properties of a configuration of a file-based configuration builder.
+ * Definition of a parameters interface providing a fluent API for setting all properties of a configuration of a
+ * file-based configuration builder.
  * </p>
  * <p>
- * <strong>Important note:</strong> This interface is not intended to be
- * implemented by client code! It defines a set of available properties and may
- * be extended even in minor releases.
+ * <strong>Important note:</strong> This interface is not intended to be implemented by client code! It defines a set of
+ * available properties and may be extended even in minor releases.
  * </p>
  *
  * @since 2.0
  */
-public interface FileBasedBuilderParameters extends
-        BasicBuilderProperties<FileBasedBuilderParameters>,
-        FileBasedBuilderProperties<FileBasedBuilderParameters>,
-        BuilderParameters
-{
+public interface FileBasedBuilderParameters
+    extends BasicBuilderProperties<FileBasedBuilderParameters>, FileBasedBuilderProperties<FileBasedBuilderParameters>, BuilderParameters {
 }
