@@ -23,21 +23,16 @@ import org.apache.commons.configuration2.builder.HierarchicalBuilderProperties;
 
 /**
  * <p>
- * Definition of a parameters interface providing a fluent API for setting all
- * properties for a hierarchical configuration.
+ * Definition of a parameters interface providing a fluent API for setting all properties for a hierarchical
+ * configuration.
  * </p>
  * <p>
- * <strong>Important note:</strong> This interface is not intended to be
- * implemented by client code! It defines a set of available properties and may
- * be extended even in minor releases.
+ * <strong>Important note:</strong> This interface is not intended to be implemented by client code! It defines a set of
+ * available properties and may be extended even in minor releases.
  * </p>
  *
  * @since 2.0
  */
-public interface HierarchicalBuilderParameters extends
-        BasicBuilderProperties<HierarchicalBuilderParameters>,
-        FileBasedBuilderProperties<HierarchicalBuilderParameters>,
-        HierarchicalBuilderProperties<HierarchicalBuilderParameters>,
-        BuilderParameters
-{
+public interface HierarchicalBuilderParameters extends BasicBuilderProperties<HierarchicalBuilderParameters>,
+    FileBasedBuilderProperties<HierarchicalBuilderParameters>, HierarchicalBuilderProperties<HierarchicalBuilderParameters>, BuilderParameters {
 }
