@@ -17,73 +17,61 @@
 
 package org.apache.commons.configuration2.ex;
 
-
 /**
  * A configuration related runtime exception.
  *
  * @since 1.0
  *
  */
-public class ConfigurationRuntimeException extends RuntimeException
-{
+public class ConfigurationRuntimeException extends RuntimeException {
     /**
      * The serial version ID.
      */
     private static final long serialVersionUID = -7838702245512140996L;
 
     /**
-     * Constructs a new {@code ConfigurationRuntimeException} without
-     * specified detail message.
+     * Constructs a new {@code ConfigurationRuntimeException} without specified detail message.
      */
-    public ConfigurationRuntimeException()
-    {
-        super();
+    public ConfigurationRuntimeException() {
     }
 
     /**
-     * Constructs a new {@code ConfigurationRuntimeException} with
-     * specified detail message.
+     * Constructs a new {@code ConfigurationRuntimeException} with specified detail message.
      *
-     * @param message  the error message
+     * @param message the error message
      */
-    public ConfigurationRuntimeException(final String message)
-    {
+    public ConfigurationRuntimeException(final String message) {
         super(message);
     }
 
     /**
-     * Constructs a new {@code ConfigurationRuntimeException} with
-     * specified detail message using {@link String#format(String,Object...)}.
+     * Constructs a new {@code ConfigurationRuntimeException} with specified detail message using
+     * {@link String#format(String,Object...)}.
      *
-     * @param message  the error message
+     * @param message the error message
      * @param args arguments to the error message
      * @see String#format(String,Object...)
      */
-    public ConfigurationRuntimeException(final String message, final Object... args)
-    {
+    public ConfigurationRuntimeException(final String message, final Object... args) {
         super(String.format(message, args));
     }
 
     /**
-     * Constructs a new {@code ConfigurationRuntimeException} with
-     * specified nested {@code Throwable}.
+     * Constructs a new {@code ConfigurationRuntimeException} with specified nested {@code Throwable}.
      *
-     * @param cause  the exception or error that caused this exception to be thrown
+     * @param cause the exception or error that caused this exception to be thrown
      */
-    public ConfigurationRuntimeException(final Throwable cause)
-    {
+    public ConfigurationRuntimeException(final Throwable cause) {
         super(cause);
     }
 
     /**
-     * Constructs a new {@code ConfigurationRuntimeException} with
-     * specified detail message and nested {@code Throwable}.
+     * Constructs a new {@code ConfigurationRuntimeException} with specified detail message and nested {@code Throwable}.
      *
-     * @param message  the error message
-     * @param cause    the exception or error that caused this exception to be thrown
+     * @param message the error message
+     * @param cause the exception or error that caused this exception to be thrown
      */
-    public ConfigurationRuntimeException(final String message, final Throwable cause)
-    {
+    public ConfigurationRuntimeException(final String message, final Throwable cause) {
         super(message, cause);
     }
 }
