@@ -22,40 +22,36 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.Map;
+import java.util.function.Function;
 
 /**
  * <p>
  * A simple value class defining a {@link ConfigurationInterpolator}.
  * </p>
  * <p>
- * Objects of this class can be used for creating new
- * {@code ConfigurationInterpolator} instances; they contain all required
- * properties. It is either possible to set a fully initialized
- * {@code ConfigurationInterpolator} directly which can be used as is.
- * Alternatively, some or all properties of an instance to be newly created can
- * be set. These properties include
+ * Objects of this class can be used for creating new {@code ConfigurationInterpolator} instances; they contain all
+ * required properties. It is either possible to set a fully initialized {@code ConfigurationInterpolator} directly
+ * which can be used as is. Alternatively, some or all properties of an instance to be newly created can be set. These
+ * properties include
  * </p>
  * <ul>
  * <li>a map with {@code Lookup} objects associated with a specific prefix</li>
  * <li>a collection with default {@code Lookup} objects (without a prefix)</li>
  * <li>a parent {@code ConfigurationInterpolator}</li>
+ * <li>a function used to convert interpolated values into strings</li>
  * </ul>
  * <p>
- * When setting up a configuration it is possible to define the
- * {@code ConfigurationInterpolator} in terms of this class. The configuration
- * will then either use the {@code ConfigurationInterpolator} instance
- * explicitly defined in the {@code InterpolatorSpecification} instance or
- * create a new one.
+ * When setting up a configuration it is possible to define the {@code ConfigurationInterpolator} in terms of this
+ * class. The configuration will then either use the {@code ConfigurationInterpolator} instance explicitly defined in
+ * the {@code InterpolatorSpecification} instance or create a new one.
  * </p>
  * <p>
- * Instances are not created directly, but using the nested {@code Builder}
- * class. They are then immutable.
+ * Instances are not created directly, but using the nested {@code Builder} class. They are then immutable.
  * </p>
  *
  * @since 2.0
  */
-public final class InterpolatorSpecification
-{
+public final class InterpolatorSpecification {
     /** The {@code ConfigurationInterpolator} instance to be used directly. */
     private final ConfigurationInterpolator interpolator;
 
@@ -68,32 +64,28 @@ public final class InterpolatorSpecification
     /** The collection with default lookups. */
     private final Collection<Lookup> defaultLookups;
 
+    /** Function used to convert interpolated values to strings. */
+    private final Function<Object, String> stringConverter;
+
     /**
-     * Creates a new instance of {@code InterpolatorSpecification} with the
-     * properties defined by the given builder object.
+     * Creates a new instance of {@code InterpolatorSpecification} with the properties defined by the given builder object.
      *
      * @param builder the builder
      */
-    private InterpolatorSpecification(final Builder builder)
-    {
+    private InterpolatorSpecification(final Builder builder) {
         interpolator = builder.interpolator;
         parentInterpolator = builder.parentInterpolator;
-        prefixLookups =
-                Collections.unmodifiableMap(new HashMap<>(
-                        builder.prefixLookups));
-        defaultLookups =
-                Collections.unmodifiableCollection(new ArrayList<>(
-                        builder.defLookups));
+        prefixLookups = Collections.unmodifiableMap(new HashMap<>(builder.prefixLookups));
+        defaultLookups = Collections.unmodifiableCollection(new ArrayList<>(builder.defLookups));
+        stringConverter = builder.stringConverter;
     }
 
     /**
-     * Returns the {@code ConfigurationInterpolator} instance to be used
-     * directly.
+     * Returns the {@code ConfigurationInterpolator} instance to be used directly.
      *
      * @return the {@code ConfigurationInterpolator} (can be <b>null</b>)
      */
-    public ConfigurationInterpolator getInterpolator()
-    {
+    public ConfigurationInterpolator getInterpolator() {
         return interpolator;
     }
 
@@ -102,45 +94,50 @@ public final class InterpolatorSpecification
      *
      * @return the parent {@code ConfigurationInterpolator} (can be <b>null</b>)
      */
-    public ConfigurationInterpolator getParentInterpolator()
-    {
+    public ConfigurationInterpolator getParentInterpolator() {
         return parentInterpolator;
     }
 
     /**
-     * Returns a map with prefix lookups. The keys of the map are the prefix
-     * strings, its values are the corresponding {@code Lookup} objects.
+     * Returns a map with prefix lookups. The keys of the map are the prefix strings, its values are the corresponding
+     * {@code Lookup} objects.
      *
-     * @return the prefix lookups for a new {@code ConfigurationInterpolator}
-     *         instance (never <b>null</b>)
+     * @return the prefix lookups for a new {@code ConfigurationInterpolator} instance (never <b>null</b>)
      */
-    public Map<String, Lookup> getPrefixLookups()
-    {
+    public Map<String, Lookup> getPrefixLookups() {
         return prefixLookups;
     }
 
     /**
      * Returns a collection with the default lookups.
      *
-     * @return the default lookups for a new {@code ConfigurationInterpolator}
-     *         instance (never <b>null</b>)
+     * @return the default lookups for a new {@code ConfigurationInterpolator} instance (never <b>null</b>)
      */
-    public Collection<Lookup> getDefaultLookups()
-    {
+    public Collection<Lookup> getDefaultLookups() {
         return defaultLookups;
     }
 
     /**
-     * <p>A <em>builder</em> class for creating instances of
-     * {@code InterpolatorSpecification}.</p>
+     * Returns the function used to convert interpolated values to strings or {@code null}
+     * if the default conversion function is to be used.
+     *
+     * @return function used to convert interpolated values to strings or {@code null} if
+     *      the default conversion function is to be used
+     */
+    public Function<Object, String> getStringConverter() {
+        return stringConverter;
+    }
+
+    /**
      * <p>
-     * This class provides a fluent API for defining the various properties of
-     * an {@code InterpolatorSpecification} object. <em>Note:</em> This builder
-     * class is not thread-safe.
+     * A <em>builder</em> class for creating instances of {@code InterpolatorSpecification}.
+     * </p>
+     * <p>
+     * This class provides a fluent API for defining the various properties of an {@code InterpolatorSpecification} object.
+     * <em>Note:</em> This builder class is not thread-safe.
      * </p>
      */
-    public static class Builder
-    {
+    public static class Builder {
         /** A map with prefix lookups. */
         private final Map<String, Lookup> prefixLookups;
 
@@ -153,8 +150,10 @@ public final class InterpolatorSpecification
         /** The parent {@code ConfigurationInterpolator}. */
         private ConfigurationInterpolator parentInterpolator;
 
-        public Builder()
-        {
+        /** Function used to convert interpolated values to strings. */
+        private Function<Object, String> stringConverter;
+
+        public Builder() {
             prefixLookups = new HashMap<>();
             defLookups = new LinkedList<>();
         }
@@ -167,10 +166,8 @@ public final class InterpolatorSpecification
          * @return a reference to this builder for method chaining
          * @throws IllegalArgumentException if a required parameter is missing
          */
-        public Builder withPrefixLookup(final String prefix, final Lookup lookup)
-        {
-            if (prefix == null)
-            {
+        public Builder withPrefixLookup(final String prefix, final Lookup lookup) {
+            if (prefix == null) {
                 throw new IllegalArgumentException("Prefix must not be null!");
             }
             checkLookup(lookup);
@@ -179,21 +176,16 @@ public final class InterpolatorSpecification
         }
 
         /**
-         * Adds the content of the given map to the prefix lookups managed by
-         * this builder. The map can be <b>null</b>, then this method has no
-         * effect.
+         * Adds the content of the given map to the prefix lookups managed by this builder. The map can be <b>null</b>, then
+         * this method has no effect.
          *
          * @param lookups the map with prefix lookups to be added
          * @return a reference to this builder for method chaining
-         * @throws IllegalArgumentException if the map contains <b>null</b>
-         *         values
+         * @throws IllegalArgumentException if the map contains <b>null</b> values
          */
-        public Builder withPrefixLookups(final Map<String, ? extends Lookup> lookups)
-        {
-            if (lookups != null)
-            {
-                for (final Map.Entry<String, ? extends Lookup> e : lookups.entrySet())
-                {
+        public Builder withPrefixLookups(final Map<String, ? extends Lookup> lookups) {
+            if (lookups != null) {
+                for (final Map.Entry<String, ? extends Lookup> e : lookups.entrySet()) {
                     withPrefixLookup(e.getKey(), e.getValue());
                 }
             }
@@ -207,29 +199,23 @@ public final class InterpolatorSpecification
          * @return a reference to this builder for method chaining
          * @throws IllegalArgumentException if the {@code Lookup} is <b>null</b>
          */
-        public Builder withDefaultLookup(final Lookup lookup)
-        {
+        public Builder withDefaultLookup(final Lookup lookup) {
             checkLookup(lookup);
             defLookups.add(lookup);
             return this;
         }
 
         /**
-         * Adds the content of the given collection to the default lookups
-         * managed by this builder. The collection can be <b>null</b>, then this
-         * method has no effect.
+         * Adds the content of the given collection to the default lookups managed by this builder. The collection can be
+         * <b>null</b>, then this method has no effect.
          *
          * @param lookups the collection with lookups to be added
          * @return a reference to this builder for method chaining
-         * @throws IllegalArgumentException if the collection contains
-         *         <b>null</b> entries
+         * @throws IllegalArgumentException if the collection contains <b>null</b> entries
          */
-        public Builder withDefaultLookups(final Collection<? extends Lookup> lookups)
-        {
-            if (lookups != null)
-            {
-                for (final Lookup l : lookups)
-                {
+        public Builder withDefaultLookups(final Collection<? extends Lookup> lookups) {
+            if (lookups != null) {
+                for (final Lookup l : lookups) {
                     withDefaultLookup(l);
                 }
             }
@@ -237,73 +223,75 @@ public final class InterpolatorSpecification
         }
 
         /**
-         * Sets the {@code ConfigurationInterpolator} instance for the
-         * {@code InterpolatorSpecification}. This means that a
-         * {@code ConfigurationInterpolator} has been created and set up
-         * externally and can be used directly.
+         * Sets the {@code ConfigurationInterpolator} instance for the {@code InterpolatorSpecification}. This means that a
+         * {@code ConfigurationInterpolator} has been created and set up externally and can be used directly.
          *
          * @param ci the {@code ConfigurationInterpolator} (can be <b>null</b>)
          * @return a reference to this builder for method chaining
          */
-        public Builder withInterpolator(final ConfigurationInterpolator ci)
-        {
+        public Builder withInterpolator(final ConfigurationInterpolator ci) {
             interpolator = ci;
             return this;
         }
 
         /**
-         * Sets an optional parent {@code ConfigurationInterpolator}. If
-         * defined, this object is set as parent of a newly created
-         * {@code ConfigurationInterpolator} instance.
+         * Sets an optional parent {@code ConfigurationInterpolator}. If defined, this object is set as parent of a newly
+         * created {@code ConfigurationInterpolator} instance.
          *
-         * @param parent the parent {@code ConfigurationInterpolator} (can be
-         *        <b>null</b>)
+         * @param parent the parent {@code ConfigurationInterpolator} (can be <b>null</b>)
          * @return a reference to this builder for method chaining
          */
-        public Builder withParentInterpolator(final ConfigurationInterpolator parent)
-        {
+        public Builder withParentInterpolator(final ConfigurationInterpolator parent) {
             parentInterpolator = parent;
             return this;
         }
 
         /**
-         * Creates a new {@code InterpolatorSpecification} instance with the
-         * properties set so far. After that this builder instance is reset so
-         * that it can be reused for creating further specification objects.
+         * Sets the function used to convert interpolated values to strings. Pass {@code null}
+         * if the default conversion function is to be used.
+         *
+         * @param fn function used to convert interpolated values to string or {@code null} if the
+         *      default conversion function is to be used
+         * @return a reference to this builder for method chaining
+         */
+        public Builder withStringConverter(final Function<Object, String> fn) {
+            this.stringConverter = fn;
+            return this;
+        }
+
+
+        /**
+         * Creates a new {@code InterpolatorSpecification} instance with the properties set so far. After that this builder
+         * instance is reset so that it can be reused for creating further specification objects.
          *
          * @return the newly created {@code InterpolatorSpecification}
          */
-        public InterpolatorSpecification create()
-        {
-            final InterpolatorSpecification spec =
-                    new InterpolatorSpecification(this);
+        public InterpolatorSpecification create() {
+            final InterpolatorSpecification spec = new InterpolatorSpecification(this);
             reset();
             return spec;
         }
 
         /**
-         * Removes all data from this builder. Afterwards it can be used to
-         * define a brand new {@code InterpolatorSpecification} object.
+         * Removes all data from this builder. Afterwards it can be used to define a brand new {@code InterpolatorSpecification}
+         * object.
          */
-        public void reset()
-        {
+        public void reset() {
             interpolator = null;
             parentInterpolator = null;
             prefixLookups.clear();
             defLookups.clear();
+            stringConverter = null;
         }
 
         /**
-         * Helper method for checking a lookup. Throws an exception if the
-         * lookup is <b>null</b>.
+         * Helper method for checking a lookup. Throws an exception if the lookup is <b>null</b>.
          *
          * @param lookup the lookup to be checked
          * @throws IllegalArgumentException if the lookup is <b>null</b>
          */
-        private static void checkLookup(final Lookup lookup)
-        {
-            if (lookup == null)
-            {
+        private static void checkLookup(final Lookup lookup) {
+            if (lookup == null) {
                 throw new IllegalArgumentException("Lookup must not be null!");
             }
         }
