@@ -19,48 +19,45 @@ package org.apache.commons.configuration2.io;
 import java.util.Map;
 
 /**
- * Some FileSystems allow options to be passed on File operations. Users of commons
- * configuration can implement this interface and register it with the FileSystem.
+ * Some FileSystems allow options to be passed on File operations. Users of commons configuration can implement this
+ * interface and register it with the FileSystem.
+ *
  * @since 1.7
  */
-public interface FileOptionsProvider
-{
+public interface FileOptionsProvider {
     /**
-     * Key used to identify the user to be associated with the current file operations.
-     * The value associated with this key is a String identifying the current user.
+     * Key used to identify the user to be associated with the current file operations. The value associated with this key
+     * is a String identifying the current user.
      */
     String CURRENT_USER = "currentUser";
 
     /**
-     * Key used to indicate whether Webdav versioning support should be enabled.
-     * The value associated with this key is a Boolean where True indicates versioning should
-     * be enabled.
+     * Key used to indicate whether Webdav versioning support should be enabled. The value associated with this key is a
+     * Boolean where True indicates versioning should be enabled.
      */
     String VERSIONING = "versioning";
 
     /**
-     * Key used to identify the proxy host to connect through.
-     * The value associated with this key is a String identifying the host name of the proxy.
+     * Key used to identify the proxy host to connect through. The value associated with this key is a String identifying
+     * the host name of the proxy.
      */
     String PROXY_HOST = "proxyHost";
 
     /**
-     * Key used to identify the proxy port to connect through.
-     * The value associated with this key is an Integer identifying the port on the proxy.
+     * Key used to identify the proxy port to connect through. The value associated with this key is an Integer identifying
+     * the port on the proxy.
      */
     String PROXY_PORT = "proxyPort";
 
     /**
-     * Key used to identify the maximum number of connections allowed to a single host.
-     * The value associated with this key is an Integer identifying the maximum number of
-     * connections allowed to a single host.
+     * Key used to identify the maximum number of connections allowed to a single host. The value associated with this key
+     * is an Integer identifying the maximum number of connections allowed to a single host.
      */
     String MAX_HOST_CONNECTIONS = "maxHostConnections";
 
     /**
-     * Key used to identify the maximum number of connections allowed to all hosts.
-     * The value associated with this key is an Integer identifying the maximum number of
-     * connections allowed to all hosts.
+     * Key used to identify the maximum number of connections allowed to all hosts. The value associated with this key is an
+     * Integer identifying the maximum number of connections allowed to all hosts.
      */
     String MAX_TOTAL_CONNECTIONS = "maxTotalConnections";
 
