@@ -17,8 +17,6 @@
 
 package org.apache.commons.configuration2.plist;
 
-import javax.xml.parsers.SAXParser;
-import javax.xml.parsers.SAXParserFactory;
 import java.io.PrintWriter;
 import java.io.Reader;
 import java.io.UnsupportedEncodingException;
@@ -40,6 +38,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.TimeZone;
 
+import javax.xml.parsers.SAXParser;
+import javax.xml.parsers.SAXParserFactory;
+
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.configuration2.BaseHierarchicalConfiguration;
 import org.apache.commons.configuration2.FileBasedConfiguration;
@@ -52,8 +53,8 @@ import org.apache.commons.configuration2.io.FileLocator;
 import org.apache.commons.configuration2.io.FileLocatorAware;
 import org.apache.commons.configuration2.tree.ImmutableNode;
 import org.apache.commons.configuration2.tree.InMemoryNodeModel;
-import org.apache.commons.lang3.StringEscapeUtils;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.text.StringEscapeUtils;
 import org.xml.sax.Attributes;
 import org.xml.sax.EntityResolver;
 import org.xml.sax.InputSource;
@@ -61,10 +62,13 @@ import org.xml.sax.SAXException;
 import org.xml.sax.helpers.DefaultHandler;
 
 /**
- * Property list file (plist) in XML FORMAT as used by Mac OS X (http://www.apple.com/DTDs/PropertyList-1.0.dtd).
- * This configuration doesn't support the binary FORMAT used in OS X 10.4.
+ * Property list file (plist) in XML FORMAT as used by Mac OS X (http://www.apple.com/DTDs/PropertyList-1.0.dtd). This
+ * configuration doesn't support the binary FORMAT used in OS X 10.4.
+ *
+ * <p>
+ * Example:
+ * </p>
  *
- * <p>Example:</p>
  * <pre>
  * &lt;?xml version="1.0"?&gt;
  * &lt;!DOCTYPE plist SYSTEM "file://localhost/System/Library/DTDs/PropertyList.dtd"&gt;
@@ -123,12 +127,8 @@ import org.xml.sax.helpers.DefaultHandler;
  *
  * @since 1.2
  *
- * @author Emmanuel Bourg
- * @version $Id: XMLPropertyListConfiguration.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
-public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
-    implements FileBasedConfiguration, FileLocatorAware
-{
+public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration implements FileBasedConfiguration, FileLocatorAware {
     /** Size of the indentation for the generated file. */
     private static final int INDENT_SIZE = 4;
 
@@ -139,142 +139,108 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
     private FileLocator locator;
 
     /**
-     * Creates an empty XMLPropertyListConfiguration object which can be
-     * used to synthesize a new plist file by adding values and
-     * then saving().
+     * Creates an empty XMLPropertyListConfiguration object which can be used to synthesize a new plist file by adding
+     * values and then saving().
      */
-    public XMLPropertyListConfiguration()
-    {
+    public XMLPropertyListConfiguration() {
     }
 
     /**
-     * Creates a new instance of {@code XMLPropertyListConfiguration} and
-     * copies the content of the specified configuration into this object.
+     * Creates a new instance of {@code XMLPropertyListConfiguration} and copies the content of the specified configuration
+     * into this object.
      *
      * @param configuration the configuration to copy
      * @since 1.4
      */
-    public XMLPropertyListConfiguration(HierarchicalConfiguration<ImmutableNode> configuration)
-    {
+    public XMLPropertyListConfiguration(final HierarchicalConfiguration<ImmutableNode> configuration) {
         super(configuration);
     }
 
     /**
-     * Creates a new instance of {@code XMLPropertyConfiguration} with the given
-     * root node.
+     * Creates a new instance of {@code XMLPropertyConfiguration} with the given root node.
      *
      * @param root the root node
      */
-    XMLPropertyListConfiguration(ImmutableNode root)
-    {
+    XMLPropertyListConfiguration(final ImmutableNode root) {
         super(new InMemoryNodeModel(root));
     }
 
-    @Override
-    protected void setPropertyInternal(String key, Object value)
-    {
-        // special case for byte arrays, they must be stored as is in the configuration
-        if (value instanceof byte[])
-        {
-            setDetailEvents(false);
-            try
-            {
-                clearProperty(key);
-                addPropertyDirect(key, value);
-            }
-            finally
-            {
-                setDetailEvents(true);
-            }
+    private void setPropertyDirect(final String key, final Object value) {
+        setDetailEvents(false);
+        try {
+            clearProperty(key);
+            addPropertyDirect(key, value);
+        } finally {
+            setDetailEvents(true);
         }
-        else
-        {
+    }
+
+    @Override
+    protected void setPropertyInternal(final String key, final Object value) {
+        // special case for byte arrays, they must be stored as is in the configuration
+        if (value instanceof byte[] || value instanceof List) {
+            setPropertyDirect(key, value);
+        } else if (value instanceof Object[]) {
+            setPropertyDirect(key, Arrays.asList((Object[]) value));
+        } else {
             super.setPropertyInternal(key, value);
         }
     }
 
     @Override
-    protected void addPropertyInternal(String key, Object value)
-    {
-        if (value instanceof byte[] || value instanceof List)
-        {
+    protected void addPropertyInternal(final String key, final Object value) {
+        if (value instanceof byte[] || value instanceof List) {
             addPropertyDirect(key, value);
-        }
-        else if (value instanceof Object[])
-        {
+        } else if (value instanceof Object[]) {
             addPropertyDirect(key, Arrays.asList((Object[]) value));
-        }
-        else
-        {
+        } else {
             super.addPropertyInternal(key, value);
         }
     }
 
     /**
-     * Stores the current file locator. This method is called before I/O
-     * operations.
+     * Stores the current file locator. This method is called before I/O operations.
      *
      * @param locator the current {@code FileLocator}
      */
     @Override
-    public void initFileLocator(FileLocator locator)
-    {
+    public void initFileLocator(final FileLocator locator) {
         this.locator = locator;
     }
 
     @Override
-    public void read(Reader in) throws ConfigurationException
-    {
+    public void read(final Reader in) throws ConfigurationException {
         // set up the DTD validation
-        EntityResolver resolver = new EntityResolver()
-        {
-            @Override
-            public InputSource resolveEntity(String publicId, String systemId)
-            {
-                return new InputSource(getClass().getClassLoader()
-                        .getResourceAsStream("PropertyList-1.0.dtd"));
-            }
-        };
+        final EntityResolver resolver = (publicId, systemId) -> new InputSource(getClass().getClassLoader().getResourceAsStream("PropertyList-1.0.dtd"));
 
         // parse the file
-        XMLPropertyListHandler handler = new XMLPropertyListHandler();
-        try
-        {
-            SAXParserFactory factory = SAXParserFactory.newInstance();
+        final XMLPropertyListHandler handler = new XMLPropertyListHandler();
+        try {
+            final SAXParserFactory factory = SAXParserFactory.newInstance();
             factory.setValidating(true);
 
-            SAXParser parser = factory.newSAXParser();
+            final SAXParser parser = factory.newSAXParser();
             parser.getXMLReader().setEntityResolver(resolver);
             parser.getXMLReader().setContentHandler(handler);
             parser.getXMLReader().parse(new InputSource(in));
 
-            getNodeModel().mergeRoot(handler.getResultBuilder().createNode(),
-                    null, null, null, this);
-        }
-        catch (Exception e)
-        {
-            throw new ConfigurationException(
-                    "Unable to parse the configuration file", e);
+            getNodeModel().mergeRoot(handler.getResultBuilder().createNode(), null, null, null, this);
+        } catch (final Exception e) {
+            throw new ConfigurationException("Unable to parse the configuration file", e);
         }
     }
 
     @Override
-    public void write(Writer out) throws ConfigurationException
-    {
-        if (locator == null)
-        {
-            throw new ConfigurationException("Save operation not properly "
-                    + "initialized! Do not call write(Writer) directly,"
-                    + " but use a FileHandler to save a configuration.");
+    public void write(final Writer out) throws ConfigurationException {
+        if (locator == null) {
+            throw new ConfigurationException(
+                "Save operation not properly " + "initialized! Do not call write(Writer) directly," + " but use a FileHandler to save a configuration.");
         }
-        PrintWriter writer = new PrintWriter(out);
+        final PrintWriter writer = new PrintWriter(out);
 
-        if (locator.getEncoding() != null)
-        {
+        if (locator.getEncoding() != null) {
             writer.println("<?xml version=\"1.0\" encoding=\"" + locator.getEncoding() + "\"?>");
-        }
-        else
-        {
+        } else {
             writer.println("<?xml version=\"1.0\"?>");
         }
 
@@ -290,41 +256,32 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
     /**
      * Append a node to the writer, indented according to a specific level.
      */
-    private void printNode(PrintWriter out, int indentLevel, ImmutableNode node)
-    {
-        String padding = StringUtils.repeat(" ", indentLevel * INDENT_SIZE);
+    private void printNode(final PrintWriter out, final int indentLevel, final ImmutableNode node) {
+        final String padding = StringUtils.repeat(" ", indentLevel * INDENT_SIZE);
 
-        if (node.getNodeName() != null)
-        {
+        if (node.getNodeName() != null) {
             out.println(padding + "<key>" + StringEscapeUtils.escapeXml10(node.getNodeName()) + "</key>");
         }
 
-        List<ImmutableNode> children = node.getChildren();
-        if (!children.isEmpty())
-        {
+        final List<ImmutableNode> children = node.getChildren();
+        if (!children.isEmpty()) {
             out.println(padding + "<dict>");
 
-            Iterator<ImmutableNode> it = children.iterator();
-            while (it.hasNext())
-            {
-                ImmutableNode child = it.next();
+            final Iterator<ImmutableNode> it = children.iterator();
+            while (it.hasNext()) {
+                final ImmutableNode child = it.next();
                 printNode(out, indentLevel + 1, child);
 
-                if (it.hasNext())
-                {
+                if (it.hasNext()) {
                     out.println();
                 }
             }
 
             out.println(padding + "</dict>");
-        }
-        else if (node.getValue() == null)
-        {
+        } else if (node.getValue() == null) {
             out.println(padding + "<dict/>");
-        }
-        else
-        {
-            Object value = node.getValue();
+        } else {
+            final Object value = node.getValue();
             printValue(out, indentLevel, value);
         }
     }
@@ -332,131 +289,88 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
     /**
      * Append a value to the writer, indented according to a specific level.
      */
-    private void printValue(PrintWriter out, int indentLevel, Object value)
-    {
-        String padding = StringUtils.repeat(" ", indentLevel * INDENT_SIZE);
+    private void printValue(final PrintWriter out, final int indentLevel, final Object value) {
+        final String padding = StringUtils.repeat(" ", indentLevel * INDENT_SIZE);
 
-        if (value instanceof Date)
-        {
-            synchronized (PListNodeBuilder.FORMAT)
-            {
+        if (value instanceof Date) {
+            synchronized (PListNodeBuilder.FORMAT) {
                 out.println(padding + "<date>" + PListNodeBuilder.FORMAT.format((Date) value) + "</date>");
             }
-        }
-        else if (value instanceof Calendar)
-        {
+        } else if (value instanceof Calendar) {
             printValue(out, indentLevel, ((Calendar) value).getTime());
-        }
-        else if (value instanceof Number)
-        {
-            if (value instanceof Double || value instanceof Float || value instanceof BigDecimal)
-            {
+        } else if (value instanceof Number) {
+            if (value instanceof Double || value instanceof Float || value instanceof BigDecimal) {
                 out.println(padding + "<real>" + value.toString() + "</real>");
-            }
-            else
-            {
+            } else {
                 out.println(padding + "<integer>" + value.toString() + "</integer>");
             }
-        }
-        else if (value instanceof Boolean)
-        {
-            if (((Boolean) value).booleanValue())
-            {
+        } else if (value instanceof Boolean) {
+            if (((Boolean) value).booleanValue()) {
                 out.println(padding + "<true/>");
-            }
-            else
-            {
+            } else {
                 out.println(padding + "<false/>");
             }
-        }
-        else if (value instanceof List)
-        {
+        } else if (value instanceof List) {
             out.println(padding + "<array>");
-            for (Object o : (List<?>) value)
-            {
+            for (final Object o : (List<?>) value) {
                 printValue(out, indentLevel + 1, o);
             }
             out.println(padding + "</array>");
-        }
-        else if (value instanceof HierarchicalConfiguration)
-        {
+        } else if (value instanceof HierarchicalConfiguration) {
             // This is safe because we have created this configuration
             @SuppressWarnings("unchecked")
-            HierarchicalConfiguration<ImmutableNode> config =
-                    (HierarchicalConfiguration<ImmutableNode>) value;
-            printNode(out, indentLevel, config.getNodeModel().getNodeHandler()
-                    .getRootNode());
-        }
-        else if (value instanceof ImmutableConfiguration)
-        {
+            final HierarchicalConfiguration<ImmutableNode> config = (HierarchicalConfiguration<ImmutableNode>) value;
+            printNode(out, indentLevel, config.getNodeModel().getNodeHandler().getRootNode());
+        } else if (value instanceof ImmutableConfiguration) {
             // display a flat Configuration as a dictionary
             out.println(padding + "<dict>");
 
-            ImmutableConfiguration config = (ImmutableConfiguration) value;
-            Iterator<String> it = config.getKeys();
-            while (it.hasNext())
-            {
+            final ImmutableConfiguration config = (ImmutableConfiguration) value;
+            final Iterator<String> it = config.getKeys();
+            while (it.hasNext()) {
                 // create a node for each property
-                String key = it.next();
-                ImmutableNode node =
-                        new ImmutableNode.Builder().name(key)
-                                .value(config.getProperty(key)).create();
+                final String key = it.next();
+                final ImmutableNode node = new ImmutableNode.Builder().name(key).value(config.getProperty(key)).create();
 
                 // print the node
                 printNode(out, indentLevel + 1, node);
 
-                if (it.hasNext())
-                {
+                if (it.hasNext()) {
                     out.println();
                 }
             }
             out.println(padding + "</dict>");
-        }
-        else if (value instanceof Map)
-        {
+        } else if (value instanceof Map) {
             // display a Map as a dictionary
-            Map<String, Object> map = transformMap((Map<?, ?>) value);
+            final Map<String, Object> map = transformMap((Map<?, ?>) value);
             printValue(out, indentLevel, new MapConfiguration(map));
-        }
-        else if (value instanceof byte[])
-        {
-            String base64;
-            try
-            {
+        } else if (value instanceof byte[]) {
+            final String base64;
+            try {
                 base64 = new String(Base64.encodeBase64((byte[]) value), DATA_ENCODING);
-            }
-            catch (UnsupportedEncodingException e)
-            {
+            } catch (final UnsupportedEncodingException e) {
                 // Cannot happen as UTF-8 is a standard encoding
                 throw new AssertionError(e);
             }
             out.println(padding + "<data>" + StringEscapeUtils.escapeXml10(base64) + "</data>");
-        }
-        else if (value != null)
-        {
+        } else if (value != null) {
             out.println(padding + "<string>" + StringEscapeUtils.escapeXml10(String.valueOf(value)) + "</string>");
-        }
-        else
-        {
+        } else {
             out.println(padding + "<string/>");
         }
     }
 
     /**
-     * Transform a map of arbitrary types into a map with string keys and object
-     * values. All keys of the source map which are not of type String are
-     * dropped.
+     * Transform a map of arbitrary types into a map with string keys and object values. All keys of the source map which
+     * are not of type String are dropped.
      *
      * @param src the map to be converted
      * @return the resulting map
      */
-    private static Map<String, Object> transformMap(Map<?, ?> src)
-    {
-        Map<String, Object> dest = new HashMap<>();
-        for (Map.Entry<?, ?> e : src.entrySet())
-        {
-            if (e.getKey() instanceof String)
-            {
+    private static Map<String, Object> transformMap(final Map<?, ?> src) {
+        final Map<String, Object> dest = new HashMap<>();
+        for (final Map.Entry<?, ?> e : src.entrySet()) {
+            if (e.getKey() instanceof String) {
                 dest.put((String) e.getKey(), e.getValue());
             }
         }
@@ -466,8 +380,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
     /**
      * SAX Handler to build the configuration nodes while the document is being parsed.
      */
-    private class XMLPropertyListHandler extends DefaultHandler
-    {
+    private class XMLPropertyListHandler extends DefaultHandler {
         /** The buffer containing the text node being read */
         private final StringBuilder buffer = new StringBuilder();
 
@@ -477,8 +390,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
         /** The builder for the resulting node. */
         private final PListNodeBuilder resultBuilder;
 
-        public XMLPropertyListHandler()
-        {
+        public XMLPropertyListHandler() {
             resultBuilder = new PListNodeBuilder();
             push(resultBuilder);
         }
@@ -488,38 +400,29 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          *
          * @return the result node builder
          */
-        public PListNodeBuilder getResultBuilder()
-        {
+        public PListNodeBuilder getResultBuilder() {
             return resultBuilder;
         }
 
         /**
          * Return the node on the top of the stack.
          */
-        private PListNodeBuilder peek()
-        {
-            if (!stack.isEmpty())
-            {
+        private PListNodeBuilder peek() {
+            if (!stack.isEmpty()) {
                 return stack.get(stack.size() - 1);
             }
-            else
-            {
-                return null;
-            }
+            return null;
         }
 
         /**
-         * Returns the node on top of the non-empty stack. Throws an exception if the
-         * stack is empty.
+         * Returns the node on top of the non-empty stack. Throws an exception if the stack is empty.
          *
          * @return the top node of the stack
          * @throws ConfigurationRuntimeException if the stack is empty
          */
-        private PListNodeBuilder peekNE()
-        {
-            PListNodeBuilder result = peek();
-            if (result == null)
-            {
+        private PListNodeBuilder peekNE() {
+            final PListNodeBuilder result = peek();
+            if (result == null) {
                 throw new ConfigurationRuntimeException("Access to empty stack!");
             }
             return result;
@@ -528,117 +431,77 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
         /**
          * Remove and return the node on the top of the stack.
          */
-        private PListNodeBuilder pop()
-        {
-            if (!stack.isEmpty())
-            {
+        private PListNodeBuilder pop() {
+            if (!stack.isEmpty()) {
                 return stack.remove(stack.size() - 1);
             }
-            else
-            {
-                return null;
-            }
+            return null;
         }
 
         /**
          * Put a node on the top of the stack.
          */
-        private void push(PListNodeBuilder node)
-        {
+        private void push(final PListNodeBuilder node) {
             stack.add(node);
         }
 
         @Override
-        public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException
-        {
-            if ("array".equals(qName))
-            {
+        public void startElement(final String uri, final String localName, final String qName, final Attributes attributes) throws SAXException {
+            if ("array".equals(qName)) {
                 push(new ArrayNodeBuilder());
-            }
-            else if ("dict".equals(qName))
-            {
-                if (peek() instanceof ArrayNodeBuilder)
-                {
-                    // push the new root builder on the stack
-                    push(new PListNodeBuilder());
-                }
+            } else if ("dict".equals(qName) && peek() instanceof ArrayNodeBuilder) {
+                // push the new root builder on the stack
+                push(new PListNodeBuilder());
             }
         }
 
         @Override
-        public void endElement(String uri, String localName, String qName) throws SAXException
-        {
-            if ("key".equals(qName))
-            {
+        public void endElement(final String uri, final String localName, final String qName) throws SAXException {
+            if ("key".equals(qName)) {
                 // create a new node, link it to its parent and push it on the stack
-                PListNodeBuilder node = new PListNodeBuilder();
+                final PListNodeBuilder node = new PListNodeBuilder();
                 node.setName(buffer.toString());
                 peekNE().addChild(node);
                 push(node);
-            }
-            else if ("dict".equals(qName))
-            {
+            } else if ("dict".equals(qName)) {
                 // remove the root of the XMLPropertyListConfiguration previously pushed on the stack
-                PListNodeBuilder builder = pop();
+                final PListNodeBuilder builder = pop();
                 assert builder != null : "Stack was empty!";
-                if (peek() instanceof ArrayNodeBuilder)
-                {
+                if (peek() instanceof ArrayNodeBuilder) {
                     // create the configuration
-                    XMLPropertyListConfiguration config = new XMLPropertyListConfiguration(builder.createNode());
+                    final XMLPropertyListConfiguration config = new XMLPropertyListConfiguration(builder.createNode());
 
                     // add it to the ArrayNodeBuilder
-                    ArrayNodeBuilder node = (ArrayNodeBuilder) peekNE();
+                    final ArrayNodeBuilder node = (ArrayNodeBuilder) peekNE();
                     node.addValue(config);
                 }
-            }
-            else
-            {
-                if ("string".equals(qName))
-                {
+            } else {
+                if ("string".equals(qName)) {
                     peekNE().addValue(buffer.toString());
-                }
-                else if ("integer".equals(qName))
-                {
+                } else if ("integer".equals(qName)) {
                     peekNE().addIntegerValue(buffer.toString());
-                }
-                else if ("real".equals(qName))
-                {
+                } else if ("real".equals(qName)) {
                     peekNE().addRealValue(buffer.toString());
-                }
-                else if ("true".equals(qName))
-                {
+                } else if ("true".equals(qName)) {
                     peekNE().addTrueValue();
-                }
-                else if ("false".equals(qName))
-                {
+                } else if ("false".equals(qName)) {
                     peekNE().addFalseValue();
-                }
-                else if ("data".equals(qName))
-                {
+                } else if ("data".equals(qName)) {
                     peekNE().addDataValue(buffer.toString());
-                }
-                else if ("date".equals(qName))
-                {
-                    try
-                    {
+                } else if ("date".equals(qName)) {
+                    try {
                         peekNE().addDateValue(buffer.toString());
+                    } catch (final IllegalArgumentException iex) {
+                        getLogger().warn("Ignoring invalid date property " + buffer);
                     }
-                    catch (IllegalArgumentException iex)
-                    {
-                        getLogger().warn(
-                                "Ignoring invalid date property " + buffer);
-                    }
-                }
-                else if ("array".equals(qName))
-                {
-                    ArrayNodeBuilder array = (ArrayNodeBuilder) pop();
+                } else if ("array".equals(qName)) {
+                    final ArrayNodeBuilder array = (ArrayNodeBuilder) pop();
                     peekNE().addList(array);
                 }
 
                 // remove the plist node on the stack once the value has been parsed,
                 // array nodes remains on the stack for the next values in the list
-                if (!(peek() instanceof ArrayNodeBuilder))
-                {
+                if (!(peek() instanceof ArrayNodeBuilder)) {
                     pop();
                 }
             }
@@ -647,39 +510,33 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
         }
 
         @Override
-        public void characters(char[] ch, int start, int length) throws SAXException
-        {
+        public void characters(final char[] ch, final int start, final int length) throws SAXException {
             buffer.append(ch, start, length);
         }
     }
 
     /**
-     * A specialized builder class with addXXX methods to parse the typed data passed by the SAX handler.
-     * It is used for creating the nodes of the configuration.
+     * A specialized builder class with addXXX methods to parse the typed data passed by the SAX handler. It is used for
+     * creating the nodes of the configuration.
      */
-    private static class PListNodeBuilder
-    {
+    private static class PListNodeBuilder {
         /**
-         * The MacOS FORMAT of dates in plist files. Note: Because
-         * {@code SimpleDateFormat} is not thread-safe, each access has to be
-         * synchronized.
+         * The MacOS FORMAT of dates in plist files. Note: Because {@code SimpleDateFormat} is not thread-safe, each access has
+         * to be synchronized.
          */
         private static final DateFormat FORMAT = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");
-        static
-        {
+        static {
             FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
         }
 
         /**
-         * The GNUstep FORMAT of dates in plist files. Note: Because
-         * {@code SimpleDateFormat} is not thread-safe, each access has to be
-         * synchronized.
+         * The GNUstep FORMAT of dates in plist files. Note: Because {@code SimpleDateFormat} is not thread-safe, each access
+         * has to be synchronized.
          */
         private static final DateFormat GNUSTEP_FORMAT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss Z");
 
         /** A collection with child builders of this builder. */
-        private final Collection<PListNodeBuilder> childBuilders =
-                new LinkedList<>();
+        private final Collection<PListNodeBuilder> childBuilders = new LinkedList<>();
 
         /** The name of the represented node. */
         private String name;
@@ -688,29 +545,22 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
         private Object value;
 
         /**
-         * Update the value of the node. If the existing value is null, it's
-         * replaced with the new value. If the existing value is a list, the
-         * specified value is appended to the list. If the existing value is
-         * not null, a list with the two values is built.
+         * Update the value of the node. If the existing value is null, it's replaced with the new value. If the existing value
+         * is a list, the specified value is appended to the list. If the existing value is not null, a list with the two values
+         * is built.
          *
          * @param v the value to be added
          */
-        public void addValue(Object v)
-        {
-            if (value == null)
-            {
+        public void addValue(final Object v) {
+            if (value == null) {
                 value = v;
-            }
-            else if (value instanceof Collection)
-            {
+            } else if (value instanceof Collection) {
                 // This is safe because we create the collections ourselves
                 @SuppressWarnings("unchecked")
-                Collection<Object> collection = (Collection<Object>) value;
+                final Collection<Object> collection = (Collection<Object>) value;
                 collection.add(v);
-            }
-            else
-            {
-                List<Object> list = new ArrayList<>();
+            } else {
+                final List<Object> list = new ArrayList<>();
                 list.add(value);
                 list.add(v);
                 value = list;
@@ -723,49 +573,34 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          * @param value the value to be added
          * @throws IllegalArgumentException if the date string cannot be parsed
          */
-        public void addDateValue(String value)
-        {
-            try
-            {
-                if (value.indexOf(' ') != -1)
-                {
+        public void addDateValue(final String value) {
+            try {
+                if (value.indexOf(' ') != -1) {
                     // parse the date using the GNUstep FORMAT
-                    synchronized (GNUSTEP_FORMAT)
-                    {
+                    synchronized (GNUSTEP_FORMAT) {
                         addValue(GNUSTEP_FORMAT.parse(value));
                     }
-                }
-                else
-                {
+                } else {
                     // parse the date using the MacOS X FORMAT
-                    synchronized (FORMAT)
-                    {
+                    synchronized (FORMAT) {
                         addValue(FORMAT.parse(value));
                     }
                 }
-            }
-            catch (ParseException e)
-            {
-                throw new IllegalArgumentException(String.format(
-                        "'%s' cannot be parsed to a date!", value), e);
+            } catch (final ParseException e) {
+                throw new IllegalArgumentException(String.format("'%s' cannot be parsed to a date!", value), e);
             }
         }
 
         /**
-         * Parse the specified string as a byte array in base 64 FORMAT
-         * and add it to the values of the node.
+         * Parse the specified string as a byte array in base 64 FORMAT and add it to the values of the node.
          *
          * @param value the value to be added
          */
-        public void addDataValue(String value)
-        {
-            try
-            {
+        public void addDataValue(final String value) {
+            try {
                 addValue(Base64.decodeBase64(value.getBytes(DATA_ENCODING)));
-            }
-            catch (UnsupportedEncodingException e)
-            {
-                //Cannot happen as UTF-8 is a default encoding
+            } catch (final UnsupportedEncodingException e) {
+                // Cannot happen as UTF-8 is a default encoding
                 throw new AssertionError(e);
             }
         }
@@ -775,8 +610,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          *
          * @param value the value to be added
          */
-        public void addIntegerValue(String value)
-        {
+        public void addIntegerValue(final String value) {
             addValue(new BigInteger(value));
         }
 
@@ -785,24 +619,21 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          *
          * @param value the value to be added
          */
-        public void addRealValue(String value)
-        {
+        public void addRealValue(final String value) {
             addValue(new BigDecimal(value));
         }
 
         /**
          * Add a boolean value 'true' to the values of the node.
          */
-        public void addTrueValue()
-        {
+        public void addTrueValue() {
             addValue(Boolean.TRUE);
         }
 
         /**
          * Add a boolean value 'false' to the values of the node.
          */
-        public void addFalseValue()
-        {
+        public void addFalseValue() {
             addValue(Boolean.FALSE);
         }
 
@@ -811,8 +642,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          *
          * @param node the node whose value will be added to the current node value
          */
-        public void addList(ArrayNodeBuilder node)
-        {
+        public void addList(final ArrayNodeBuilder node) {
             addValue(node.getNodeValue());
         }
 
@@ -821,8 +651,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          *
          * @param nodeName the node name
          */
-        public void setName(String nodeName)
-        {
+        public void setName(final String nodeName) {
             name = nodeName;
         }
 
@@ -831,8 +660,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          *
          * @param child the child builder to be added
          */
-        public void addChild(PListNodeBuilder child)
-        {
+        public void addChild(final PListNodeBuilder child) {
             childBuilders.add(child);
         }
 
@@ -841,36 +669,30 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          *
          * @return the newly created configuration node
          */
-        public ImmutableNode createNode()
-        {
-            ImmutableNode.Builder nodeBuilder =
-                    new ImmutableNode.Builder(childBuilders.size());
-            for (PListNodeBuilder child : childBuilders)
-            {
+        public ImmutableNode createNode() {
+            final ImmutableNode.Builder nodeBuilder = new ImmutableNode.Builder(childBuilders.size());
+            for (final PListNodeBuilder child : childBuilders) {
                 nodeBuilder.addChild(child.createNode());
             }
             return nodeBuilder.name(name).value(getNodeValue()).create();
         }
 
         /**
-         * Returns the final value for the node to be created. This method is
-         * called when the represented configuration node is actually created.
+         * Returns the final value for the node to be created. This method is called when the represented configuration node is
+         * actually created.
          *
          * @return the value of the resulting configuration node
          */
-        protected Object getNodeValue()
-        {
+        protected Object getNodeValue() {
             return value;
         }
     }
 
     /**
-     * Container for array elements. <b>Do not use this class !</b>
-     * It is used internally by XMLPropertyConfiguration to parse the
-     * configuration file, it may be removed at any moment in the future.
+     * Container for array elements. <b>Do not use this class !</b> It is used internally by XMLPropertyConfiguration to
+     * parse the configuration file, it may be removed at any moment in the future.
      */
-    private static class ArrayNodeBuilder extends PListNodeBuilder
-    {
+    private static class ArrayNodeBuilder extends PListNodeBuilder {
         /** The list of values in the array. */
         private final List<Object> list = new ArrayList<>();
 
@@ -880,8 +702,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          * @param value the value to be added
          */
         @Override
-        public void addValue(Object value)
-        {
+        public void addValue(final Object value) {
             list.add(value);
         }
 
@@ -891,8 +712,7 @@ public class XMLPropertyListConfiguration extends BaseHierarchicalConfiguration
          * @return the {@link List} of values
          */
         @Override
-        protected Object getNodeValue()
-        {
+        protected Object getNodeValue() {
             return list;
         }
     }
