@@ -23,17 +23,13 @@ import java.util.List;
 
 /**
  * <p>
- * A simple data class used by {@link ExpressionEngine} to store
- * the results of the {@code prepareAdd()} operation.
+ * A simple data class used by {@link ExpressionEngine} to store the results of the {@code prepareAdd()} operation.
  * </p>
  * <p>
- * If a new property is to be added to a configuration, the affected
- * {@code Configuration} object must know, where in its hierarchy of
- * configuration nodes new elements have to be added. This information is
- * obtained by an {@code ExpressionEngine} object that interprets the key
- * of the new property. This expression engine will pack all information
- * necessary for the configuration to perform the add operation in an instance
- * of this class.
+ * If a new property is to be added to a configuration, the affected {@code Configuration} object must know, where in
+ * its hierarchy of configuration nodes new elements have to be added. This information is obtained by an
+ * {@code ExpressionEngine} object that interprets the key of the new property. This expression engine will pack all
+ * information necessary for the configuration to perform the add operation in an instance of this class.
  * </p>
  * <p>
  * Information managed by this class contains:
@@ -42,21 +38,19 @@ import java.util.List;
  * <li>the configuration node, to which new elements must be added</li>
  * <li>the name of the new node</li>
  * <li>whether the new node is a child node or an attribute node</li>
- * <li>if a whole branch is to be added at once, the names of all nodes between
- * the parent node (the target of the add operation) and the new node</li>
+ * <li>if a whole branch is to be added at once, the names of all nodes between the parent node (the target of the add
+ * operation) and the new node</li>
  * </ul>
  *
  * @since 1.3
  * @param <T> the type of nodes this class can handle
  */
-public class NodeAddData<T>
-{
+public class NodeAddData<T> {
     /** Stores the parent node of the add operation. */
     private final T parent;
 
     /**
-     * Stores a list with the names of nodes that are on the path between the
-     * parent node and the new node.
+     * Stores a list with the names of nodes that are on the path between the parent node and the new node.
      */
     private final List<String> pathNodes;
 
@@ -74,9 +68,7 @@ public class NodeAddData<T>
      * @param isAttr flag whether the new node is an attribute
      * @param intermediateNodes an optional collection with path nodes
      */
-    public NodeAddData(final T parentNode, final String newName, final boolean isAttr,
-            final Collection<String> intermediateNodes)
-    {
+    public NodeAddData(final T parentNode, final String newName, final boolean isAttr, final Collection<String> intermediateNodes) {
         parent = parentNode;
         newNodeName = newName;
         attribute = isAttr;
@@ -86,11 +78,9 @@ public class NodeAddData<T>
     /**
      * Returns a flag if the new node to be added is an attribute.
      *
-     * @return <b>true</b> for an attribute node, <b>false</b> for a child
-     * node
+     * @return <b>true</b> for an attribute node, <b>false</b> for a child node
      */
-    public boolean isAttribute()
-    {
+    public boolean isAttribute() {
         return attribute;
     }
 
@@ -99,8 +89,7 @@ public class NodeAddData<T>
      *
      * @return the new node's name
      */
-    public String getNewNodeName()
-    {
+    public String getNewNodeName() {
         return newNodeName;
     }
 
@@ -109,27 +98,20 @@ public class NodeAddData<T>
      *
      * @return the parent node
      */
-    public T getParent()
-    {
+    public T getParent() {
         return parent;
     }
 
     /**
-     * Returns a list with further nodes that must be added. This is needed if a
-     * complete branch is to be added at once. For instance, imagine that there
-     * exists only a node {@code database}. Now the key
-     * {@code database.connection.settings.username} (assuming the syntax
-     * of the default expression engine) is to be added. Then
-     * {@code username} is the name of the new node, but the nodes
-     * {@code connection} and {@code settings} must be added to
-     * the parent node first. In this example these names would be returned by
-     * this method.
+     * Returns a list with further nodes that must be added. This is needed if a complete branch is to be added at once. For
+     * instance, imagine that there exists only a node {@code database}. Now the key
+     * {@code database.connection.settings.username} (assuming the syntax of the default expression engine) is to be added.
+     * Then {@code username} is the name of the new node, but the nodes {@code connection} and {@code settings} must be
+     * added to the parent node first. In this example these names would be returned by this method.
      *
-     * @return a list with the names of nodes that must be added as parents of
-     * the new node (never <b>null</b>)
+     * @return a list with the names of nodes that must be added as parents of the new node (never <b>null</b>)
      */
-    public List<String> getPathNodes()
-    {
+    public List<String> getPathNodes() {
         return pathNodes;
     }
 
@@ -139,14 +121,10 @@ public class NodeAddData<T>
      * @param intermediateNodes the nodes passed to the constructor
      * @return an unmodifiable list of path nodes
      */
-    private static List<String> createPathNodes(
-            final Collection<String> intermediateNodes)
-    {
-        if (intermediateNodes == null)
-        {
+    private static List<String> createPathNodes(final Collection<String> intermediateNodes) {
+        if (intermediateNodes == null) {
             return Collections.emptyList();
         }
-        return Collections.unmodifiableList(new ArrayList<>(
-                intermediateNodes));
+        return Collections.unmodifiableList(new ArrayList<>(intermediateNodes));
     }
 }
