@@ -36,26 +36,12 @@ import org.dbunit.dataset.xml.XmlDataSet;
 import org.dbunit.operation.DatabaseOperation;
 
 /**
- * A helper class for performing tests for {@link DatabaseConfiguration}. This
- * class maintains an in-process database that stores configuration data and can
- * be accessed from a {@link DatabaseConfiguration} instance. Constants for
- * table and column names and database connection settings are provided, too.
+ * A helper class for performing tests for {@link DatabaseConfiguration}. This class maintains an in-process database
+ * that stores configuration data and can be accessed from a {@link DatabaseConfiguration} instance. Constants for table
+ * and column names and database connection settings are provided, too.
  *
  */
-public class DatabaseConfigurationTestHelper
-{
-    /** Constant for the JDBC driver class. */
-    public final String DATABASE_DRIVER = "org.hsqldb.jdbcDriver";
-
-    /** Constant for the connection URL. */
-    public final String DATABASE_URL = "jdbc:hsqldb:mem:testdb";
-
-    /** Constant for the DB user name. */
-    public final String DATABASE_USERNAME = "sa";
-
-    /** Constant for the DB password. */
-    public final String DATABASE_PASSWORD = "";
-
+public class DatabaseConfigurationTestHelper {
     /** Constant for the configuration table. */
     public static final String TABLE = "configuration";
 
@@ -74,6 +60,18 @@ public class DatabaseConfigurationTestHelper
     /** Constant for the name of the test configuration. */
     public static final String CONFIG_NAME = "test";
 
+    /** Constant for the JDBC driver class. */
+    public final String DATABASE_DRIVER = "org.hsqldb.jdbcDriver";
+
+    /** Constant for the connection URL. */
+    public final String DATABASE_URL = "jdbc:hsqldb:mem:testdb";
+
+    /** Constant for the DB user name. */
+    public final String DATABASE_USERNAME = "sa";
+
+    /** Constant for the DB password. */
+    public final String DATABASE_PASSWORD = "";
+
     /** Stores the in-process database. */
     private HsqlDB hsqlDB;
 
@@ -81,93 +79,12 @@ public class DatabaseConfigurationTestHelper
     private DataSource datasource;
 
     /**
-     * The auto-commit mode for the configuration instances created by this
-     * helper.
+     * The auto-commit mode for the configuration instances created by this helper.
      */
     private boolean autoCommit;
 
     /**
-     * Returns the auto-commit mode of the configuration instances created by
-     * this helper.
-     *
-     * @return the auto-commit mode
-     */
-    public boolean isAutoCommit()
-    {
-        return autoCommit;
-    }
-
-    /**
-     * Sets the auto-commit mode of the configuration instances created by this
-     * helper.
-     *
-     * @param autoCommit the auto-commit mode
-     */
-    public void setAutoCommit(final boolean autoCommit)
-    {
-        this.autoCommit = autoCommit;
-    }
-
-    /**
-     * Initializes this helper object. This method can be called from a
-     * {@code setUp()} method of a unit test class. It creates the database
-     * instance if necessary.
-     *
-     * @throws Exception if an error occurs
-     */
-    public void setUp() throws Exception
-    {
-        final File script = ConfigurationAssert.getTestFile("testdb.script");
-        hsqlDB = new HsqlDB(DATABASE_URL, DATABASE_DRIVER, script.getAbsolutePath());
-    }
-
-    /**
-     * Frees the resources used by this helper class. This method can be called
-     * by a {@code tearDown()} method of a unit test class.
-     *
-     * @throws Exception if an error occurs
-     */
-    public void tearDown() throws Exception
-    {
-        if (datasource != null)
-        {
-            datasource.getConnection().close();
-        }
-        hsqlDB.close();
-    }
-
-    /**
-     * Returns a parameters object with default settings.
-     *
-     * @return the parameters object
-     */
-    public DatabaseBuilderParameters setUpDefaultParameters()
-    {
-        return new Parameters().database().setDataSource(getDatasource())
-                .setTable(TABLE).setKeyColumn(COL_KEY)
-                .setValueColumn(COL_VALUE).setAutoCommit(isAutoCommit());
-    }
-
-    /**
-     * Returns a parameters object with settings for a configuration table
-     * containing the data of multiple configurations.
-     *
-     * @param configName the name of the configuration instance or <b>null</b>
-     *        for the default name
-     * @return the parameters object
-     */
-    public DatabaseBuilderParameters setUpMultiParameters(final String configName)
-    {
-        return setUpDefaultParameters()
-                .setTable(TABLE_MULTI)
-                .setConfigurationNameColumn(COL_NAME)
-                .setConfigurationName(
-                        configName != null ? configName : CONFIG_NAME);
-    }
-
-    /**
-     * Creates a configuration instance of the specified class with the given
-     * parameters.
+     * Creates a configuration instance of the specified class with the given parameters.
      *
      * @param <T> the type of the result configuration
      * @param configCls the configuration class
@@ -175,26 +92,53 @@ public class DatabaseConfigurationTestHelper
      * @return the newly created configuration instance
      * @throws ConfigurationException if an error occurs
      */
-    public <T extends DatabaseConfiguration> T createConfig(final Class<T> configCls,
-            final DatabaseBuilderParameters params) throws ConfigurationException
-    {
-        return new BasicConfigurationBuilder<>(configCls).configure(params)
-                .getConfiguration();
+    public <T extends DatabaseConfiguration> T createConfig(final Class<T> configCls, final DatabaseBuilderParameters params) throws ConfigurationException {
+        return new BasicConfigurationBuilder<>(configCls).configure(params).getConfiguration();
     }
 
     /**
-     * Creates a database configuration with default settings of the specified
-     * class.
+     * Returns the {@code DataSource} managed by this class. The data source is created on first access.
      *
-     * @param <T> the type of the result configuration
-     * @param configCls the configuration class
-     * @return the newly created configuration instance
-     * @throws ConfigurationException if an error occurs
+     * @return the {@code DataSource}
      */
-    public <T extends DatabaseConfiguration> T setUpConfig(final Class<T> configCls)
-            throws ConfigurationException
-    {
-        return createConfig(configCls, setUpDefaultParameters());
+    public DataSource getDatasource() {
+        if (datasource == null) {
+            try {
+                datasource = setUpDataSource();
+            } catch (final Exception ex) {
+                throw new ConfigurationRuntimeException("Could not create data source", ex);
+            }
+        }
+        return datasource;
+    }
+
+    /**
+     * Returns the auto-commit mode of the configuration instances created by this helper.
+     *
+     * @return the auto-commit mode
+     */
+    public boolean isAutoCommit() {
+        return autoCommit;
+    }
+
+    /**
+     * Sets the auto-commit mode of the configuration instances created by this helper.
+     *
+     * @param autoCommit the auto-commit mode
+     */
+    public void setAutoCommit(final boolean autoCommit) {
+        this.autoCommit = autoCommit;
+    }
+
+    /**
+     * Initializes this helper object. This method can be called from a {@code setUp()} method of a unit test class. It
+     * creates the database instance if necessary.
+     *
+     * @throws Exception if an error occurs
+     */
+    public void setUp() throws Exception {
+        final File script = ConfigurationAssert.getTestFile("testdb.script");
+        hsqlDB = new HsqlDB(DATABASE_URL, DATABASE_DRIVER, script.getAbsolutePath());
     }
 
     /**
@@ -203,73 +147,29 @@ public class DatabaseConfigurationTestHelper
      * @return the configuration
      * @throws ConfigurationException if an error occurs
      */
-    public DatabaseConfiguration setUpConfig() throws ConfigurationException
-    {
+    public DatabaseConfiguration setUpConfig() throws ConfigurationException {
         return setUpConfig(DatabaseConfiguration.class);
     }
 
     /**
-     * Creates a configuration with support for multiple configuration instances
-     * in a single table of the specified class.
+     * Creates a database configuration with default settings of the specified class.
      *
      * @param <T> the type of the result configuration
      * @param configCls the configuration class
-     * @param configName the name of the configuration instance or <b>null</b>
-     *        for the default name
      * @return the newly created configuration instance
      * @throws ConfigurationException if an error occurs
      */
-    public <T extends DatabaseConfiguration> T setUpMultiConfig(
-            final Class<T> configCls, final String configName)
-            throws ConfigurationException
-    {
-        return createConfig(configCls, setUpMultiParameters(configName));
+    public <T extends DatabaseConfiguration> T setUpConfig(final Class<T> configCls) throws ConfigurationException {
+        return createConfig(configCls, setUpDefaultParameters());
     }
 
     /**
-     * Creates a database configuration that supports multiple configurations in
-     * a table with default values.
-     *
-     * @return the configuration
-     * @throws ConfigurationException if an error occurs
-     */
-    public DatabaseConfiguration setUpMultiConfig() throws ConfigurationException
-    {
-        return setUpMultiConfig(DatabaseConfiguration.class, null);
-    }
-
-    /**
-     * Returns the {@code DataSource} managed by this class. The data
-     * source is created on first access.
-     *
-     * @return the {@code DataSource}
-     */
-    public DataSource getDatasource()
-    {
-        if (datasource == null)
-        {
-            try
-            {
-                datasource = setUpDataSource();
-            }
-            catch (final Exception ex)
-            {
-                throw new ConfigurationRuntimeException(
-                        "Could not create data source", ex);
-            }
-        }
-        return datasource;
-    }
-
-    /**
-     * Creates the internal data source. This method also initializes the
-     * database.
+     * Creates the internal data source. This method also initializes the database.
      *
      * @return the data source
      * @throws Exception if an error occurs
      */
-    private DataSource setUpDataSource() throws Exception
-    {
+    private DataSource setUpDataSource() throws Exception {
         final BasicDataSource ds = new BasicDataSource();
         ds.setDriverClassName(DATABASE_DRIVER);
         ds.setUrl(DATABASE_URL);
@@ -280,17 +180,12 @@ public class DatabaseConfigurationTestHelper
         // prepare the database
         final Connection conn = ds.getConnection();
         final IDatabaseConnection connection = new DatabaseConnection(conn);
-        final IDataSet dataSet = new XmlDataSet(new FileInputStream(
-                ConfigurationAssert.getTestFile("dataset.xml")));
+        final IDataSet dataSet = new XmlDataSet(new FileInputStream(ConfigurationAssert.getTestFile("dataset.xml")));
 
-        try
-        {
+        try {
             DatabaseOperation.CLEAN_INSERT.execute(connection, dataSet);
-        }
-        finally
-        {
-            if (!isAutoCommit())
-            {
+        } finally {
+            if (!isAutoCommit()) {
                 conn.commit();
             }
             connection.close();
@@ -298,4 +193,61 @@ public class DatabaseConfigurationTestHelper
 
         return ds;
     }
+
+    /**
+     * Returns a parameters object with default settings.
+     *
+     * @return the parameters object
+     */
+    public DatabaseBuilderParameters setUpDefaultParameters() {
+        return new Parameters().database().setDataSource(getDatasource()).setTable(TABLE).setKeyColumn(COL_KEY).setValueColumn(COL_VALUE)
+            .setAutoCommit(isAutoCommit());
+    }
+
+    /**
+     * Creates a database configuration that supports multiple configurations in a table with default values.
+     *
+     * @return the configuration
+     * @throws ConfigurationException if an error occurs
+     */
+    public DatabaseConfiguration setUpMultiConfig() throws ConfigurationException {
+        return setUpMultiConfig(DatabaseConfiguration.class, null);
+    }
+
+    /**
+     * Creates a configuration with support for multiple configuration instances in a single table of the specified class.
+     *
+     * @param <T> the type of the result configuration
+     * @param configCls the configuration class
+     * @param configName the name of the configuration instance or <b>null</b> for the default name
+     * @return the newly created configuration instance
+     * @throws ConfigurationException if an error occurs
+     */
+    public <T extends DatabaseConfiguration> T setUpMultiConfig(final Class<T> configCls, final String configName) throws ConfigurationException {
+        return createConfig(configCls, setUpMultiParameters(configName));
+    }
+
+    /**
+     * Returns a parameters object with settings for a configuration table containing the data of multiple configurations.
+     *
+     * @param configName the name of the configuration instance or <b>null</b> for the default name
+     * @return the parameters object
+     */
+    public DatabaseBuilderParameters setUpMultiParameters(final String configName) {
+        return setUpDefaultParameters().setTable(TABLE_MULTI).setConfigurationNameColumn(COL_NAME)
+            .setConfigurationName(configName != null ? configName : CONFIG_NAME);
+    }
+
+    /**
+     * Frees the resources used by this helper class. This method can be called by a {@code tearDown()} method of a unit
+     * test class.
+     *
+     * @throws Exception if an error occurs
+     */
+    public void tearDown() throws Exception {
+        if (datasource != null) {
+            datasource.getConnection().close();
+        }
+        hsqlDB.close();
+    }
 }
