@@ -26,11 +26,9 @@ import org.apache.log4j.ConsoleAppender;
 /**
  * Configures logging for tests.
  *
- * When running with Maven do -Dmaven.surefire.debug="LogLevel=level" to set the
- * Log Level to the desired value.
+ * When running with Maven do -Dmaven.surefire.debug="LogLevel=level" to set the Log Level to the desired value.
  */
-public class Logging extends Log4JLogger
-{
+public class Logging extends Log4JLogger {
     private static final long serialVersionUID = 8619242753795694874L;
 
     /**
@@ -40,25 +38,20 @@ public class Logging extends Log4JLogger
 
     private static Priority traceLevel; // TODO should this be Level?
 
-    static
-    {
+    static {
         // Releases of log4j1.2 >= 1.2.12 have Priority.TRACE available, earlier
         // versions do not. If TRACE is not available, then we have to map
         // calls to Log.trace(...) onto the DEBUG level.
 
-        try
-        {
+        try {
             traceLevel = (Priority) Level.class.getDeclaredField("TRACE").get(null);
-        }
-        catch (final Exception ex)
-        {
+        } catch (final Exception ex) {
             // ok, trace not available
             traceLevel = Level.DEBUG;
         }
 
         final String level = System.getProperty("LogLevel");
-        if (level != null)
-        {
+        if (level != null) {
             final org.apache.log4j.Logger log = org.apache.log4j.Logger.getRootLogger();
             log.setLevel(Level.toLevel(level));
             final Appender appender = new ConsoleAppender(new PatternLayout("%p %l - %m%n"), ConsoleAppender.SYSTEM_OUT);
@@ -66,28 +59,23 @@ public class Logging extends Log4JLogger
         }
     }
 
-    public Logging()
-    {
-        super();
-    }
-
-
-    /**
-     * Base constructor.
-     */
-    public Logging(final String name)
-    {
-        super(name);
+    public Logging() {
     }
 
     /**
      * For use with a log4j factory.
      */
-    public Logging(final org.apache.log4j.Logger logger)
-    {
+    public Logging(final org.apache.log4j.Logger logger) {
         super(logger);
     }
 
+    /**
+     * Base constructor.
+     */
+    public Logging(final String name) {
+        super(name);
+    }
+
     // ---------------------------------------------------------
     // Implementation
     //
@@ -105,38 +93,6 @@ public class Logging extends Log4JLogger
     // version 1.2 of log4j.
     // ---------------------------------------------------------
 
-
-    /**
-     * Logs a message with {@code org.apache.log4j.Priority.TRACE}.
-     * When using a log4j version that does not support the {@code TRACE}
-     * level, the message will be logged at the {@code DEBUG} level.
-     *
-     * @param message to log
-     * @see org.apache.commons.logging.Log#trace(Object)
-     */
-    @Override
-    public void trace(final Object message)
-    {
-        getLogger().log(FQCN, traceLevel, message, null);
-    }
-
-
-    /**
-     * Logs a message with {@code org.apache.log4j.Priority.TRACE}.
-     * When using a log4j version that does not support the {@code TRACE}
-     * level, the message will be logged at the {@code DEBUG} level.
-     *
-     * @param message to log
-     * @param t       log this cause
-     * @see org.apache.commons.logging.Log#trace(Object, Throwable)
-     */
-    @Override
-    public void trace(final Object message, final Throwable t)
-    {
-        getLogger().log(FQCN, traceLevel, message, t);
-    }
-
-
     /**
      * Logs a message with {@code org.apache.log4j.Priority.DEBUG}.
      *
@@ -144,8 +100,7 @@ public class Logging extends Log4JLogger
      * @see org.apache.commons.logging.Log#debug(Object)
      */
     @Override
-    public void debug(final Object message)
-    {
+    public void debug(final Object message) {
         getLogger().log(FQCN, Level.DEBUG, message, null);
     }
 
@@ -153,70 +108,14 @@ public class Logging extends Log4JLogger
      * Logs a message with {@code org.apache.log4j.Priority.DEBUG}.
      *
      * @param message to log
-     * @param t       log this cause
+     * @param t log this cause
      * @see org.apache.commons.logging.Log#debug(Object, Throwable)
      */
     @Override
-    public void debug(final Object message, final Throwable t)
-    {
+    public void debug(final Object message, final Throwable t) {
         getLogger().log(FQCN, Level.DEBUG, message, t);
     }
 
-
-    /**
-     * Logs a message with {@code org.apache.log4j.Priority.INFO}.
-     *
-     * @param message to log
-     * @see org.apache.commons.logging.Log#info(Object)
-     */
-    @Override
-    public void info(final Object message)
-    {
-        getLogger().log(FQCN, Level.INFO, message, null);
-    }
-
-
-    /**
-     * Logs a message with {@code org.apache.log4j.Priority.INFO}.
-     *
-     * @param message to log
-     * @param t       log this cause
-     * @see org.apache.commons.logging.Log#info(Object, Throwable)
-     */
-    @Override
-    public void info(final Object message, final Throwable t)
-    {
-        getLogger().log(FQCN, Level.INFO, message, t);
-    }
-
-
-    /**
-     * Logs a message with {@code org.apache.log4j.Priority.WARN}.
-     *
-     * @param message to log
-     * @see org.apache.commons.logging.Log#warn(Object)
-     */
-    @Override
-    public void warn(final Object message)
-    {
-        getLogger().log(FQCN, Level.WARN, message, null);
-    }
-
-
-    /**
-     * Logs a message with {@code org.apache.log4j.Priority.WARN}.
-     *
-     * @param message to log
-     * @param t       log this cause
-     * @see org.apache.commons.logging.Log#warn(Object, Throwable)
-     */
-    @Override
-    public void warn(final Object message, final Throwable t)
-    {
-        getLogger().log(FQCN, Level.WARN, message, t);
-    }
-
-
     /**
      * Logs a message with {@code org.apache.log4j.Priority.ERROR}.
      *
@@ -224,26 +123,22 @@ public class Logging extends Log4JLogger
      * @see org.apache.commons.logging.Log#error(Object)
      */
     @Override
-    public void error(final Object message)
-    {
+    public void error(final Object message) {
         getLogger().log(FQCN, Level.ERROR, message, null);
     }
 
-
     /**
      * Logs a message with {@code org.apache.log4j.Priority.ERROR}.
      *
      * @param message to log
-     * @param t       log this cause
+     * @param t log this cause
      * @see org.apache.commons.logging.Log#error(Object, Throwable)
      */
     @Override
-    public void error(final Object message, final Throwable t)
-    {
+    public void error(final Object message, final Throwable t) {
         getLogger().log(FQCN, Level.ERROR, message, t);
     }
 
-
     /**
      * Logs a message with {@code org.apache.log4j.Priority.FATAL}.
      *
@@ -251,23 +146,91 @@ public class Logging extends Log4JLogger
      * @see org.apache.commons.logging.Log#fatal(Object)
      */
     @Override
-    public void fatal(final Object message)
-    {
+    public void fatal(final Object message) {
         getLogger().log(FQCN, Level.FATAL, message, null);
     }
 
-
     /**
      * Logs a message with {@code org.apache.log4j.Priority.FATAL}.
      *
      * @param message to log
-     * @param t       log this cause
+     * @param t log this cause
      * @see org.apache.commons.logging.Log#fatal(Object, Throwable)
      */
     @Override
-    public void fatal(final Object message, final Throwable t)
-    {
+    public void fatal(final Object message, final Throwable t) {
         getLogger().log(FQCN, Level.FATAL, message, t);
     }
 
+    /**
+     * Logs a message with {@code org.apache.log4j.Priority.INFO}.
+     *
+     * @param message to log
+     * @see org.apache.commons.logging.Log#info(Object)
+     */
+    @Override
+    public void info(final Object message) {
+        getLogger().log(FQCN, Level.INFO, message, null);
+    }
+
+    /**
+     * Logs a message with {@code org.apache.log4j.Priority.INFO}.
+     *
+     * @param message to log
+     * @param t log this cause
+     * @see org.apache.commons.logging.Log#info(Object, Throwable)
+     */
+    @Override
+    public void info(final Object message, final Throwable t) {
+        getLogger().log(FQCN, Level.INFO, message, t);
+    }
+
+    /**
+     * Logs a message with {@code org.apache.log4j.Priority.TRACE}. When using a log4j version that does not support the
+     * {@code TRACE} level, the message will be logged at the {@code DEBUG} level.
+     *
+     * @param message to log
+     * @see org.apache.commons.logging.Log#trace(Object)
+     */
+    @Override
+    public void trace(final Object message) {
+        getLogger().log(FQCN, traceLevel, message, null);
+    }
+
+    /**
+     * Logs a message with {@code org.apache.log4j.Priority.TRACE}. When using a log4j version that does not support the
+     * {@code TRACE} level, the message will be logged at the {@code DEBUG} level.
+     *
+     * @param message to log
+     * @param t log this cause
+     * @see org.apache.commons.logging.Log#trace(Object, Throwable)
+     */
+    @Override
+    public void trace(final Object message, final Throwable t) {
+        getLogger().log(FQCN, traceLevel, message, t);
+    }
+
+    /**
+     * Logs a message with {@code org.apache.log4j.Priority.WARN}.
+     *
+     * @param message to log
+     * @see org.apache.commons.logging.Log#warn(Object)
+     */
+    @Override
+    public void warn(final Object message) {
+        getLogger().log(FQCN, Level.WARN, message, null);
+    }
+
+    /**
+     * Logs a message with {@code org.apache.log4j.Priority.WARN}.
+     *
+     * @param message to log
+     * @param t log this cause
+     * @see org.apache.commons.logging.Log#warn(Object, Throwable)
+     */
+    @Override
+    public void warn(final Object message, final Throwable t) {
+        getLogger().log(FQCN, Level.WARN, message, t);
+    }
+
 }
