@@ -29,14 +29,13 @@ import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
 
 /**
- * A mock implementation of the {@code InitialContextFactory} interface.
- * This implementation will return a mock context that contains some test data.
+ * A mock implementation of the {@code InitialContextFactory} interface. This implementation will return a mock context
+ * that contains some test data.
  */
-public class MockInitialContextFactory implements InitialContextFactory
-{
+public class MockInitialContextFactory implements InitialContextFactory {
     /**
-     * Constant for the use cycles environment property. If this property is
-     * present in the environment, a cyclic context will be created.
+     * Constant for the use cycles environment property. If this property is present in the environment, a cyclic context
+     * will be created.
      */
     public static final String PROP_CYCLES = "useCycles";
 
@@ -46,7 +45,7 @@ public class MockInitialContextFactory implements InitialContextFactory
     /** Constant for the list method. */
     private static final String METHOD_LIST = "list";
 
-    /** Constant for the close method.*/
+    /** Constant for the close method. */
     private static final String METHOD_CLOSE = "close";
 
     /** Constant for the name of the missing property. */
@@ -56,69 +55,57 @@ public class MockInitialContextFactory implements InitialContextFactory
     private static final String PREFIX = "test/";
 
     /** An array with the names of the supported properties. */
-    private static final String[] PROP_NAMES =
-    { "key", "key2", "short", "boolean", "byte", "double", "float", "integer",
-            "long", "onlyinjndi" };
+    private static final String[] PROP_NAMES = {"key", "key2", "short", "boolean", "byte", "double", "float", "integer", "long", "onlyinjndi"};
 
     /** An array with the values of the supported properties. */
-    private static final String[] PROP_VALUES =
-    { "jndivalue", "jndivalue2", "1", "true", "10", "10.25", "20.25", "10",
-            "1000000", "true" };
+    private static final String[] PROP_VALUES = {"jndivalue", "jndivalue2", "1", "true", "10", "10.25", "20.25", "10", "1000000", "true"};
 
     /** An array with properties that are requested, but are not in the context. */
-    private static final String[] MISSING_NAMES =
-    { "missing/list", "test/imaginarykey", "foo/bar" };
+    private static final String[] MISSING_NAMES = {"missing/list", "test/imaginarykey", "foo/bar"};
 
     /**
-     * Creates a {@code Context} object that is backed by a mock object.
-     * The mock context can be queried for the values of certain test
-     * properties. It also supports listing the contained (sub) properties.
+     * Adds a new name-and-value pair to an enum mock.
      *
-     * @param env the environment
-     * @return the context mock
+     * @param mockEnum the enum mock
+     * @param name the name
+     * @param value the value
      */
-    @Override
-    public Context getInitialContext(@SuppressWarnings("rawtypes") final Hashtable env) throws NamingException
-    {
-        final boolean useCycles = env.containsKey(PROP_CYCLES);
+    private void addEnumPair(final Mock mockEnum, final String name, final Object value) {
+        final NameClassPair ncp = new NameClassPair(name, value.getClass().getName());
+        mockEnum.expectAndReturn("hasMore", true);
+        mockEnum.expectAndReturn("next", ncp);
+    }
 
-        final Mock mockTopCtx = createCtxMock(PREFIX);
-        final Mock mockCycleCtx = createCtxMock("");
-        final Mock mockPrfxCtx = createCtxMock("");
-        final Mock mockBaseCtx = new Mock(Context.class);
-        mockBaseCtx.matchAndReturn(METHOD_LOOKUP, C.eq(""), mockTopCtx.proxy());
-        mockBaseCtx.matchAndReturn(METHOD_LOOKUP, C.eq("test"), mockPrfxCtx
-                .proxy());
-        mockTopCtx.matchAndReturn(METHOD_LOOKUP, C.eq("test"), mockPrfxCtx
-                .proxy());
-        mockPrfxCtx.matchAndReturn(METHOD_LIST, C.eq(""), createEnumMock(
-                mockPrfxCtx, PROP_NAMES, PROP_VALUES).proxy());
+    /**
+     * Binds a property value to the mock context.
+     *
+     * @param mockCtx the context
+     * @param name the name of the property
+     * @param value the value of the property
+     */
+    private void bind(final Mock mockCtx, final String name, final String value) {
+        mockCtx.matchAndReturn(METHOD_LOOKUP, C.eq(name), value);
+        bindError(mockCtx, name + MISSING_PROP);
+    }
 
-        if (useCycles)
-        {
-            mockTopCtx.matchAndReturn(METHOD_LOOKUP, C.eq("cycle"),
-                    mockCycleCtx.proxy());
-            mockTopCtx.matchAndReturn(METHOD_LIST, C.eq(""), createEnumMock(
-                    mockTopCtx, new String[]
-                    { "test", "cycle" }, new Object[]
-                    { mockPrfxCtx.proxy(), mockCycleCtx.proxy() }).proxy());
-            final Mock mockEnum = createEnumMock(mockCycleCtx, PROP_NAMES,
-                    PROP_VALUES, false);
-            addEnumPair(mockEnum, "cycleCtx", mockCycleCtx.proxy());
-            closeEnum(mockEnum);
-            mockCycleCtx
-                    .matchAndReturn(METHOD_LIST, C.eq(""), mockEnum.proxy());
-            mockCycleCtx.matchAndReturn(METHOD_LOOKUP, C.eq("cycleCtx"),
-                    mockCycleCtx.proxy());
-        }
-        else
-        {
-            mockTopCtx.matchAndReturn(METHOD_LIST, C.eq(""), createEnumMock(
-                    mockTopCtx, new String[]
-                    { "test" }, new Object[]
-                    { mockPrfxCtx.proxy() }).proxy());
-        }
-        return (Context) mockBaseCtx.proxy();
+    /**
+     * Configures the mock to expect a call for a non existing property.
+     *
+     * @param mockCtx the mock
+     * @param name the name of the property
+     */
+    private void bindError(final Mock mockCtx, final String name) {
+        mockCtx.matchAndThrow(METHOD_LOOKUP, C.eq(name), new NameNotFoundException("unknown property"));
+    }
+
+    /**
+     * Closes an enumeration mock.
+     *
+     * @param mockEnum the mock
+     */
+    private void closeEnum(final Mock mockEnum) {
+        mockEnum.expectAndReturn("hasMore", false);
+        mockEnum.expect(METHOD_CLOSE);
     }
 
     /**
@@ -127,14 +114,11 @@ public class MockInitialContextFactory implements InitialContextFactory
      * @param prefix the prefix
      * @return the mock for the context
      */
-    private Mock createCtxMock(final String prefix)
-    {
+    private Mock createCtxMock(final String prefix) {
         final Mock mockCtx = new Mock(Context.class);
-        for (int i = 0; i < PROP_NAMES.length; i++)
-        {
+        for (int i = 0; i < PROP_NAMES.length; i++) {
             bind(mockCtx, prefix + PROP_NAMES[i], PROP_VALUES[i]);
-            final String errProp = prefix.length() > 0 ? PROP_NAMES[i] : PREFIX
-                    + PROP_NAMES[i];
+            final String errProp = prefix.isEmpty() ? PREFIX + PROP_NAMES[i] : PROP_NAMES[i];
             bindError(mockCtx, errProp);
         }
         for (final String element : MISSING_NAMES) {
@@ -146,28 +130,16 @@ public class MockInitialContextFactory implements InitialContextFactory
     }
 
     /**
-     * Binds a property value to the mock context.
+     * Creates and initializes a mock for a naming enumeration that expects to be closed. This is a shortcut of
+     * createEnumMock(mockCtx, names, values, true);
      *
-     * @param mockCtx the context
-     * @param name the name of the property
-     * @param value the value of the property
+     * @param mockCtx the mock representing the context
+     * @param names the names contained in the iteration
+     * @param values the corresponding values
+     * @return the mock for the enumeration
      */
-    private void bind(final Mock mockCtx, final String name, final String value)
-    {
-        mockCtx.matchAndReturn(METHOD_LOOKUP, C.eq(name), value);
-        bindError(mockCtx, name + MISSING_PROP);
-    }
-
-    /**
-     * Configures the mock to expect a call for a non existing property.
-     *
-     * @param mockCtx the mock
-     * @param name the name of the property
-     */
-    private void bindError(final Mock mockCtx, final String name)
-    {
-        mockCtx.matchAndThrow(METHOD_LOOKUP, C.eq(name),
-                new NameNotFoundException("unknown property"));
+    private Mock createEnumMock(final Mock mockCtx, final String[] names, final Object[] values) {
+        return createEnumMock(mockCtx, names, values, true);
     }
 
     /**
@@ -179,58 +151,49 @@ public class MockInitialContextFactory implements InitialContextFactory
      * @param close a flag whether the enumeration should expect to be closed
      * @return the mock for the enumeration
      */
-    private Mock createEnumMock(final Mock mockCtx, final String[] names, final Object[] values,
-            final boolean close)
-    {
+    private Mock createEnumMock(final Mock mockCtx, final String[] names, final Object[] values, final boolean close) {
         final Mock mockEnum = new Mock(NamingEnumeration.class);
-        for (int i = 0; i < names.length; i++)
-        {
+        for (int i = 0; i < names.length; i++) {
             addEnumPair(mockEnum, names[i], values[i]);
         }
-        if (close)
-        {
+        if (close) {
             closeEnum(mockEnum);
         }
         return mockEnum;
     }
 
     /**
-     * Creates and initializes a mock for a naming enumeration that expects to
-     * be closed. This is a shortcut of createEnumMock(mockCtx, names, values,
-     * true);
+     * Creates a {@code Context} object that is backed by a mock object. The mock context can be queried for the values of
+     * certain test properties. It also supports listing the contained (sub) properties.
      *
-     * @param mockCtx the mock representing the context
-     * @param names the names contained in the iteration
-     * @param values the corresponding values
-     * @return the mock for the enumeration
+     * @param env the environment
+     * @return the context mock
      */
-    private Mock createEnumMock(final Mock mockCtx, final String[] names, final Object[] values)
-    {
-        return createEnumMock(mockCtx, names, values, true);
-    }
+    @Override
+    public Context getInitialContext(@SuppressWarnings("rawtypes") final Hashtable env) throws NamingException {
+        final boolean useCycles = env.containsKey(PROP_CYCLES);
 
-    /**
-     * Adds a new name-and-value pair to an enum mock.
-     *
-     * @param mockEnum the enum mock
-     * @param name the name
-     * @param value the value
-     */
-    private void addEnumPair(final Mock mockEnum, final String name, final Object value)
-    {
-        final NameClassPair ncp = new NameClassPair(name, value.getClass().getName());
-        mockEnum.expectAndReturn("hasMore", true);
-        mockEnum.expectAndReturn("next", ncp);
-    }
+        final Mock mockTopCtx = createCtxMock(PREFIX);
+        final Mock mockCycleCtx = createCtxMock("");
+        final Mock mockPrfxCtx = createCtxMock("");
+        final Mock mockBaseCtx = new Mock(Context.class);
+        mockBaseCtx.matchAndReturn(METHOD_LOOKUP, C.eq(""), mockTopCtx.proxy());
+        mockBaseCtx.matchAndReturn(METHOD_LOOKUP, C.eq("test"), mockPrfxCtx.proxy());
+        mockTopCtx.matchAndReturn(METHOD_LOOKUP, C.eq("test"), mockPrfxCtx.proxy());
+        mockPrfxCtx.matchAndReturn(METHOD_LIST, C.eq(""), createEnumMock(mockPrfxCtx, PROP_NAMES, PROP_VALUES).proxy());
 
-    /**
-     * Closes an enumeration mock.
-     *
-     * @param mockEnum the mock
-     */
-    private void closeEnum(final Mock mockEnum)
-    {
-        mockEnum.expectAndReturn("hasMore", false);
-        mockEnum.expect(METHOD_CLOSE);
+        if (useCycles) {
+            mockTopCtx.matchAndReturn(METHOD_LOOKUP, C.eq("cycle"), mockCycleCtx.proxy());
+            mockTopCtx.matchAndReturn(METHOD_LIST, C.eq(""),
+                createEnumMock(mockTopCtx, new String[] {"test", "cycle"}, new Object[] {mockPrfxCtx.proxy(), mockCycleCtx.proxy()}).proxy());
+            final Mock mockEnum = createEnumMock(mockCycleCtx, PROP_NAMES, PROP_VALUES, false);
+            addEnumPair(mockEnum, "cycleCtx", mockCycleCtx.proxy());
+            closeEnum(mockEnum);
+            mockCycleCtx.matchAndReturn(METHOD_LIST, C.eq(""), mockEnum.proxy());
+            mockCycleCtx.matchAndReturn(METHOD_LOOKUP, C.eq("cycleCtx"), mockCycleCtx.proxy());
+        } else {
+            mockTopCtx.matchAndReturn(METHOD_LIST, C.eq(""), createEnumMock(mockTopCtx, new String[] {"test"}, new Object[] {mockPrfxCtx.proxy()}).proxy());
+        }
+        return (Context) mockBaseCtx.proxy();
     }
 }
