@@ -43,66 +43,41 @@ import org.xml.sax.helpers.DefaultHandler;
  * Test class for BaseConfigurationXMLReader.
  *
  */
-public class TestBaseConfigurationXMLReader
-{
-    private static final String[] CONTINENTS =
-    {
-        "Africa", "America", "Asia", "Australia", "Europe"
-    };
+public class TestBaseConfigurationXMLReader {
+    // A ContentHandler that raises an exception
+    private static class TestContentHandler extends DefaultHandler {
+        @Override
+        public void characters(final char[] ch, final int start, final int length) throws SAXException {
+            throw new SAXException("Test exception during parsing");
+        }
+    }
 
+    private static final String[] CONTINENTS = {"Africa", "America", "Asia", "Australia", "Europe"};
     private BaseConfiguration config;
+
     private BaseConfigurationXMLReader configReader;
 
-    @Before
-    public void setUp() throws Exception
-    {
-        config = new BaseConfiguration();
-        config.addProperty("world.continents.continent", Arrays.asList(CONTINENTS));
-        config.addProperty("world.greeting", "Hello");
-        config.addProperty("world.greeting", "Salute");
-        config.addProperty("world.wish", "Peace");
-        config.addProperty("application.mail.smtp", "smtp.mymail.org");
-        config.addProperty("application.mail.pop", "pop3.mymail.org");
-        config.addProperty("application.mail.account.type", "pop3");
-        config.addProperty("application.mail.account.user", "postmaster");
-        config.addProperty("application.mail.account.pwd", "?.-gulp*#");
-        config.addProperty("application.mail.timeout", new Integer(42));
-        config.addProperty("test", Boolean.TRUE);
-
-        configReader = new BaseConfigurationXMLReader(config);
+    private void check(final JXPathContext ctx, final String path, final String value) {
+        check(ctx, path, new String[] {value});
     }
 
-    @Test
-    public void testParse() throws Exception
-    {
-        checkDocument(configReader, "config");
+    /**
+     * Helper method for checking values in the created document.
+     *
+     * @param ctx the JXPath context
+     * @param path the path to be checked
+     * @param values the expected element values
+     */
+    private void check(final JXPathContext ctx, final String path, final String[] values) {
+        final Iterator<?> it = ctx.iterate(path);
+        for (final String value : values) {
+            assertTrue("Too few values", it.hasNext());
+            assertEquals("Wrong property value", value, it.next());
+        }
+        assertFalse("Too many values", it.hasNext());
     }
 
-    @Test(expected = SAXException.class)
-    public void testParseSAXException() throws IOException, SAXException
-    {
-        configReader.setContentHandler(new TestContentHandler());
-        configReader.parse("systemID");
-    }
-
-    @Test(expected = IOException.class)
-    public void testParseIOException() throws SAXException, IOException
-    {
-        final BaseConfigurationXMLReader reader = new BaseConfigurationXMLReader();
-        reader.parse("document");
-    }
-
-    @Test
-    public void testSetRootName() throws Exception
-    {
-        final BaseConfigurationXMLReader reader = new BaseConfigurationXMLReader(config);
-        reader.setRootName("apache");
-        checkDocument(reader, "apache");
-    }
-
-    private void checkDocument(final BaseConfigurationXMLReader creader,
-    final String rootName) throws Exception
-    {
+    private void checkDocument(final BaseConfigurationXMLReader creader, final String rootName) throws Exception {
         final SAXSource source = new SAXSource(creader, new InputSource());
         final DOMResult result = new DOMResult();
         final Transformer trans = TransformerFactory.newInstance().newTransformer();
@@ -114,7 +89,7 @@ public class TestBaseConfigurationXMLReader
         assertEquals("Wrong number of children", 3, ctx.selectNodes("/*").size());
 
         check(ctx, "world/continents/continent", CONTINENTS);
-        check(ctx, "world/greeting", new String[] { "Hello", "Salute" });
+        check(ctx, "world/greeting", new String[] {"Hello", "Salute"});
         check(ctx, "world/wish", "Peace");
         check(ctx, "application/mail/smtp", "smtp.mymail.org");
         check(ctx, "application/mail/timeout", "42");
@@ -123,37 +98,45 @@ public class TestBaseConfigurationXMLReader
         check(ctx, "test", "true");
     }
 
-    /**
-     * Helper method for checking values in the created document.
-     *
-     * @param ctx the JXPath context
-     * @param path the path to be checked
-     * @param values the expected element values
-     */
-    private void check(final JXPathContext ctx, final String path, final String[] values)
-    {
-        final Iterator<?> it = ctx.iterate(path);
-        for (final String value : values) {
-            assertTrue("Too few values", it.hasNext());
-            assertEquals("Wrong property value", value, it.next());
-        }
-        assertFalse("Too many values", it.hasNext());
+    @Before
+    public void setUp() throws Exception {
+        config = new BaseConfiguration();
+        config.addProperty("world.continents.continent", Arrays.asList(CONTINENTS));
+        config.addProperty("world.greeting", "Hello");
+        config.addProperty("world.greeting", "Salute");
+        config.addProperty("world.wish", "Peace");
+        config.addProperty("application.mail.smtp", "smtp.mymail.org");
+        config.addProperty("application.mail.pop", "pop3.mymail.org");
+        config.addProperty("application.mail.account.type", "pop3");
+        config.addProperty("application.mail.account.user", "postmaster");
+        config.addProperty("application.mail.account.pwd", "?.-gulp*#");
+        config.addProperty("application.mail.timeout", Integer.valueOf(42));
+        config.addProperty("test", Boolean.TRUE);
+
+        configReader = new BaseConfigurationXMLReader(config);
     }
 
-    private void check(final JXPathContext ctx, final String path, final String value)
-    {
-        check(ctx, path, new String[]
-        { value });
+    @Test
+    public void testParse() throws Exception {
+        checkDocument(configReader, "config");
     }
 
-    // A ContentHandler that raises an exception
-    private static class TestContentHandler extends DefaultHandler
-     {
-        @Override
-        public void characters(final char[] ch, final int start, final int length)
-            throws SAXException
-        {
-            throw new SAXException("Test exception during parsing");
-        }
+    @Test(expected = IOException.class)
+    public void testParseIOException() throws SAXException, IOException {
+        final BaseConfigurationXMLReader reader = new BaseConfigurationXMLReader();
+        reader.parse("document");
+    }
+
+    @Test(expected = SAXException.class)
+    public void testParseSAXException() throws IOException, SAXException {
+        configReader.setContentHandler(new TestContentHandler());
+        configReader.parse("systemID");
+    }
+
+    @Test
+    public void testSetRootName() throws Exception {
+        final BaseConfigurationXMLReader reader = new BaseConfigurationXMLReader(config);
+        reader.setRootName("apache");
+        checkDocument(reader, "apache");
     }
 }
