@@ -17,7 +17,7 @@
 
 package org.apache.commons.configuration2;
 
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.assertEquals;
 
 import java.io.File;
 import java.io.StringWriter;
@@ -33,15 +33,13 @@ import org.junit.Test;
  * Unit test for simple MultiConfigurationTest.
  *
  */
-public class TestPatternSubtreeConfiguration
-{
-    private static File CONFIG_FILE = ConfigurationAssert.getTestFile("testPatternSubtreeConfig.xml");
-    private static String PATTERN = "BusinessClient[@name='${sys:Id}']";
+public class TestPatternSubtreeConfiguration {
+    private static final File CONFIG_FILE = ConfigurationAssert.getTestFile("testPatternSubtreeConfig.xml");
+    private static final String PATTERN = "BusinessClient[@name='${sys:Id}']";
     private XMLConfiguration conf;
 
     @Before
-    public void setUp() throws Exception
-    {
+    public void setUp() throws Exception {
         conf = new XMLConfiguration();
         new FileHandler(conf).load(CONFIG_FILE);
     }
@@ -50,44 +48,37 @@ public class TestPatternSubtreeConfiguration
      * Rigourous Test :-)
      */
     @Test
-    public void testMultiConfiguration()
-    {
+    public void testMultiConfiguration() {
         final PatternSubtreeConfigurationWrapper config = new PatternSubtreeConfigurationWrapper(this.conf, PATTERN);
         config.setExpressionEngine(new XPathExpressionEngine());
 
         System.setProperty("Id", "1001");
-        assertTrue(config.getInt("rowsPerPage") == 15);
+        assertEquals(15, config.getInt("rowsPerPage"));
 
         System.setProperty("Id", "1002");
-        assertTrue(config.getInt("rowsPerPage") == 25);
+        assertEquals(25, config.getInt("rowsPerPage"));
 
         System.setProperty("Id", "1003");
-        assertTrue(config.getInt("rowsPerPage") == 35);
+        assertEquals(35, config.getInt("rowsPerPage"));
     }
 
     /**
-     * Tests a read operation if the wrapped configuration does not implement
-     * FileBased.
+     * Tests a read operation if the wrapped configuration does not implement FileBased.
      */
     @Test(expected = ConfigurationException.class)
-    public void testReadNotFileBased() throws ConfigurationException
-    {
+    public void testReadNotFileBased() throws ConfigurationException {
         final HierarchicalConfiguration<ImmutableNode> hc = new BaseHierarchicalConfiguration();
-        final PatternSubtreeConfigurationWrapper config =
-                new PatternSubtreeConfigurationWrapper(hc, PATTERN);
+        final PatternSubtreeConfigurationWrapper config = new PatternSubtreeConfigurationWrapper(hc, PATTERN);
         new FileHandler(config).load(CONFIG_FILE);
     }
 
     /**
-     * Tests a write operation if the wrapped configuration does not implement
-     * FileBased.
+     * Tests a write operation if the wrapped configuration does not implement FileBased.
      */
     @Test(expected = ConfigurationException.class)
-    public void testSaveNotFileBased() throws ConfigurationException
-    {
+    public void testSaveNotFileBased() throws ConfigurationException {
         final HierarchicalConfiguration<ImmutableNode> hc = new BaseHierarchicalConfiguration();
-        final PatternSubtreeConfigurationWrapper config =
-                new PatternSubtreeConfigurationWrapper(hc, PATTERN);
+        final PatternSubtreeConfigurationWrapper config = new PatternSubtreeConfigurationWrapper(hc, PATTERN);
         new FileHandler(config).save(new StringWriter());
     }
 }
