@@ -18,7 +18,7 @@ package org.apache.commons.configuration2;
  */
 
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.assertFalse;
 
 import java.util.Iterator;
 import java.util.List;
@@ -30,15 +30,12 @@ import org.apache.commons.lang3.StringUtils;
 import org.junit.Test;
 
 /**
- * Test that the configuration factory returns keys in the same
- * sequence as the properties configurator
+ * Test that the configuration factory returns keys in the same sequence as the properties configurator
  *
  */
-public class TestPropertiesSequence
-{
+public class TestPropertiesSequence {
     @Test
-    public void testConfigurationValuesInSameOrderFromFile() throws Exception
-    {
+    public void testConfigurationValuesInSameOrderFromFile() throws Exception {
         final String simpleConfigurationFile = ConfigurationAssert.getTestFile("testSequence.properties").getAbsolutePath();
         final String compositeConfigurationFile = ConfigurationAssert.getTestFile("testSequenceDigester.xml").getAbsolutePath();
 
@@ -57,18 +54,16 @@ public class TestPropertiesSequence
         final List<String> keysSimpleConfiguration = ConfigurationAssert.keysToList(a);
         final List<String> keysCompositeConfiguration = ConfigurationAssert.keysToList(b);
 
-        assertTrue("Size:" + keysSimpleConfiguration.size(), keysSimpleConfiguration.size() > 0);
+        assertFalse("Size:" + keysSimpleConfiguration.size(), keysSimpleConfiguration.isEmpty());
         assertEquals(keysSimpleConfiguration.size(), keysCompositeConfiguration.size());
 
-        for (int i = 0; i < keysSimpleConfiguration.size(); i++)
-        {
+        for (int i = 0; i < keysSimpleConfiguration.size(); i++) {
             assertEquals(keysSimpleConfiguration.get(i), keysCompositeConfiguration.get(i));
         }
     }
 
     @Test
-    public void testConfigurationValuesInSameOrderWithManualAdd() throws Exception
-    {
+    public void testConfigurationValuesInSameOrderWithManualAdd() throws Exception {
         final String simpleConfigurationFile = ConfigurationAssert.getTestFile("testSequence.properties").getAbsolutePath();
         final String compositeConfigurationFile = ConfigurationAssert.getTestFile("testSequenceDigester.xml").getAbsolutePath();
 
@@ -93,18 +88,16 @@ public class TestPropertiesSequence
         final List<String> keysSimpleConfiguration = ConfigurationAssert.keysToList(a);
         final List<String> keysCompositeConfiguration = ConfigurationAssert.keysToList(b);
 
-        assertTrue("Size:" + keysSimpleConfiguration.size(), keysSimpleConfiguration.size() > 0);
+        assertFalse("Size:" + keysSimpleConfiguration.size(), keysSimpleConfiguration.isEmpty());
         assertEquals(keysSimpleConfiguration.size(), keysCompositeConfiguration.size());
 
-        for (int i = 0; i < keysSimpleConfiguration.size(); i++)
-        {
+        for (int i = 0; i < keysSimpleConfiguration.size(); i++) {
             assertEquals(keysSimpleConfiguration.get(i), keysCompositeConfiguration.get(i));
         }
     }
 
     @Test
-    public void testMappingInSameOrder() throws Exception
-    {
+    public void testMappingInSameOrder() throws Exception {
         final String simpleConfigurationFile = ConfigurationAssert.getTestFile("testSequence.properties").getAbsolutePath();
         final String compositeConfigurationFile = ConfigurationAssert.getTestFile("testSequenceDigester.xml").getAbsolutePath();
 
@@ -120,33 +113,27 @@ public class TestPropertiesSequence
         final Configuration mapping = new BaseConfiguration();
         final Configuration mapping2 = new BaseConfiguration();
 
-        for (final Iterator<String> keys = simpleConfiguration.getKeys(); keys.hasNext();)
-        {
+        for (final Iterator<String> keys = simpleConfiguration.getKeys(); keys.hasNext();) {
             final String key = keys.next();
             final String[] keyParts = StringUtils.split(key, ".");
 
-            if ((keyParts.length == 3) && keyParts[0].equals("prefix") && keyParts[2].equals("postfix"))
-            {
+            if ((keyParts.length == 3) && keyParts[0].equals("prefix") && keyParts[2].equals("postfix")) {
                 final String serviceKey = keyParts[1];
 
-                if (!mapping.containsKey(serviceKey))
-                {
+                if (!mapping.containsKey(serviceKey)) {
                     mapping.setProperty(serviceKey, simpleConfiguration.getString(key));
                 }
             }
         }
 
-        for (final Iterator<String> keys = compositeConfiguration.getKeys(); keys.hasNext();)
-        {
+        for (final Iterator<String> keys = compositeConfiguration.getKeys(); keys.hasNext();) {
             final String key = keys.next();
             final String[] keyParts = StringUtils.split(key, ".");
 
-            if ((keyParts.length == 3) && keyParts[0].equals("prefix") && keyParts[2].equals("postfix"))
-            {
+            if ((keyParts.length == 3) && keyParts[0].equals("prefix") && keyParts[2].equals("postfix")) {
                 final String serviceKey = keyParts[1];
 
-                if (!mapping2.containsKey(serviceKey))
-                {
+                if (!mapping2.containsKey(serviceKey)) {
                     mapping2.setProperty(serviceKey, compositeConfiguration.getString(key));
                 }
             }
