@@ -37,13 +37,10 @@ import static org.junit.Assert.assertThat;
 /**
  * Test class to test the handling of list structures in XMLConfiguration.
  */
-public class TestXMLListHandling
-{
+public class TestXMLListHandling {
     /** XML to be loaded by the configuration. */
-    private static final String SOURCE = "<config>" + "<values>a,b,c</values>"
-            + "<split><value>1</value><value>2</value></split>"
-            + "<mixed><values>foo,blah</values><values>bar,baz</values></mixed>"
-            + "</config>";
+    private static final String SOURCE = "<config>" + "<values>a,b,c</values>" + "<split><value>1</value><value>2</value></split>"
+        + "<mixed><values>foo,blah</values><values>bar,baz</values></mixed>" + "</config>";
 
     /** Key for the string property with multiple values. */
     private static final String KEY_VALUES = "values";
@@ -54,42 +51,30 @@ public class TestXMLListHandling
     /** The XML element name for the single values of the split list. */
     private static final String ELEM_SPLIT = "value";
 
-    /** Configuration to be tested. */
-    private XMLConfiguration config;
-
-    @Before
-    public void setUp() throws Exception
-    {
-        config = readFromString(SOURCE);
+    /**
+     * Checks whether the specified XML contains a list of values as a single, comma-separated string.
+     *
+     * @param xml the XML
+     * @param key the key
+     * @param values the expected values
+     */
+    private static void checkCommaSeparated(final String xml, final String key, final String... values) {
+        final String strValues = StringUtils.join(values, ',');
+        final String element = element(key, strValues);
+        assertThat(xml, containsString(element));
     }
 
     /**
-     * Parses the specified string into an XML configuration.
+     * Checks whether the specified XML contains a list of values as multiple XML elements.
      *
-     * @param xml the XML to be parsed
-     * @return the resulting configuration
+     * @param xml the XML
+     * @param key the key
+     * @param values the expected values
      */
-    private static XMLConfiguration readFromString(final String xml)
-            throws ConfigurationException
-    {
-        final XMLConfiguration config = new XMLConfiguration();
-        config.setListDelimiterHandler(new DefaultListDelimiterHandler(','));
-        final FileHandler handler = new FileHandler(config);
-        handler.load(new StringReader(xml));
-        return config;
-    }
-
-    /**
-     * Saves the test configuration into a string.
-     *
-     * @return the resulting string
-     */
-    private String saveToString() throws ConfigurationException
-    {
-        final StringWriter writer = new StringWriter(4096);
-        final FileHandler handler = new FileHandler(config);
-        handler.save(writer);
-        return writer.toString();
+    private static void checkSplit(final String xml, final String key, final String... values) {
+        for (final String v : values) {
+            assertThat(xml, containsString(element(key, v)));
+        }
     }
 
     /**
@@ -99,61 +84,49 @@ public class TestXMLListHandling
      * @param value the value
      * @return the string representation of this element
      */
-    private static String element(final String key, final String value)
-    {
+    private static String element(final String key, final String value) {
         return "<" + key + '>' + value + "</" + key + '>';
     }
 
     /**
-     * Checks whether the specified XML contains a list of values as a single,
-     * comma-separated string.
+     * Parses the specified string into an XML configuration.
      *
-     * @param xml the XML
-     * @param key the key
-     * @param values the expected values
+     * @param xml the XML to be parsed
+     * @return the resulting configuration
      */
-    private static void checkCommaSeparated(final String xml, final String key,
-            final String... values)
-    {
-        final String strValues = StringUtils.join(values, ',');
-        final String element = element(key, strValues);
-        assertThat(xml, containsString(element));
+    private static XMLConfiguration readFromString(final String xml) throws ConfigurationException {
+        final XMLConfiguration config = new XMLConfiguration();
+        config.setListDelimiterHandler(new DefaultListDelimiterHandler(','));
+        final FileHandler handler = new FileHandler(config);
+        handler.load(new StringReader(xml));
+        return config;
     }
 
+    /** Configuration to be tested. */
+    private XMLConfiguration config;
+
     /**
-     * Checks whether the specified XML contains a list of values as multiple
-     * XML elements.
+     * Saves the test configuration into a string.
      *
-     * @param xml the XML
-     * @param key the key
-     * @param values the expected values
+     * @return the resulting string
      */
-    private static void checkSplit(final String xml, final String key, final String... values)
-    {
-        for (final String v : values)
-        {
-            assertThat(xml, containsString(element(key, v)));
-        }
+    private String saveToString() throws ConfigurationException {
+        final StringWriter writer = new StringWriter(4096);
+        final FileHandler handler = new FileHandler(config);
+        handler.save(writer);
+        return writer.toString();
     }
 
-    /**
-     * Tests that the list format is kept if properties are not touched,
-     */
-    @Test
-    public void testSaveNoChanges() throws ConfigurationException
-    {
-        final String xml = saveToString();
-
-        checkSplit(xml, ELEM_SPLIT, "1", "2");
-        checkCommaSeparated(xml, KEY_VALUES, "a", "b", "c");
+    @Before
+    public void setUp() throws Exception {
+        config = readFromString(SOURCE);
     }
 
     /**
      * Tests that a list item can be added without affecting the format.
      */
     @Test
-    public void testAddListItem() throws ConfigurationException
-    {
+    public void testAddListItem() throws ConfigurationException {
         config.addProperty(KEY_VALUES, "d");
         config.addProperty(KEY_SPLIT, "3");
         final String xml = saveToString();
@@ -162,12 +135,34 @@ public class TestXMLListHandling
         checkCommaSeparated(xml, KEY_VALUES, "a", "b", "c", "d");
     }
 
+    /**
+     * Tries to save the configuration with a different list delimiter handler which does not support escaping of lists.
+     * This should fail with a meaningful exception message.
+     */
+    @Test(expected = ConfigurationRuntimeException.class)
+    public void testIncompatibleListDelimiterOnSaving() throws ConfigurationException {
+        config.setListDelimiterHandler(DisabledListDelimiterHandler.INSTANCE);
+        saveToString();
+    }
+
+    /**
+     * Tests whether a list consisting of multiple elements where some elements define multiple values is handled correctly.
+     */
+    @Test
+    public void testMixedList() throws ConfigurationException {
+        final List<String> expected = Arrays.asList("foo", "blah", "bar", "baz");
+        assertEquals("Wrong list value (1)", expected, config.getList("mixed.values"));
+        final String xml = saveToString();
+
+        final XMLConfiguration c2 = readFromString(xml);
+        assertEquals("Wrong list value (2)", expected, c2.getList("mixed.values"));
+    }
+
     /**
      * Tests that a list item can be removed without affecting the format.
      */
     @Test
-    public void testRemoveListItem() throws ConfigurationException
-    {
+    public void testRemoveListItem() throws ConfigurationException {
         config.clearProperty(KEY_VALUES + "(2)");
         config.clearProperty(KEY_SPLIT + "(1)");
         final String xml = saveToString();
@@ -177,32 +172,13 @@ public class TestXMLListHandling
     }
 
     /**
-     * Tests whether a list consisting of multiple elements where some elements
-     * define multiple values is handled correctly.
+     * Tests that the list format is kept if properties are not touched,
      */
     @Test
-    public void testMixedList() throws ConfigurationException
-    {
-        final List<String> expected = Arrays.asList("foo", "blah", "bar", "baz");
-        assertEquals("Wrong list value (1)", expected,
-                config.getList("mixed.values"));
+    public void testSaveNoChanges() throws ConfigurationException {
         final String xml = saveToString();
 
-        final XMLConfiguration c2 = readFromString(xml);
-        assertEquals("Wrong list value (2)", expected,
-                c2.getList("mixed.values"));
-    }
-
-    /**
-     * Tries to save the configuration with a different list delimiter handler
-     * which does not support escaping of lists. This should fail with a
-     * meaningful exception message.
-     */
-    @Test(expected = ConfigurationRuntimeException.class)
-    public void testIncompatibleListDelimiterOnSaving()
-            throws ConfigurationException
-    {
-        config.setListDelimiterHandler(DisabledListDelimiterHandler.INSTANCE);
-        saveToString();
+        checkSplit(xml, ELEM_SPLIT, "1", "2");
+        checkCommaSeparated(xml, KEY_VALUES, "a", "b", "c");
     }
 }
