@@ -28,58 +28,21 @@ import org.apache.commons.configuration2.event.EventListener;
 import org.apache.commons.configuration2.event.EventType;
 
 /**
- * A test implementation of an event listener for configuration builders. This
- * class is used by some unit tests. It collects the events received by the
- * listener and provides some methods for querying them.
+ * A test implementation of an event listener for configuration builders. This class is used by some unit tests. It
+ * collects the events received by the listener and provides some methods for querying them.
  *
  */
-public class BuilderEventListenerImpl implements
-        EventListener<ConfigurationBuilderEvent>
-{
+public class BuilderEventListenerImpl implements EventListener<ConfigurationBuilderEvent> {
     /** A list with the received events. */
-    private final List<ConfigurationBuilderEvent> events =
-            new LinkedList<>();
+    private final List<ConfigurationBuilderEvent> events = new LinkedList<>();
 
     /** An iterator for inspecting the received events. */
     private Iterator<ConfigurationBuilderEvent> iterator;
 
-    /**
-     * {@inheritDoc} This implementation just records the event.
-     */
-    @Override
-    public void onEvent(final ConfigurationBuilderEvent event)
-    {
-        events.add(event);
-    }
-
-    /**
-     * Checks whether the next received event is of the specified event type and
-     * returns it. Causes the test to fail if there are no more events or the
-     * next event is of a different event type.
-     *
-     * @param eventType the expected event type
-     * @param <T> the type of the received event
-     * @return the next received event
-     */
-    public <T extends ConfigurationBuilderEvent> T nextEvent(
-            final EventType<T> eventType)
-    {
-        final Iterator<ConfigurationBuilderEvent> it = initIterator();
-        assertTrue("Too few events received", it.hasNext());
-        final ConfigurationBuilderEvent nextEvent = it.next();
-        assertEquals("Wrong event type", eventType, nextEvent.getEventType());
-        // Safe cast because of the comparison of the event type
-        @SuppressWarnings("unchecked")
-        final
-        T resultEvent = (T) nextEvent;
-        return resultEvent;
-    }
-
     /**
      * Checks that no further events have been received by this listener.
      */
-    public void assertNoMoreEvents()
-    {
+    public void assertNoMoreEvents() {
         assertFalse("Too many events", initIterator().hasNext());
     }
 
@@ -88,12 +51,37 @@ public class BuilderEventListenerImpl implements
      *
      * @return the iterator to be used
      */
-    private Iterator<ConfigurationBuilderEvent> initIterator()
-    {
-        if (iterator == null)
-        {
+    private Iterator<ConfigurationBuilderEvent> initIterator() {
+        if (iterator == null) {
             iterator = events.iterator();
         }
         return iterator;
     }
+
+    /**
+     * Checks whether the next received event is of the specified event type and returns it. Causes the test to fail if
+     * there are no more events or the next event is of a different event type.
+     *
+     * @param eventType the expected event type
+     * @param <T> the type of the received event
+     * @return the next received event
+     */
+    public <T extends ConfigurationBuilderEvent> T nextEvent(final EventType<T> eventType) {
+        final Iterator<ConfigurationBuilderEvent> it = initIterator();
+        assertTrue("Too few events received", it.hasNext());
+        final ConfigurationBuilderEvent nextEvent = it.next();
+        assertEquals("Wrong event type", eventType, nextEvent.getEventType());
+        // Safe cast because of the comparison of the event type
+        @SuppressWarnings("unchecked")
+        final T resultEvent = (T) nextEvent;
+        return resultEvent;
+    }
+
+    /**
+     * {@inheritDoc} This implementation just records the event.
+     */
+    @Override
+    public void onEvent(final ConfigurationBuilderEvent event) {
+        events.add(event);
+    }
 }
