@@ -27,40 +27,90 @@ import org.junit.Test;
  * Test class for {@code AutoSaveListener}.
  *
  */
-public class TestAutoSaveListener
-{
+public class TestAutoSaveListener {
     /** A mock for the associated builder. */
     private FileBasedConfigurationBuilder<?> builder;
 
     /** The listener to be tested. */
     private AutoSaveListener listener;
 
-    @Before
-    public void setUp() throws Exception
-    {
-        builder = EasyMock.createMock(FileBasedConfigurationBuilder.class);
-        listener = new AutoSaveListener(builder);
-    }
-
     /**
      * Sends a configuration changed notification to the test listener.
      *
      * @param before flag whether the event is before the update
      */
-    private void fireChangeEvent(final boolean before)
-    {
-        listener.onEvent(new ConfigurationEvent(this,
-                ConfigurationEvent.ADD_PROPERTY, "someProperty",
-                "someValue", before));
+    private void fireChangeEvent(final boolean before) {
+        listener.onEvent(new ConfigurationEvent(this, ConfigurationEvent.ADD_PROPERTY, "someProperty", "someValue", before));
+    }
+
+    @Before
+    public void setUp() throws Exception {
+        builder = EasyMock.createMock(FileBasedConfigurationBuilder.class);
+        listener = new AutoSaveListener(builder);
     }
 
     /**
-     * Tests whether the file handler can be updated and is correctly
-     * initialized.
+     * Tests that after a load operation changes on the monitored configuration are detected again.
      */
     @Test
-    public void testUpdateFileHandler()
-    {
+    public void testConfigurationChangedAfterLoading() throws ConfigurationException {
+        builder.save();
+        EasyMock.replay(builder);
+        final FileHandler handler = new FileHandler();
+        listener.loading(handler);
+        fireChangeEvent(false);
+        listener.loaded(handler);
+        fireChangeEvent(false);
+        EasyMock.verify(builder);
+    }
+
+    /**
+     * Tests whether a change of the monitored configuration causes a save operation.
+     */
+    @Test
+    public void testConfigurationChangedAutoSave() throws ConfigurationException {
+        builder.save();
+        EasyMock.replay(builder);
+        fireChangeEvent(false);
+        EasyMock.verify(builder);
+    }
+
+    /**
+     * Tests whether an exception thrown by the builder's save() method is handled.
+     */
+    @Test
+    public void testConfigurationChangedAutoSaveException() throws ConfigurationException {
+        builder.save();
+        EasyMock.expectLastCall().andThrow(new ConfigurationException());
+        EasyMock.replay(builder);
+        fireChangeEvent(false);
+        EasyMock.verify(builder);
+    }
+
+    /**
+     * Tests whether no auto save is triggered before the change to the monitored configuration actually happens.
+     */
+    @Test
+    public void testConfigurationChangedBeforeUpdateNoSave() {
+        EasyMock.replay(builder);
+        fireChangeEvent(true);
+    }
+
+    /**
+     * Tests that updated during load operations do not create an auto save.
+     */
+    @Test
+    public void testConfigurationChangedWhileLoading() {
+        EasyMock.replay(builder);
+        listener.loading(new FileHandler());
+        fireChangeEvent(false);
+    }
+
+    /**
+     * Tests whether the file handler can be updated and is correctly initialized.
+     */
+    @Test
+    public void testUpdateFileHandler() {
         final FileHandler handler = EasyMock.createMock(FileHandler.class);
         final FileHandler handler2 = EasyMock.createMock(FileHandler.class);
         handler.addFileHandlerListener(listener);
@@ -73,12 +123,11 @@ public class TestAutoSaveListener
     }
 
     /**
-     * Tests whether updateFileHandler() can deal with null input. This is used
-     * for removing the listener when it is no longer needed.
+     * Tests whether updateFileHandler() can deal with null input. This is used for removing the listener when it is no
+     * longer needed.
      */
     @Test
-    public void testUpdateFileHandlerNull()
-    {
+    public void testUpdateFileHandlerNull() {
         final FileHandler handler = EasyMock.createMock(FileHandler.class);
         handler.addFileHandlerListener(listener);
         handler.removeFileHandlerListener(listener);
@@ -87,73 +136,4 @@ public class TestAutoSaveListener
         listener.updateFileHandler(null);
         EasyMock.verify(handler);
     }
-
-    /**
-     * Tests whether a change of the monitored configuration causes a save
-     * operation.
-     */
-    @Test
-    public void testConfigurationChangedAutoSave()
-            throws ConfigurationException
-    {
-        builder.save();
-        EasyMock.replay(builder);
-        fireChangeEvent(false);
-        EasyMock.verify(builder);
-    }
-
-    /**
-     * Tests whether an exception thrown by the builder's save() method is
-     * handled.
-     */
-    @Test
-    public void testConfigurationChangedAutoSaveException()
-            throws ConfigurationException
-    {
-        builder.save();
-        EasyMock.expectLastCall().andThrow(new ConfigurationException());
-        EasyMock.replay(builder);
-        fireChangeEvent(false);
-        EasyMock.verify(builder);
-    }
-
-    /**
-     * Tests whether no auto save is triggered before the change to the
-     * monitored configuration actually happens.
-     */
-    @Test
-    public void testConfigurationChangedBeforeUpdateNoSave()
-    {
-        EasyMock.replay(builder);
-        fireChangeEvent(true);
-    }
-
-    /**
-     * Tests that updated during load operations do not create an auto save.
-     */
-    @Test
-    public void testConfigurationChangedWhileLoading()
-    {
-        EasyMock.replay(builder);
-        listener.loading(new FileHandler());
-        fireChangeEvent(false);
-    }
-
-    /**
-     * Tests that after a load operation changes on the monitored configuration
-     * are detected again.
-     */
-    @Test
-    public void testConfigurationChangedAfterLoading()
-            throws ConfigurationException
-    {
-        builder.save();
-        EasyMock.replay(builder);
-        final FileHandler handler = new FileHandler();
-        listener.loading(handler);
-        fireChangeEvent(false);
-        listener.loaded(handler);
-        fireChangeEvent(false);
-        EasyMock.verify(builder);
-    }
 }
