@@ -29,78 +29,32 @@ import org.junit.Test;
  * Test class for {@code CopyObjectDefaultHandler}.
  *
  */
-public class TestCopyObjectDefaultHandler
-{
+public class TestCopyObjectDefaultHandler {
     /**
-     * Tries to create an instance without a source object.
-     */
-    @Test(expected = IllegalArgumentException.class)
-    public void testInitNull()
-    {
-        new CopyObjectDefaultHandler(null);
-    }
-
-    /**
-     * Tests whether default values can be copied onto an object of the same
-     * type.
+     * Tests whether a base type can be initialized with default values. Unknown properties should silently be ignored.
      */
     @Test
-    public void testInitializeDefaultsSameType()
-    {
-        final Long refresh = 50000L;
-        final FileBasedBuilderParametersImpl source =
-                new FileBasedBuilderParametersImpl();
-        source.setReloadingRefreshDelay(refresh).setThrowExceptionOnMissing(
-                true);
-        final CopyObjectDefaultHandler handler = new CopyObjectDefaultHandler(source);
-        final FileBasedBuilderParametersImpl copy =
-                new FileBasedBuilderParametersImpl();
-        handler.initializeDefaults(copy);
-        final Map<String, Object> map = copy.getParameters();
-        assertEquals("Wrong exception flag", Boolean.TRUE,
-                map.get("throwExceptionOnMissing"));
-        assertEquals("Wrong refresh", refresh, copy.getReloadingRefreshDelay());
-    }
-
-    /**
-     * Tests whether a base type can be initialized with default values. Unknown
-     * properties should silently be ignored.
-     */
-    @Test
-    public void testInitializeDefaultsBaseType()
-    {
+    public void testInitializeDefaultsBaseType() {
         final Long refresh = 50000L;
         final XMLBuilderParametersImpl paramsXml = new XMLBuilderParametersImpl();
-        paramsXml
-                .setValidating(true)
-                .setExpressionEngine(
-                        EasyMock.createMock(ExpressionEngine.class))
-                .setReloadingRefreshDelay(refresh);
-        final CopyObjectDefaultHandler handler =
-                new CopyObjectDefaultHandler(paramsXml);
-        final FileBasedBuilderParametersImpl paramsFb =
-                new FileBasedBuilderParametersImpl();
+        paramsXml.setValidating(true).setExpressionEngine(EasyMock.createMock(ExpressionEngine.class)).setReloadingRefreshDelay(refresh);
+        final CopyObjectDefaultHandler handler = new CopyObjectDefaultHandler(paramsXml);
+        final FileBasedBuilderParametersImpl paramsFb = new FileBasedBuilderParametersImpl();
         handler.initializeDefaults(paramsFb);
-        assertEquals("Wrong refresh", refresh,
-                paramsFb.getReloadingRefreshDelay());
+        assertEquals("Wrong refresh", refresh, paramsFb.getReloadingRefreshDelay());
     }
 
     /**
-     * Tests whether exceptions during copying are re-thrown as runtime
-     * exceptions.
+     * Tests whether exceptions during copying are re-thrown as runtime exceptions.
      */
     @Test(expected = ConfigurationRuntimeException.class)
-    public void testInitializeDefaultsException()
-    {
+    public void testInitializeDefaultsException() {
         final ExpressionEngine engine = EasyMock.createMock(ExpressionEngine.class);
         final XMLBuilderParametersImpl source = new XMLBuilderParametersImpl();
         source.setExpressionEngine(engine);
-        final XMLBuilderParametersImpl dest = new XMLBuilderParametersImpl()
-        {
+        final XMLBuilderParametersImpl dest = new XMLBuilderParametersImpl() {
             @Override
-            public HierarchicalBuilderParametersImpl setExpressionEngine(
-                    final ExpressionEngine engine)
-            {
+            public HierarchicalBuilderParametersImpl setExpressionEngine(final ExpressionEngine engine) {
                 throw new ConfigurationRuntimeException("Test exception");
             }
         };
@@ -108,4 +62,28 @@ public class TestCopyObjectDefaultHandler
         final CopyObjectDefaultHandler handler = new CopyObjectDefaultHandler(source);
         handler.initializeDefaults(dest);
     }
+
+    /**
+     * Tests whether default values can be copied onto an object of the same type.
+     */
+    @Test
+    public void testInitializeDefaultsSameType() {
+        final Long refresh = 50000L;
+        final FileBasedBuilderParametersImpl source = new FileBasedBuilderParametersImpl();
+        source.setReloadingRefreshDelay(refresh).setThrowExceptionOnMissing(true);
+        final CopyObjectDefaultHandler handler = new CopyObjectDefaultHandler(source);
+        final FileBasedBuilderParametersImpl copy = new FileBasedBuilderParametersImpl();
+        handler.initializeDefaults(copy);
+        final Map<String, Object> map = copy.getParameters();
+        assertEquals("Wrong exception flag", Boolean.TRUE, map.get("throwExceptionOnMissing"));
+        assertEquals("Wrong refresh", refresh, copy.getReloadingRefreshDelay());
+    }
+
+    /**
+     * Tries to create an instance without a source object.
+     */
+    @Test(expected = IllegalArgumentException.class)
+    public void testInitNull() {
+        new CopyObjectDefaultHandler(null);
+    }
 }
