@@ -42,8 +42,7 @@ import org.junit.Test;
  * Test class for {@code Configurations}.
  *
  */
-public class TestConfigurations
-{
+public class TestConfigurations {
     /** Constant for the name of the test properties file. */
     private static final String TEST_PROPERTIES = "test.properties";
 
@@ -65,76 +64,27 @@ public class TestConfigurations
      * @param name the name of the test file
      * @return the full path to this file
      */
-    private static String absolutePath(final String name)
-    {
+    private static String absolutePath(final String name) {
         return ConfigurationAssert.getTestFile(name).getAbsolutePath();
     }
 
     /**
-     * Tests whether a default {@code Parameters} instance is created if
-     * necessary.
+     * Checks whether a combined configuration was successfully loaded.
+     *
+     * @param config the configuration instance to be checked.
      */
-    @Test
-    public void testDefaultParameters()
-    {
-        final Configurations configs = new Configurations();
-        assertNotNull("No parameters", configs.getParameters());
+    private static void checkCombined(final Configuration config) {
+        checkProperties(config);
+        checkXML(config);
     }
 
     /**
-     * Tests whether parameters can be passed in at construction time.
+     * Checks whether a test INI configuration was correctly loaded.
+     *
+     * @param config the configuration instance to be checked.
      */
-    @Test
-    public void testInitWithParameters()
-    {
-        final Parameters params = new Parameters();
-        final Configurations configs = new Configurations(params);
-        assertSame("Wrong parameters", params, configs.getParameters());
-    }
-
-    /**
-     * Tests whether a builder for a file-based configuration can be created if
-     * an input File is specified.
-     */
-    @Test
-    public void testFileBasedBuilderWithFile()
-    {
-        final Configurations configs = new Configurations();
-        final File file = ConfigurationAssert.getTestFile(TEST_PROPERTIES);
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.fileBasedBuilder(PropertiesConfiguration.class, file);
-        assertEquals("Wrong file", file.toURI(), builder.getFileHandler()
-                .getFile().toURI());
-    }
-
-    /**
-     * Tests whether a builder for a file-based configuration can be created if
-     * a URL is specified.
-     */
-    @Test
-    public void testFileBasedBuilderWithURL()
-    {
-        final Configurations configs = new Configurations();
-        final URL url = ConfigurationAssert.getTestURL("test.properties");
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.fileBasedBuilder(PropertiesConfiguration.class, url);
-        assertEquals("Wrong URL", url, builder.getFileHandler().getURL());
-    }
-
-    /**
-     * Tests whether a builder for a file-based configuration can be created if
-     * a file name is specified.
-     */
-    @Test
-    public void testFileBasedBuilderWithPath()
-    {
-        final Configurations configs = new Configurations();
-        final String filePath = absolutePath(TEST_PROPERTIES);
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.fileBasedBuilder(PropertiesConfiguration.class,
-                        filePath);
-        assertEquals("Wrong path", filePath, builder.getFileHandler()
-                .getFileName());
+    private static void checkINI(final INIConfiguration config) {
+        assertEquals("yes", config.getProperty("testini.loaded"));
     }
 
     /**
@@ -142,175 +92,287 @@ public class TestConfigurations
      *
      * @param config the configuration instance to be checked.
      */
-    private static void checkPList(final Configuration config)
-    {
+    private static void checkPList(final Configuration config) {
         assertEquals("string1", config.getProperty("simple-string"));
     }
 
-    /**
-     * Tests whether a file-based configuration can be loaded from a file.
-     */
-    @Test
-    public void testFileBasedFile() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final PropertyListConfiguration config =
-                configs.fileBased(PropertyListConfiguration.class,
-                        ConfigurationAssert.getTestFile(TEST_PLIST));
-        checkPList(config);
-    }
-
-    /**
-     * Tests whether a file-based configuration can be loaded from a URL.
-     */
-    @Test
-    public void testFileBasedURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final PropertyListConfiguration config =
-                configs.fileBased(PropertyListConfiguration.class,
-                        ConfigurationAssert.getTestURL(TEST_PLIST));
-        checkPList(config);
-    }
-
-    /**
-     * Tests whether a file-based configuration can be loaded from a file path.
-     */
-    @Test
-    public void testFileBasedPath() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final PropertyListConfiguration config =
-                configs.fileBased(PropertyListConfiguration.class,
-                        absolutePath(TEST_PLIST));
-        checkPList(config);
-    }
-
     /**
      * Checks whether a test properties configuration was correctly loaded.
      *
      * @param config the configuration instance to be checked.
      */
-    private static void checkProperties(final Configuration config)
-    {
+    private static void checkProperties(final Configuration config) {
         assertEquals("true", config.getString("configuration.loaded"));
     }
 
     /**
-     * Tests whether a builder for a properties configuration can be created for
-     * a given file.
+     * Checks whether a test XML configuration was correctly loaded.
+     *
+     * @param config the configuration instance to be checked.
+     */
+    private static void checkXML(final Configuration config) {
+        assertEquals("value", config.getProperty("element"));
+    }
+
+    /**
+     * Tests whether a combined configuration builder can be constructed for a file.
      */
     @Test
-    public void testPropertiesBuilderFromFile() throws ConfigurationException
-    {
+    public void testCombinedBuilderFromFile() throws ConfigurationException {
         final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.propertiesBuilder(ConfigurationAssert
-                        .getTestFile(TEST_PROPERTIES));
+        final CombinedConfigurationBuilder builder = configs.combinedBuilder(ConfigurationAssert.getTestFile(TEST_COMBINED));
+        checkCombined(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a combined configuration builder can be constructed for a file path.
+     */
+    @Test
+    public void testCombinedBuilderFromPath() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final CombinedConfigurationBuilder builder = configs.combinedBuilder(absolutePath(TEST_COMBINED));
+        checkCombined(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a combined configuration builder can be constructed for a URL.
+     */
+    @Test
+    public void testCombinedBuilderFromURL() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final CombinedConfigurationBuilder builder = configs.combinedBuilder(ConfigurationAssert.getTestURL(TEST_COMBINED));
+        checkCombined(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a combined configuration can be loaded from a file.
+     */
+    @Test
+    public void testCombinedFromFile() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final CombinedConfiguration config = configs.combined(ConfigurationAssert.getTestFile(TEST_COMBINED));
+        checkCombined(config);
+    }
+
+    /**
+     * Tests whether a combined configuration can be loaded from a file path.
+     */
+    @Test
+    public void testCombinedFromPath() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final CombinedConfiguration config = configs.combined(absolutePath(TEST_COMBINED));
+        checkCombined(config);
+    }
+
+    /**
+     * Tests whether a combined configuration can be loaded from a URL.
+     */
+    @Test
+    public void testCombinedFromURL() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final CombinedConfiguration config = configs.combined(ConfigurationAssert.getTestURL(TEST_COMBINED));
+        checkCombined(config);
+    }
+
+    /**
+     * Tests whether a default {@code Parameters} instance is created if necessary.
+     */
+    @Test
+    public void testDefaultParameters() {
+        final Configurations configs = new Configurations();
+        assertNotNull("No parameters", configs.getParameters());
+    }
+
+    /**
+     * Tests whether a builder for a file-based configuration can be created if an input File is specified.
+     */
+    @Test
+    public void testFileBasedBuilderWithFile() {
+        final Configurations configs = new Configurations();
+        final File file = ConfigurationAssert.getTestFile(TEST_PROPERTIES);
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder = configs.fileBasedBuilder(PropertiesConfiguration.class, file);
+        assertEquals("Wrong file", file.toURI(), builder.getFileHandler().getFile().toURI());
+    }
+
+    /**
+     * Tests whether a builder for a file-based configuration can be created if a file name is specified.
+     */
+    @Test
+    public void testFileBasedBuilderWithPath() {
+        final Configurations configs = new Configurations();
+        final String filePath = absolutePath(TEST_PROPERTIES);
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder = configs.fileBasedBuilder(PropertiesConfiguration.class, filePath);
+        assertEquals("Wrong path", filePath, builder.getFileHandler().getFileName());
+    }
+
+    /**
+     * Tests whether a builder for a file-based configuration can be created if a URL is specified.
+     */
+    @Test
+    public void testFileBasedBuilderWithURL() {
+        final Configurations configs = new Configurations();
+        final URL url = ConfigurationAssert.getTestURL("test.properties");
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder = configs.fileBasedBuilder(PropertiesConfiguration.class, url);
+        assertEquals("Wrong URL", url, builder.getFileHandler().getURL());
+    }
+
+    /**
+     * Tests whether a file-based configuration can be loaded from a file.
+     */
+    @Test
+    public void testFileBasedFile() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final PropertyListConfiguration config = configs.fileBased(PropertyListConfiguration.class, ConfigurationAssert.getTestFile(TEST_PLIST));
+        checkPList(config);
+    }
+
+    /**
+     * Tests whether a file-based configuration can be loaded from a file path.
+     */
+    @Test
+    public void testFileBasedPath() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final PropertyListConfiguration config = configs.fileBased(PropertyListConfiguration.class, absolutePath(TEST_PLIST));
+        checkPList(config);
+    }
+
+    /**
+     * Tests whether a file-based configuration can be loaded from a URL.
+     */
+    @Test
+    public void testFileBasedURL() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final PropertyListConfiguration config = configs.fileBased(PropertyListConfiguration.class, ConfigurationAssert.getTestURL(TEST_PLIST));
+        checkPList(config);
+    }
+
+    /**
+     * Tests whether a builder for a INI configuration can be created for a given file.
+     */
+    @Test
+    public void testINIBuilderFromFile() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<INIConfiguration> builder = configs.iniBuilder(ConfigurationAssert.getTestFile(TEST_INI));
+        checkINI(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a builder for a INI configuration can be created for a given file path.
+     */
+    @Test
+    public void testINIBuilderFromPath() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<INIConfiguration> builder = configs.iniBuilder(absolutePath(TEST_INI));
+        checkINI(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a builder for a INI configuration can be created for a given URL.
+     */
+    @Test
+    public void testINIBuilderFromURL() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<INIConfiguration> builder = configs.iniBuilder(ConfigurationAssert.getTestURL(TEST_INI));
+        checkINI(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a INI configuration can be loaded from a file.
+     */
+    @Test
+    public void testINIFromFile() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final INIConfiguration config = configs.ini(ConfigurationAssert.getTestFile(TEST_INI));
+        checkINI(config);
+    }
+
+    /**
+     * Tests whether a INI configuration can be loaded from a file path.
+     */
+    @Test
+    public void testINIFromPath() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final INIConfiguration config = configs.ini(absolutePath(TEST_INI));
+        checkINI(config);
+    }
+
+    /**
+     * Tests whether a INI configuration can be loaded from a URL.
+     */
+    @Test
+    public void testINIFromURL() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final INIConfiguration config = configs.ini(ConfigurationAssert.getTestURL(TEST_INI));
+        checkINI(config);
+    }
+
+    /**
+     * Tests whether parameters can be passed in at construction time.
+     */
+    @Test
+    public void testInitWithParameters() {
+        final Parameters params = new Parameters();
+        final Configurations configs = new Configurations(params);
+        assertSame("Wrong parameters", params, configs.getParameters());
+    }
+
+    /**
+     * Tests whether a builder for a properties configuration can be created for a given file.
+     */
+    @Test
+    public void testPropertiesBuilderFromFile() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder = configs.propertiesBuilder(ConfigurationAssert.getTestFile(TEST_PROPERTIES));
         checkProperties(builder.getConfiguration());
     }
 
     /**
-     * Tests whether a properties configuration can be loaded from a file.
+     * Tests whether a builder for a properties configuration can be created for a given file path.
      */
     @Test
-    public void testPropertiesFromFile() throws ConfigurationException
-    {
+    public void testPropertiesBuilderFromPath() throws ConfigurationException {
         final Configurations configs = new Configurations();
-        final PropertiesConfiguration config =
-                configs.properties(ConfigurationAssert
-                        .getTestFile(TEST_PROPERTIES));
-        checkProperties(config);
-    }
-
-    /**
-     * Tests whether a builder for a properties configuration can be created for
-     * a given URL.
-     */
-    @Test
-    public void testPropertiesBuilderFromURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.propertiesBuilder(ConfigurationAssert
-                        .getTestURL(TEST_PROPERTIES));
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder = configs.propertiesBuilder(absolutePath(TEST_PROPERTIES));
         checkProperties(builder.getConfiguration());
     }
 
     /**
-     * Tests whether a properties configuration can be loaded from a URL.
+     * Tests whether a builder for a properties configuration can be created for a given file path when an include is not
+     * found.
      */
     @Test
-    public void testPropertiesFromURL() throws ConfigurationException
-    {
+    public void testPropertiesBuilderFromPathIncludeNotFoundFail() {
         final Configurations configs = new Configurations();
-        final PropertiesConfiguration config =
-                configs.properties(ConfigurationAssert
-                        .getTestURL(TEST_PROPERTIES));
-        checkProperties(config);
-    }
-
-    /**
-     * Tests whether a builder for a properties configuration can be created for
-     * a given file path.
-     */
-    @Test
-    public void testPropertiesBuilderFromPath() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.propertiesBuilder(absolutePath(TEST_PROPERTIES));
-        checkProperties(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a builder for a properties configuration can be created for
-     * a given file path when an include is not found.
-     */
-    @Test
-    public void testPropertiesBuilderFromPathIncludeNotFoundFail() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.propertiesBuilder(absolutePath("include-not-found.properties"));
-        try
-        {
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder = configs.propertiesBuilder(absolutePath("include-not-found.properties"));
+        try {
             builder.getConfiguration();
             Assert.fail("Expected ConfigurationException");
-        }
-        catch (ConfigurationException e) {
+        } catch (final ConfigurationException e) {
             // ignore
         }
     }
 
     /**
-     * Tests whether a builder for a properties configuration can be created for
-     * a given file path when an include is not found.
+     * Tests whether a builder for a properties configuration can be created for a given file path when an include is not
+     * found.
      */
     @Test
-    public void testPropertiesBuilderFromPathIncludeNotFoundPass() throws ConfigurationException
-    {
+    public void testPropertiesBuilderFromPathIncludeNotFoundPass() throws ConfigurationException {
         final Configurations configs = new Configurations();
         final String absPath = absolutePath("include-not-found.properties");
-        final FileBasedConfigurationBuilder<PropertiesConfiguration> builderFail =
-                configs.propertiesBuilder(absPath);
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builderFail = configs.propertiesBuilder(absPath);
         // Expect failure:
-        try
-        {
+        try {
             builderFail.getConfiguration();
             Assert.fail("Expected ConfigurationException");
-        }
-        catch (ConfigurationException e)
-        {
+        } catch (final ConfigurationException e) {
             // Ignore
             // e.printStackTrace();
         }
         // Expect failure:
-        try
-        {
+        try {
             configs.properties(absPath);
-        }
-        catch (ConfigurationException e) {
+        } catch (final ConfigurationException e) {
             // Ignore
             // e.printStackTrace();
         }
@@ -323,8 +385,7 @@ public class TestConfigurations
                             .setIncludeListener(PropertiesConfiguration.NOOP_INCLUDE_LISTENER)
                             .getParameters();
             // @formatter:on
-            final BasicConfigurationBuilder<PropertiesConfiguration> builderOk = configs.propertiesBuilder(absPath)
-                    .addParameters(map);
+            final BasicConfigurationBuilder<PropertiesConfiguration> builderOk = configs.propertiesBuilder(absPath).addParameters(map);
             final PropertiesConfiguration configuration = builderOk.getConfiguration();
             assertEquals("valueA", configuration.getString("keyA"));
         }
@@ -342,37 +403,72 @@ public class TestConfigurations
     }
 
     /**
-     * Tests whether a properties configuration can be loaded from a file path.
+     * Tests whether a builder for a properties configuration can be created for a given URL.
      */
     @Test
-    public void testPropertiesFromPath() throws ConfigurationException
-    {
+    public void testPropertiesBuilderFromURL() throws ConfigurationException {
         final Configurations configs = new Configurations();
-        final PropertiesConfiguration config =
-                configs.properties(absolutePath(TEST_PROPERTIES));
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder = configs.propertiesBuilder(ConfigurationAssert.getTestURL(TEST_PROPERTIES));
+        checkProperties(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a properties configuration can be loaded from a file.
+     */
+    @Test
+    public void testPropertiesFromFile() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final PropertiesConfiguration config = configs.properties(ConfigurationAssert.getTestFile(TEST_PROPERTIES));
         checkProperties(config);
     }
 
     /**
-     * Checks whether a test XML configuration was correctly loaded.
-     *
-     * @param config the configuration instance to be checked.
+     * Tests whether a properties configuration can be loaded from a file path.
      */
-    private static void checkXML(final Configuration config)
-    {
-        assertEquals("value", config.getProperty("element"));
+    @Test
+    public void testPropertiesFromPath() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final PropertiesConfiguration config = configs.properties(absolutePath(TEST_PROPERTIES));
+        checkProperties(config);
     }
 
     /**
-     * Tests whether a builder for a XML configuration can be created for a
-     * given file.
+     * Tests whether a properties configuration can be loaded from a URL.
      */
     @Test
-    public void testXMLBuilderFromFile() throws ConfigurationException
-    {
+    public void testPropertiesFromURL() throws ConfigurationException {
         final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<XMLConfiguration> builder =
-                configs.xmlBuilder(ConfigurationAssert.getTestFile(TEST_XML));
+        final PropertiesConfiguration config = configs.properties(ConfigurationAssert.getTestURL(TEST_PROPERTIES));
+        checkProperties(config);
+    }
+
+    /**
+     * Tests whether a builder for a XML configuration can be created for a given file.
+     */
+    @Test
+    public void testXMLBuilderFromFile() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<XMLConfiguration> builder = configs.xmlBuilder(ConfigurationAssert.getTestFile(TEST_XML));
+        checkXML(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a builder for a XML configuration can be created for a given file path.
+     */
+    @Test
+    public void testXMLBuilderFromPath() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<XMLConfiguration> builder = configs.xmlBuilder(absolutePath(TEST_XML));
+        checkXML(builder.getConfiguration());
+    }
+
+    /**
+     * Tests whether a builder for a XML configuration can be created for a given URL.
+     */
+    @Test
+    public void testXMLBuilderFromURL() throws ConfigurationException {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<XMLConfiguration> builder = configs.xmlBuilder(ConfigurationAssert.getTestURL(TEST_XML));
         checkXML(builder.getConfiguration());
     }
 
@@ -380,232 +476,29 @@ public class TestConfigurations
      * Tests whether a XML configuration can be loaded from a file.
      */
     @Test
-    public void testXMLFromFile() throws ConfigurationException
-    {
+    public void testXMLFromFile() throws ConfigurationException {
         final Configurations configs = new Configurations();
-        final XMLConfiguration config =
-                configs.xml(ConfigurationAssert.getTestFile(TEST_XML));
+        final XMLConfiguration config = configs.xml(ConfigurationAssert.getTestFile(TEST_XML));
         checkXML(config);
     }
 
-    /**
-     * Tests whether a builder for a XML configuration can be created for a
-     * given URL.
-     */
-    @Test
-    public void testXMLBuilderFromURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<XMLConfiguration> builder =
-                configs.xmlBuilder(ConfigurationAssert.getTestURL(TEST_XML));
-        checkXML(builder.getConfiguration());
-    }
-
     /**
      * Tests whether a XML configuration can be loaded from a URL.
      */
     @Test
-    public void testXMLFromURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final XMLConfiguration config =
-                configs.xml(ConfigurationAssert.getTestURL(TEST_XML));
-        checkXML(config);
-    }
-
-    /**
-     * Tests whether a builder for a XML configuration can be created for a
-     * given file path.
-     */
-    @Test
-    public void testXMLBuilderFromPath() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<XMLConfiguration> builder =
-                configs.xmlBuilder(absolutePath(TEST_XML));
-        checkXML(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a XML configuration can be loaded from a URL.
-     */
-    @Test
-    public void testXMLFromPath() throws ConfigurationException
-    {
+    public void testXMLFromPath() throws ConfigurationException {
         final Configurations configs = new Configurations();
         final XMLConfiguration config = configs.xml(absolutePath(TEST_XML));
         checkXML(config);
     }
 
     /**
-     * Checks whether a test INI configuration was correctly loaded.
-     *
-     * @param config the configuration instance to be checked.
-     */
-    private static void checkINI(final INIConfiguration config)
-    {
-        assertEquals("yes", config.getProperty("testini.loaded"));
-    }
-
-    /**
-     * Tests whether a builder for a INI configuration can be created for a
-     * given file.
+     * Tests whether a XML configuration can be loaded from a URL.
      */
     @Test
-    public void testINIBuilderFromFile() throws ConfigurationException
-    {
+    public void testXMLFromURL() throws ConfigurationException {
         final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<INIConfiguration> builder =
-                configs.iniBuilder(ConfigurationAssert.getTestFile(TEST_INI));
-        checkINI(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a INI configuration can be loaded from a file.
-     */
-    @Test
-    public void testINIFromFile() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final INIConfiguration config =
-                configs.ini(ConfigurationAssert.getTestFile(TEST_INI));
-        checkINI(config);
-    }
-
-    /**
-     * Tests whether a builder for a INI configuration can be created for a
-     * given URL.
-     */
-    @Test
-    public void testINIBuilderFromURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<INIConfiguration> builder =
-                configs.iniBuilder(ConfigurationAssert.getTestURL(TEST_INI));
-        checkINI(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a INI configuration can be loaded from a URL.
-     */
-    @Test
-    public void testINIFromURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final INIConfiguration config =
-                configs.ini(ConfigurationAssert.getTestURL(TEST_INI));
-        checkINI(config);
-    }
-
-    /**
-     * Tests whether a builder for a INI configuration can be created for a
-     * given file path.
-     */
-    @Test
-    public void testINIBuilderFromPath() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final FileBasedConfigurationBuilder<INIConfiguration> builder =
-                configs.iniBuilder(absolutePath(TEST_INI));
-        checkINI(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a INI configuration can be loaded from a file path.
-     */
-    @Test
-    public void testINIFromPath() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final INIConfiguration config = configs.ini(absolutePath(TEST_INI));
-        checkINI(config);
-    }
-
-    /**
-     * Checks whether a combined configuration was successfully loaded.
-     *
-     * @param config the configuration instance to be checked.
-     */
-    private static void checkCombined(final Configuration config)
-    {
-        checkProperties(config);
+        final XMLConfiguration config = configs.xml(ConfigurationAssert.getTestURL(TEST_XML));
         checkXML(config);
     }
-
-    /**
-     * Tests whether a combined configuration builder can be constructed for a
-     * file.
-     */
-    @Test
-    public void testCombinedBuilderFromFile() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final CombinedConfigurationBuilder builder =
-                configs.combinedBuilder(ConfigurationAssert
-                        .getTestFile(TEST_COMBINED));
-        checkCombined(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a combined configuration can be loaded from a file.
-     */
-    @Test
-    public void testCombinedFromFile() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final CombinedConfiguration config =
-                configs.combined(ConfigurationAssert.getTestFile(TEST_COMBINED));
-        checkCombined(config);
-    }
-
-    /**
-     * Tests whether a combined configuration builder can be constructed for a
-     * URL.
-     */
-    @Test
-    public void testCombinedBuilderFromURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final CombinedConfigurationBuilder builder =
-                configs.combinedBuilder(ConfigurationAssert
-                        .getTestURL(TEST_COMBINED));
-        checkCombined(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a combined configuration can be loaded from a URL.
-     */
-    @Test
-    public void testCombinedFromURL() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final CombinedConfiguration config =
-                configs.combined(ConfigurationAssert.getTestURL(TEST_COMBINED));
-        checkCombined(config);
-    }
-
-    /**
-     * Tests whether a combined configuration builder can be constructed for a
-     * file path.
-     */
-    @Test
-    public void testCombinedBuilderFromPath() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final CombinedConfigurationBuilder builder =
-                configs.combinedBuilder(absolutePath(TEST_COMBINED));
-        checkCombined(builder.getConfiguration());
-    }
-
-    /**
-     * Tests whether a combined configuration can be loaded from a file path.
-     */
-    @Test
-    public void testCombinedFromPath() throws ConfigurationException
-    {
-        final Configurations configs = new Configurations();
-        final CombinedConfiguration config =
-                configs.combined(absolutePath(TEST_COMBINED));
-        checkCombined(config);
-    }
 }
