@@ -28,245 +28,199 @@ import java.util.Set;
 import org.junit.Test;
 
 /**
- * A test class which tests whether the types of basic configuration events are
- * correctly defined.
+ * A test class which tests whether the types of basic configuration events are correctly defined.
  *
  */
-public class TestConfigurationEventTypes
-{
+public class TestConfigurationEventTypes {
     /**
-     * Tests whether the set of super event types for null input can be
-     * obtained.
+     * Helper method for checking the relevant properties of an error event type.
+     *
+     * @param type the type to be checked
      */
-    @Test
-    public void testFetchSuperEventTypesNull()
-    {
-        final Set<EventType<?>> superTypes = EventType.fetchSuperEventTypes(null);
-        assertTrue("Got super types", superTypes.isEmpty());
+    private void checkErrorEvent(final EventType<ConfigurationErrorEvent> type) {
+        assertSame("Wrong super type for " + type, ConfigurationErrorEvent.ANY, type.getSuperType());
     }
 
     /**
-     * Tests whether the set of super event types for the base type can be
-     * obtained.
-     */
-    @Test
-    public void testFetchSuperEventTypesForBaseType()
-    {
-        final Set<EventType<?>> superTypes =
-                EventType.fetchSuperEventTypes(Event.ANY);
-        assertEquals("Wrong number of super types", 1, superTypes.size());
-        assertTrue("Wrong super types", superTypes.contains(Event.ANY));
-    }
-
-    /**
-     * Tests whether the super event types of a specific type can be retrieved.
-     */
-    @Test
-    public void testFetchSuperEventTypesOfType()
-    {
-        final Set<EventType<?>> superTypes =
-                EventType.fetchSuperEventTypes(ConfigurationEvent.ADD_NODES);
-        final List<EventType<? extends Event>> expected =
-                new LinkedList<>();
-        expected.add(ConfigurationEvent.ADD_NODES);
-        expected.add(ConfigurationEvent.ANY_HIERARCHICAL);
-        expected.add(ConfigurationEvent.ANY);
-        expected.add(Event.ANY);
-        assertEquals("Wrong number of super types", expected.size(),
-                superTypes.size());
-        assertTrue("Wrong super types: " + superTypes,
-                superTypes.containsAll(expected));
-    }
-
-    /**
-     * Tests isInstanceOf() if the derived type is null.
-     */
-    @Test
-    public void testIsInstanceOfDerivedNull()
-    {
-        assertFalse("Wrong result", EventType.isInstanceOf(null, Event.ANY));
-    }
-
-    /**
-     * Tests isInstanceOf() if the base type is null.
-     */
-    @Test
-    public void testIsInstanceOfBaseNull()
-    {
-        assertFalse("Wrong result",
-                EventType.isInstanceOf(ConfigurationEvent.ANY, null));
-    }
-
-    /**
-     * Tests isInstanceOf() if there is no instanceof relationship.
-     */
-    @Test
-    public void testIsInstanceOfFalse()
-    {
-        assertFalse("Wrong result", EventType.isInstanceOf(
-                ConfigurationErrorEvent.READ, ConfigurationEvent.ANY));
-    }
-
-    /**
-     * Tests isInstanceOf() if the expected result is true.
-     */
-    @Test
-    public void testIsInstanceOfTrue()
-    {
-        assertTrue("Wrong result (1)", EventType.isInstanceOf(
-                ConfigurationEvent.ADD_NODES,
-                ConfigurationEvent.ANY_HIERARCHICAL));
-        assertTrue("Wrong result (2)", EventType.isInstanceOf(
-                ConfigurationEvent.ADD_NODES, ConfigurationEvent.ANY));
-        assertTrue("Wrong result (3)",
-                EventType.isInstanceOf(ConfigurationEvent.ADD_NODES, Event.ANY));
-        assertTrue("Wrong result (4)", EventType.isInstanceOf(
-                ConfigurationEvent.ADD_NODES, ConfigurationEvent.ADD_NODES));
-    }
-
-    /**
-     * Tests the base event type for configuration events.
-     */
-    @Test
-    public void testConfigurationEventType()
-    {
-        assertSame("Wrong super type", Event.ANY,
-                ConfigurationEvent.ANY.getSuperType());
-    }
-
-    /**
-     * Helper method for checking the relevant properties of a given event type
-     * representing a configuration update event.
+     * Helper method for checking the relevant properties of a given event type representing a hierarchical update event.
      *
      * @param eventType the event type to check
      */
-    private void checkUpdateEvent(final EventType<ConfigurationEvent> eventType)
-    {
-        assertSame("Wrong super type for " + eventType, ConfigurationEvent.ANY,
-                eventType.getSuperType());
+    private void checkHierarchicalEvent(final EventType<ConfigurationEvent> eventType) {
+        assertSame("Wrong super type for " + eventType, ConfigurationEvent.ANY_HIERARCHICAL, eventType.getSuperType());
     }
 
     /**
-     * Tests the event type for adding a property.
-     */
-    @Test
-    public void testAddPropertyEventType()
-    {
-        checkUpdateEvent(ConfigurationEvent.ADD_PROPERTY);
-    }
-
-    /**
-     * Tests the event type for setting a property.
-     */
-    @Test
-    public void testSetPropertyEventType()
-    {
-        checkUpdateEvent(ConfigurationEvent.SET_PROPERTY);
-    }
-
-    /**
-     * Tests the event type for clearing a property.
-     */
-    @Test
-    public void testClearPropertyEventType()
-    {
-        checkUpdateEvent(ConfigurationEvent.CLEAR_PROPERTY);
-    }
-
-    /**
-     * Tests the event type for clearing a whole configuration.
-     */
-    @Test
-    public void testClearEventType()
-    {
-        checkUpdateEvent(ConfigurationEvent.CLEAR);
-    }
-
-    /**
-     * Tests the common base event type for hierarchical update events.
-     */
-    @Test
-    public void testHierarchicalEventType()
-    {
-        checkUpdateEvent(ConfigurationEvent.ANY_HIERARCHICAL);
-    }
-
-    /**
-     * Helper method for checking the relevant properties of a given event type
-     * representing a hierarchical update event.
+     * Helper method for checking the relevant properties of a given event type representing a configuration update event.
      *
      * @param eventType the event type to check
      */
-    private void checkHierarchicalEvent(final EventType<ConfigurationEvent> eventType)
-    {
-        assertSame("Wrong super type for " + eventType,
-                ConfigurationEvent.ANY_HIERARCHICAL, eventType.getSuperType());
+    private void checkUpdateEvent(final EventType<ConfigurationEvent> eventType) {
+        assertSame("Wrong super type for " + eventType, ConfigurationEvent.ANY, eventType.getSuperType());
     }
 
     /**
      * Tests the event type for an add nodes operation.
      */
     @Test
-    public void testAddNodesEventType()
-    {
+    public void testAddNodesEventType() {
         checkHierarchicalEvent(ConfigurationEvent.ADD_NODES);
     }
 
     /**
-     * Tests the event type for a clear tree operation.
+     * Tests the event type for adding a property.
      */
     @Test
-    public void testClearTreeEventType()
-    {
-        checkHierarchicalEvent(ConfigurationEvent.CLEAR_TREE);
-    }
-
-    /**
-     * Tests the event type indicating a change on a sub configuration.
-     */
-    @Test
-    public void testSubnodeChangedEventType()
-    {
-        checkHierarchicalEvent(ConfigurationEvent.SUBNODE_CHANGED);
+    public void testAddPropertyEventType() {
+        checkUpdateEvent(ConfigurationEvent.ADD_PROPERTY);
     }
 
     /**
      * Tests the common base event type for error events.
      */
     @Test
-    public void testBaseErrorEventType()
-    {
-        assertEquals("Wrong super type", Event.ANY,
-                ConfigurationErrorEvent.ANY.getSuperType());
+    public void testBaseErrorEventType() {
+        assertEquals("Wrong super type", Event.ANY, ConfigurationErrorEvent.ANY.getSuperType());
     }
 
     /**
-     * Helper method for checking the relevant properties of an error event
-     * type.
-     *
-     * @param type the type to be checked
+     * Tests the event type for clearing a whole configuration.
      */
-    private void checkErrorEvent(final EventType<ConfigurationErrorEvent> type)
-    {
-        assertSame("Wrong super type for " + type, ConfigurationErrorEvent.ANY,
-                type.getSuperType());
+    @Test
+    public void testClearEventType() {
+        checkUpdateEvent(ConfigurationEvent.CLEAR);
+    }
+
+    /**
+     * Tests the event type for clearing a property.
+     */
+    @Test
+    public void testClearPropertyEventType() {
+        checkUpdateEvent(ConfigurationEvent.CLEAR_PROPERTY);
+    }
+
+    /**
+     * Tests the event type for a clear tree operation.
+     */
+    @Test
+    public void testClearTreeEventType() {
+        checkHierarchicalEvent(ConfigurationEvent.CLEAR_TREE);
+    }
+
+    /**
+     * Tests the base event type for configuration events.
+     */
+    @Test
+    public void testConfigurationEventType() {
+        assertSame("Wrong super type", Event.ANY, ConfigurationEvent.ANY.getSuperType());
+    }
+
+    /**
+     * Tests whether the set of super event types for the base type can be obtained.
+     */
+    @Test
+    public void testFetchSuperEventTypesForBaseType() {
+        final Set<EventType<?>> superTypes = EventType.fetchSuperEventTypes(Event.ANY);
+        assertEquals("Wrong number of super types", 1, superTypes.size());
+        assertTrue("Wrong super types", superTypes.contains(Event.ANY));
+    }
+
+    /**
+     * Tests whether the set of super event types for null input can be obtained.
+     */
+    @Test
+    public void testFetchSuperEventTypesNull() {
+        final Set<EventType<?>> superTypes = EventType.fetchSuperEventTypes(null);
+        assertTrue("Got super types", superTypes.isEmpty());
+    }
+
+    /**
+     * Tests whether the super event types of a specific type can be retrieved.
+     */
+    @Test
+    public void testFetchSuperEventTypesOfType() {
+        final Set<EventType<?>> superTypes = EventType.fetchSuperEventTypes(ConfigurationEvent.ADD_NODES);
+        final List<EventType<? extends Event>> expected = new LinkedList<>();
+        expected.add(ConfigurationEvent.ADD_NODES);
+        expected.add(ConfigurationEvent.ANY_HIERARCHICAL);
+        expected.add(ConfigurationEvent.ANY);
+        expected.add(Event.ANY);
+        assertEquals("Wrong number of super types", expected.size(), superTypes.size());
+        assertTrue("Wrong super types: " + superTypes, superTypes.containsAll(expected));
+    }
+
+    /**
+     * Tests the common base event type for hierarchical update events.
+     */
+    @Test
+    public void testHierarchicalEventType() {
+        checkUpdateEvent(ConfigurationEvent.ANY_HIERARCHICAL);
+    }
+
+    /**
+     * Tests isInstanceOf() if the base type is null.
+     */
+    @Test
+    public void testIsInstanceOfBaseNull() {
+        assertFalse("Wrong result", EventType.isInstanceOf(ConfigurationEvent.ANY, null));
+    }
+
+    /**
+     * Tests isInstanceOf() if the derived type is null.
+     */
+    @Test
+    public void testIsInstanceOfDerivedNull() {
+        assertFalse("Wrong result", EventType.isInstanceOf(null, Event.ANY));
+    }
+
+    /**
+     * Tests isInstanceOf() if there is no instanceof relationship.
+     */
+    @Test
+    public void testIsInstanceOfFalse() {
+        assertFalse("Wrong result", EventType.isInstanceOf(ConfigurationErrorEvent.READ, ConfigurationEvent.ANY));
+    }
+
+    /**
+     * Tests isInstanceOf() if the expected result is true.
+     */
+    @Test
+    public void testIsInstanceOfTrue() {
+        assertTrue("Wrong result (1)", EventType.isInstanceOf(ConfigurationEvent.ADD_NODES, ConfigurationEvent.ANY_HIERARCHICAL));
+        assertTrue("Wrong result (2)", EventType.isInstanceOf(ConfigurationEvent.ADD_NODES, ConfigurationEvent.ANY));
+        assertTrue("Wrong result (3)", EventType.isInstanceOf(ConfigurationEvent.ADD_NODES, Event.ANY));
+        assertTrue("Wrong result (4)", EventType.isInstanceOf(ConfigurationEvent.ADD_NODES, ConfigurationEvent.ADD_NODES));
     }
 
     /**
      * Tests the event type indicating a read error.
      */
     @Test
-    public void testReadErrorEventType()
-    {
+    public void testReadErrorEventType() {
         checkErrorEvent(ConfigurationErrorEvent.READ);
     }
 
+    /**
+     * Tests the event type for setting a property.
+     */
+    @Test
+    public void testSetPropertyEventType() {
+        checkUpdateEvent(ConfigurationEvent.SET_PROPERTY);
+    }
+
+    /**
+     * Tests the event type indicating a change on a sub configuration.
+     */
+    @Test
+    public void testSubnodeChangedEventType() {
+        checkHierarchicalEvent(ConfigurationEvent.SUBNODE_CHANGED);
+    }
+
     /**
      * Tests the event type indicating a write error.
      */
     @Test
-    public void testWriteErrorEventType()
-    {
+    public void testWriteErrorEventType() {
         checkErrorEvent(ConfigurationErrorEvent.WRITE);
     }
 }
