@@ -25,14 +25,12 @@ import org.junit.Test;
  * Test class for {@code EventType}.
  *
  */
-public class TestEventType
-{
+public class TestEventType {
     /** The event type to be tested. */
     private EventType<Event> eventType;
 
     @Before
-    public void setUp() throws Exception
-    {
+    public void setUp() throws Exception {
         eventType = new EventType<>(null, "TEST");
     }
 
@@ -40,8 +38,7 @@ public class TestEventType
      * Tests the string representation.
      */
     @Test
-    public void testToString()
-    {
+    public void testToString() {
         final String s = eventType.toString();
         assertEquals("Wrong string", "EventType [ TEST ]", s);
     }
