@@ -27,14 +27,12 @@ import java.util.Map;
 /**
  * Test class for EnvironmentLookup.
  */
-public class TestEnvironmentLookup
-{
+public class TestEnvironmentLookup {
     /** The lookup to be tested. */
     private Lookup lookup;
 
     @Before
-    public void setUp() throws Exception
-    {
+    public void setUp() throws Exception {
         lookup = DefaultLookups.ENVIRONMENT.getLookup();
     }
 
@@ -42,12 +40,9 @@ public class TestEnvironmentLookup
      * Tests whether environment variables can be queried.
      */
     @Test
-    public void testLookup()
-    {
-        for (final Map.Entry<String, String> e : System.getenv().entrySet())
-        {
-            assertEquals("Wrong value for " + e.getKey(), e.getValue(),
-                    lookup.lookup(e.getKey()));
+    public void testLookup() {
+        for (final Map.Entry<String, String> e : System.getenv().entrySet()) {
+            assertEquals("Wrong value for " + e.getKey(), e.getValue(), lookup.lookup(e.getKey()));
         }
     }
 
@@ -55,9 +50,7 @@ public class TestEnvironmentLookup
      * Tries to lookup a non existing property.
      */
     @Test
-    public void testLookupNonExisting()
-    {
-        assertNull("Got result for non existing environment variable", lookup
-                .lookup("a non existing variable!"));
+    public void testLookupNonExisting() {
+        assertNull("Got result for non existing environment variable", lookup.lookup("a non existing variable!"));
     }
 }
