@@ -41,34 +41,27 @@ import org.junit.Test;
  * Test class for ExprLookup.
  *
  */
-public class TestExprLookup
-{
-    public static class Utility
-    {
+public class TestExprLookup {
+    public static class Utility {
         String message;
 
-        public Utility(final String msg)
-        {
+        public Utility(final String msg) {
             this.message = msg;
         }
 
-        public String getMessage()
-        {
+        public String getMessage() {
             return message;
         }
 
-        public String str(final String str)
-        {
+        public String str(final String str) {
             return str;
         }
     }
 
-    private static String PATTERN1 =
-        "String.replace(Util.message, 'Hello', 'Goodbye') + System.getProperty('user.name')";
-    private static String PATTERN2 =
-        "'$[element] ' + String.trimToEmpty('$[space.description]')";
+    private static final String PATTERN1 = "String.replace(Util.message, 'Hello', 'Goodbye') + System.getProperty('user.name')";
+    private static final String PATTERN2 = "'$[element] ' + String.trimToEmpty('$[space.description]')";
 
-    private static File TEST_FILE = ConfigurationAssert.getTestFile("test.xml");
+    private static final File TEST_FILE = ConfigurationAssert.getTestFile("test.xml");
 
     /**
      * Loads the test configuration.
@@ -76,8 +69,7 @@ public class TestExprLookup
      * @return the test configuration
      * @throws ConfigurationException if an error occurs
      */
-    private static XMLConfiguration loadConfig() throws ConfigurationException
-    {
+    private static XMLConfiguration loadConfig() throws ConfigurationException {
         final XMLConfiguration config = new XMLConfiguration();
         final FileHandler handler = new FileHandler(config);
         handler.load(TEST_FILE);
@@ -88,8 +80,7 @@ public class TestExprLookup
      * Tests whether variables can be queried.
      */
     @Test
-    public void testGetVariables()
-    {
+    public void testGetVariables() {
         final ExprLookup.Variables vars = new ExprLookup.Variables();
         vars.add(new ExprLookup.Variable("String", org.apache.commons.lang3.StringUtils.class));
         final ExprLookup lookup = new ExprLookup(vars);
@@ -100,8 +91,7 @@ public class TestExprLookup
      * Tests that getVariables() returns a copy of the original variables.
      */
     @Test
-    public void testGetVariablesDefensiveCopy()
-    {
+    public void testGetVariablesDefensiveCopy() {
         final ExprLookup.Variables vars = new ExprLookup.Variables();
         vars.add(new ExprLookup.Variable("String", org.apache.commons.lang3.StringUtils.class));
         final ExprLookup lookup = new ExprLookup(vars);
@@ -111,14 +101,13 @@ public class TestExprLookup
     }
 
     @Test
-    public void testLookup() throws Exception
-    {
+    public void testLookup() throws Exception {
         final ConsoleAppender app = new ConsoleAppender(new SimpleLayout());
         final Log log = LogFactory.getLog("TestLogger");
-        final Logger logger = ((Log4JLogger)log).getLogger();
-        logger.addAppender(app);
-        logger.setLevel(Level.DEBUG);
-        logger.setAdditivity(false);
+        //final Logger logger = ((Log4JLogger) log).getLogger();
+        //logger.addAppender(app);
+        //logger.setLevel(Level.DEBUG);
+        //logger.setAdditivity(false);
         final ExprLookup.Variables vars = new ExprLookup.Variables();
         vars.add(new ExprLookup.Variable("String", org.apache.commons.lang3.StringUtils.class));
         vars.add(new ExprLookup.Variable("Util", new Utility("Hello")));
@@ -133,15 +122,41 @@ public class TestExprLookup
         assertTrue(str.startsWith("Goodbye"));
         str = lookup.lookup(PATTERN2);
         assertTrue("Incorrect value: " + str, str.equals("value Some text"));
-        logger.removeAppender(app);
+        //logger.removeAppender(app);
+    }
+
+    @Test
+    public void testLookupLog4j1() throws Exception {
+        final ConsoleAppender app = new ConsoleAppender(new SimpleLayout());
+        final Log log = LogFactory.getLog("TestLogger");
+        if (log instanceof Log4JLogger) {
+            final Logger logger = ((Log4JLogger) log).getLogger();
+            logger.addAppender(app);
+            logger.setLevel(Level.DEBUG);
+            logger.setAdditivity(false);
+            final ExprLookup.Variables vars = new ExprLookup.Variables();
+            vars.add(new ExprLookup.Variable("String", org.apache.commons.lang3.StringUtils.class));
+            vars.add(new ExprLookup.Variable("Util", new Utility("Hello")));
+            vars.add(new ExprLookup.Variable("System", "Class:java.lang.System"));
+            final XMLConfiguration config = loadConfig();
+            final ConfigurationLogger testLogger = new ConfigurationLogger("TestLogger");
+            config.setLogger(testLogger);
+            final ExprLookup lookup = new ExprLookup(vars);
+            lookup.setInterpolator(config.getInterpolator());
+            lookup.setLogger(testLogger);
+            String str = lookup.lookup(PATTERN1);
+            assertTrue(str.startsWith("Goodbye"));
+            str = lookup.lookup(PATTERN2);
+            assertTrue("Incorrect value: " + str, str.equals("value Some text"));
+            logger.removeAppender(app);
+        }
     }
 
     /**
      * Tests a lookup() operation if no ConfigurationInterpolator object has been set.
      */
     @Test
-    public void testLookupNoConfigurationInterpolator()
-    {
+    public void testLookupNoConfigurationInterpolator() {
         final ExprLookup.Variables vars = new ExprLookup.Variables();
         vars.add(new ExprLookup.Variable("String", org.apache.commons.lang3.StringUtils.class));
         final ExprLookup lookup = new ExprLookup(vars);
@@ -153,8 +168,7 @@ public class TestExprLookup
      * Tests an expression that does not yield a string.
      */
     @Test
-    public void testLookupNonStringExpression() throws ConfigurationException
-    {
+    public void testLookupNonStringExpression() throws ConfigurationException {
         final ExprLookup.Variables vars = new ExprLookup.Variables();
         vars.add(new ExprLookup.Variable("System", "Class:java.lang.System"));
         final ExprLookup lookup = new ExprLookup(vars);
@@ -169,14 +183,12 @@ public class TestExprLookup
      * Tests an expression that yields a null value.
      */
     @Test
-    public void testLookupNullExpression() throws ConfigurationException
-    {
+    public void testLookupNullExpression() throws ConfigurationException {
         final ExprLookup.Variables vars = new ExprLookup.Variables();
         vars.add(new ExprLookup.Variable("System", "Class:java.lang.System"));
         final ExprLookup lookup = new ExprLookup(vars);
         final XMLConfiguration config = loadConfig();
         lookup.setInterpolator(config.getInterpolator());
-        assertNull("Wrong result",
-                lookup.lookup("System.getProperty('undefined.property')"));
+        assertNull("Wrong result", lookup.lookup("System.getProperty('undefined.property')"));
     }
 }
