@@ -31,8 +31,7 @@ import org.junit.Test;
  * Test class for {@code AbsoluteNameLocationStrategy}.
  *
  */
-public class TestAbsoluteNameLocationStrategy
-{
+public class TestAbsoluteNameLocationStrategy {
     /** A mock for the file system. */
     private FileSystem fileSystem;
 
@@ -40,60 +39,48 @@ public class TestAbsoluteNameLocationStrategy
     private AbsoluteNameLocationStrategy strategy;
 
     @Before
-    public void setUp() throws Exception
-    {
+    public void setUp() throws Exception {
         fileSystem = EasyMock.createMock(FileSystem.class);
         EasyMock.replay(fileSystem);
         strategy = new AbsoluteNameLocationStrategy();
     }
 
     /**
-     * Tests a locate() operation if no file name is provided.
+     * Tests a successful locate() operation.
      */
     @Test
-    public void testNoFileName()
-    {
-        final FileLocator locator = FileLocatorUtils.fileLocator().create();
-        assertNull("Got a URL", strategy.locate(fileSystem, locator));
+    public void testExistingAbsoluteFile() {
+        final File file = ConfigurationAssert.getTestFile("test.xml");
+        final FileLocator locator = FileLocatorUtils.fileLocator().fileName(file.getAbsolutePath()).create();
+        final URL url = strategy.locate(fileSystem, locator);
+        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils.fileFromURL(url).getAbsoluteFile());
     }
 
     /**
      * Tests a locate() operation if no absolute file name is provided.
      */
     @Test
-    public void testNoAbsoluteFileName()
-    {
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().fileName("test.xml").create();
+    public void testNoAbsoluteFileName() {
+        final FileLocator locator = FileLocatorUtils.fileLocator().fileName("test.xml").create();
         assertNull("Got a URL", strategy.locate(fileSystem, locator));
     }
 
     /**
-     * Tests a locate() operation if an absolute file name is provided, but this
-     * file does not exist.
+     * Tests a locate() operation if no file name is provided.
      */
     @Test
-    public void testNonExistingAbsoluteFile()
-    {
+    public void testNoFileName() {
+        final FileLocator locator = FileLocatorUtils.fileLocator().create();
+        assertNull("Got a URL", strategy.locate(fileSystem, locator));
+    }
+
+    /**
+     * Tests a locate() operation if an absolute file name is provided, but this file does not exist.
+     */
+    @Test
+    public void testNonExistingAbsoluteFile() {
         final File file = ConfigurationAssert.getOutFile("NotExistingFile.tst");
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().fileName(file.getAbsolutePath())
-                        .create();
+        final FileLocator locator = FileLocatorUtils.fileLocator().fileName(file.getAbsolutePath()).create();
         assertNull("Got a URL", strategy.locate(fileSystem, locator));
     }
-
-    /**
-     * Tests a successful locate() operation.
-     */
-    @Test
-    public void testExistingAbsoluteFile()
-    {
-        final File file = ConfigurationAssert.getTestFile("test.xml");
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().fileName(file.getAbsolutePath())
-                        .create();
-        final URL url = strategy.locate(fileSystem, locator);
-        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils
-                .fileFromURL(url).getAbsoluteFile());
-    }
 }
