@@ -34,27 +34,46 @@ import org.junit.Test;
  * Test class for {@code CombinedLocationStrategy}.
  *
  */
-public class TestCombinedLocationStrategy
-{
+public class TestCombinedLocationStrategy {
     /** A test locator. */
     private static FileLocator locator;
 
     /** A URL indicating a successful locate() operation. */
     private static URL locateURL;
 
+    @BeforeClass
+    public static void setUpOnce() throws Exception {
+        locator = FileLocatorUtils.fileLocator().fileName("testFile.tst").create();
+        locateURL = ConfigurationAssert.getTestURL("test.xml");
+    }
+
     /** A mock for the file system. */
     private FileSystem fileSystem;
 
     /** An array with mock sub strategies. */
     private FileLocationStrategy[] subStrategies;
 
-    @BeforeClass
-    public static void setUpOnce() throws Exception
-    {
-        locator =
-                FileLocatorUtils.fileLocator().fileName("testFile.tst")
-                        .create();
-        locateURL = ConfigurationAssert.getTestURL("test.xml");
+    /**
+     * Checks whether the passed in combined strategy contains the expected sub strategies.
+     *
+     * @param strategy the combined strategy to check
+     */
+    private void checkSubStrategies(final CombinedLocationStrategy strategy) {
+        final Collection<FileLocationStrategy> subs = strategy.getSubStrategies();
+        assertEquals("Wrong number of strategies", getSubStrategies().length, subs.size());
+        int idx = 0;
+        for (final FileLocationStrategy strat : subs) {
+            assertEquals("Wrong sub strategy at " + idx, getSubStrategies()[idx++], strat);
+        }
+    }
+
+    /**
+     * Helper method for creating a combined strategy with the mock sub strategies.
+     *
+     * @return the newly created combined strategy
+     */
+    private CombinedLocationStrategy createCombinedStrategy() {
+        return new CombinedLocationStrategy(Arrays.asList(getSubStrategies()));
     }
 
     /**
@@ -62,10 +81,8 @@ public class TestCombinedLocationStrategy
      *
      * @return the mock file system
      */
-    private FileSystem getFileSystem()
-    {
-        if (fileSystem == null)
-        {
+    private FileSystem getFileSystem() {
+        if (fileSystem == null) {
             fileSystem = EasyMock.createMock(FileSystem.class);
             EasyMock.replay(fileSystem);
         }
@@ -77,15 +94,11 @@ public class TestCombinedLocationStrategy
      *
      * @return the array with mock strategies
      */
-    private FileLocationStrategy[] getSubStrategies()
-    {
-        if (subStrategies == null)
-        {
+    private FileLocationStrategy[] getSubStrategies() {
+        if (subStrategies == null) {
             subStrategies = new FileLocationStrategy[2];
-            for (int i = 0; i < subStrategies.length; i++)
-            {
-                subStrategies[i] =
-                        EasyMock.createMock(FileLocationStrategy.class);
+            for (int i = 0; i < subStrategies.length; i++) {
+                subStrategies[i] = EasyMock.createMock(FileLocationStrategy.class);
             }
         }
         return subStrategies;
@@ -94,143 +107,90 @@ public class TestCombinedLocationStrategy
     /**
      * Replays the mock objects for the sub strategies.
      */
-    private void replaySubStrategies()
-    {
+    private void replaySubStrategies() {
         EasyMock.replay((Object[]) getSubStrategies());
     }
 
-    /**
-     * Verifies the mock objects for the sub strategies.
-     */
-    private void verifySubStrategies()
-    {
-        EasyMock.verify((Object[]) getSubStrategies());
-    }
-
-    /**
-     * Checks whether the passed in combined strategy contains the expected sub
-     * strategies.
-     *
-     * @param strategy the combined strategy to check
-     */
-    private void checkSubStrategies(final CombinedLocationStrategy strategy)
-    {
-        final Collection<FileLocationStrategy> subs = strategy.getSubStrategies();
-        assertEquals("Wrong number of strategies", getSubStrategies().length,
-                subs.size());
-        int idx = 0;
-        for (final FileLocationStrategy strat : subs)
-        {
-            assertEquals("Wrong sub strategy at " + idx,
-                    getSubStrategies()[idx++], strat);
-        }
-    }
-
-    /**
-     * Helper method for creating a combined strategy with the mock sub
-     * strategies.
-     *
-     * @return the newly created combined strategy
-     */
-    private CombinedLocationStrategy createCombinedStrategy()
-    {
-        return new CombinedLocationStrategy(Arrays.asList(getSubStrategies()));
-    }
-
-    /**
-     * Tries to create an instance with a null collection.
-     */
-    @Test(expected = IllegalArgumentException.class)
-    public void testInitNullCollection()
-    {
-        new CombinedLocationStrategy(null);
-    }
-
-    /**
-     * Tries to create an instance containing a null element.
-     */
-    @Test(expected = IllegalArgumentException.class)
-    public void testInitCollectionWithNullEntries()
-    {
-        final Collection<FileLocationStrategy> col =
-                new LinkedList<>(
-                        Arrays.asList(getSubStrategies()));
-        col.add(null);
-        new CombinedLocationStrategy(col);
-    }
-
-    /**
-     * Tests whether a defensive copy of the collection with sub strategies is
-     * made.
-     */
-    @Test
-    public void testInitDefensiveCopy()
-    {
-        final Collection<FileLocationStrategy> col =
-                new LinkedList<>(
-                        Arrays.asList(getSubStrategies()));
-        final CombinedLocationStrategy strategy = new CombinedLocationStrategy(col);
-        col.add(EasyMock.createMock(FileLocationStrategy.class));
-        checkSubStrategies(strategy);
-    }
-
     /**
      * Tests that the collection with sub strategies cannot be modified.
      */
     @Test(expected = UnsupportedOperationException.class)
-    public void testGetSubStrategiesModify()
-    {
+    public void testGetSubStrategiesModify() {
         final CombinedLocationStrategy strategy = createCombinedStrategy();
         strategy.getSubStrategies().clear();
     }
 
     /**
-     * Tests a successful locate() operation if the first sub strategy can
-     * locate the file.
+     * Tries to create an instance containing a null element.
      */
-    @Test
-    public void testLocateSuccessFirstSubStrategy()
-    {
-        EasyMock.expect(getSubStrategies()[0].locate(getFileSystem(), locator))
-                .andReturn(locateURL);
-        replaySubStrategies();
-        final CombinedLocationStrategy strategy = createCombinedStrategy();
-        assertSame("Wrong result", locateURL,
-                strategy.locate(getFileSystem(), locator));
-        verifySubStrategies();
+    @Test(expected = IllegalArgumentException.class)
+    public void testInitCollectionWithNullEntries() {
+        final Collection<FileLocationStrategy> col = new LinkedList<>(Arrays.asList(getSubStrategies()));
+        col.add(null);
+        new CombinedLocationStrategy(col);
     }
 
     /**
-     * Tests a successful locate() operation if the 2nd sub strategy can locate
-     * the file.
+     * Tests whether a defensive copy of the collection with sub strategies is made.
      */
     @Test
-    public void testLocateSuccessSecondSubStrategy()
-    {
-        EasyMock.expect(getSubStrategies()[0].locate(getFileSystem(), locator))
-                .andReturn(null);
-        EasyMock.expect(getSubStrategies()[1].locate(getFileSystem(), locator))
-                .andReturn(locateURL);
-        replaySubStrategies();
-        final CombinedLocationStrategy strategy = createCombinedStrategy();
-        assertSame("Wrong result", locateURL,
-                strategy.locate(getFileSystem(), locator));
-        verifySubStrategies();
+    public void testInitDefensiveCopy() {
+        final Collection<FileLocationStrategy> col = new LinkedList<>(Arrays.asList(getSubStrategies()));
+        final CombinedLocationStrategy strategy = new CombinedLocationStrategy(col);
+        col.add(EasyMock.createMock(FileLocationStrategy.class));
+        checkSubStrategies(strategy);
+    }
+
+    /**
+     * Tries to create an instance with a null collection.
+     */
+    @Test(expected = IllegalArgumentException.class)
+    public void testInitNullCollection() {
+        new CombinedLocationStrategy(null);
     }
 
     /**
      * Tests a failed locate() operation.
      */
     @Test
-    public void testLocateFailed()
-    {
-        EasyMock.expect(getSubStrategies()[0].locate(getFileSystem(), locator))
-                .andReturn(null);
-        EasyMock.expect(getSubStrategies()[1].locate(getFileSystem(), locator))
-                .andReturn(null);
+    public void testLocateFailed() {
+        EasyMock.expect(getSubStrategies()[0].locate(getFileSystem(), locator)).andReturn(null);
+        EasyMock.expect(getSubStrategies()[1].locate(getFileSystem(), locator)).andReturn(null);
         replaySubStrategies();
         final CombinedLocationStrategy strategy = createCombinedStrategy();
         assertNull("Got a URL", strategy.locate(getFileSystem(), locator));
         verifySubStrategies();
     }
+
+    /**
+     * Tests a successful locate() operation if the first sub strategy can locate the file.
+     */
+    @Test
+    public void testLocateSuccessFirstSubStrategy() {
+        EasyMock.expect(getSubStrategies()[0].locate(getFileSystem(), locator)).andReturn(locateURL);
+        replaySubStrategies();
+        final CombinedLocationStrategy strategy = createCombinedStrategy();
+        assertSame("Wrong result", locateURL, strategy.locate(getFileSystem(), locator));
+        verifySubStrategies();
+    }
+
+    /**
+     * Tests a successful locate() operation if the 2nd sub strategy can locate the file.
+     */
+    @Test
+    public void testLocateSuccessSecondSubStrategy() {
+        EasyMock.expect(getSubStrategies()[0].locate(getFileSystem(), locator)).andReturn(null);
+        EasyMock.expect(getSubStrategies()[1].locate(getFileSystem(), locator)).andReturn(locateURL);
+        replaySubStrategies();
+        final CombinedLocationStrategy strategy = createCombinedStrategy();
+        assertSame("Wrong result", locateURL, strategy.locate(getFileSystem(), locator));
+        verifySubStrategies();
+    }
+
+    /**
+     * Verifies the mock objects for the sub strategies.
+     */
+    private void verifySubStrategies() {
+        EasyMock.verify((Object[]) getSubStrategies());
+    }
 }
