@@ -18,7 +18,7 @@ package org.apache.commons.configuration2.io;
 
 import static org.hamcrest.CoreMatchers.containsString;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertThat;
@@ -34,8 +34,7 @@ import org.junit.Test;
  * Test class for {@code FileLocator}.
  *
  */
-public class TestFileLocator
-{
+public class TestFileLocator {
     /** Constant for a file name. */
     private static final String FILE_NAME = "test.xml";
 
@@ -54,21 +53,54 @@ public class TestFileLocator
     /** A test location strategy. */
     private static FileLocationStrategy locationStrategy;
 
+    /**
+     * Tests whether a locator has the expected properties.
+     *
+     * @param locator the locator to check
+     */
+    private static void checkLocator(final FileLocator locator) {
+        assertEquals("Wrong base path", BASE_PATH, locator.getBasePath());
+        assertEquals("Wrong file name", FILE_NAME, locator.getFileName());
+        assertEquals("Wrong encoding", ENCODING, locator.getEncoding());
+        assertEquals("Wrong URL", sourceURL.toExternalForm(), locator.getSourceURL().toExternalForm());
+        assertSame("Wrong file system", fileSystem, locator.getFileSystem());
+        assertSame("Wrong location strategy", locationStrategy, locator.getLocationStrategy());
+    }
+
     @BeforeClass
-    public static void setUpOnce() throws Exception
-    {
+    public static void setUpOnce() throws Exception {
         sourceURL = ConfigurationAssert.getTestURL(FILE_NAME);
         fileSystem = EasyMock.createMock(FileSystem.class);
         locationStrategy = EasyMock.createMock(FileLocationStrategy.class);
         EasyMock.replay(fileSystem, locationStrategy);
     }
 
+    /**
+     * Tests the creation of a file locator.
+     */
+    @Test
+    public void testCreateFileLocator() {
+        final FileLocator locator = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).encoding(ENCODING).fileSystem(fileSystem)
+            .sourceURL(sourceURL).locationStrategy(locationStrategy).create();
+        checkLocator(locator);
+    }
+
+    /**
+     * Tests whether a file locator can be created from a source locator.
+     */
+    @Test
+    public void testCreateFileLocatorFromSource() {
+        final FileLocator locatorSrc = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName("someFile").encoding(ENCODING).fileSystem(fileSystem)
+            .sourceURL(sourceURL).locationStrategy(locationStrategy).create();
+        final FileLocator locator = FileLocatorUtils.fileLocator(locatorSrc).fileName(FILE_NAME).create();
+        checkLocator(locator);
+    }
+
     /**
      * Tests whether an undefined file locator can be created.
      */
     @Test
-    public void testCreateFileLocatorUndefined()
-    {
+    public void testCreateFileLocatorUndefined() {
         final FileLocator locator = FileLocatorUtils.fileLocator().create();
         assertNull("Got a base path", locator.getBasePath());
         assertNull("Got a file name", locator.getFileName());
@@ -79,120 +111,23 @@ public class TestFileLocator
     }
 
     /**
-     * Tests whether a locator has the expected properties.
-     *
-     * @param locator the locator to check
-     */
-    private static void checkLocator(final FileLocator locator)
-    {
-        assertEquals("Wrong base path", BASE_PATH, locator.getBasePath());
-        assertEquals("Wrong file name", FILE_NAME, locator.getFileName());
-        assertEquals("Wrong encoding", ENCODING, locator.getEncoding());
-        assertEquals("Wrong URL", sourceURL.toExternalForm(), locator
-                .getSourceURL().toExternalForm());
-        assertSame("Wrong file system", fileSystem, locator.getFileSystem());
-        assertSame("Wrong location strategy", locationStrategy,
-                locator.getLocationStrategy());
-    }
-
-    /**
-     * Tests the creation of a file locator.
+     * Tests the equals() implementation of FileLocator if the expected result is false.
      */
     @Test
-    public void testCreateFileLocator()
-    {
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).encoding(ENCODING)
-                        .fileSystem(fileSystem).sourceURL(sourceURL)
-                        .locationStrategy(locationStrategy).create();
-        checkLocator(locator);
-    }
-
-    /**
-     * Tests whether a file locator can be created from a source locator.
-     */
-    @Test
-    public void testCreateFileLocatorFromSource()
-    {
-        final FileLocator locatorSrc =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName("someFile").encoding(ENCODING)
-                        .fileSystem(fileSystem).sourceURL(sourceURL)
-                        .locationStrategy(locationStrategy).create();
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator(locatorSrc).fileName(FILE_NAME)
-                        .create();
-        checkLocator(locator);
-    }
-
-    /**
-     * Tests the equals() implementation of FileLocator if the expected result
-     * is true.
-     */
-    @Test
-    public void testFileLocatorEqualsTrue()
-    {
-        FileLocator loc1 = FileLocatorUtils.fileLocator().create();
-        ConfigurationAssert.checkEquals(loc1, loc1, true);
-        FileLocator loc2 = FileLocatorUtils.fileLocator().create();
-        ConfigurationAssert.checkEquals(loc1, loc2, true);
-        loc1 =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).encoding(ENCODING)
-                        .fileSystem(fileSystem).sourceURL(sourceURL)
-                        .locationStrategy(locationStrategy).create();
-        loc2 =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).encoding(ENCODING)
-                        .fileSystem(fileSystem).sourceURL(sourceURL)
-                        .locationStrategy(locationStrategy).create();
-        ConfigurationAssert.checkEquals(loc1, loc2, true);
-    }
-
-    /**
-     * Tests the equals() implementation of FileLocator if the expected result
-     * is false.
-     */
-    @Test
-    public void testFileLocatorEqualsFalse()
-    {
-        final FileLocator loc1 =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).encoding(ENCODING)
-                        .fileSystem(fileSystem).sourceURL(sourceURL)
-                        .locationStrategy(locationStrategy).create();
-        FileLocator loc2 =
-                FileLocatorUtils.fileLocator(loc1)
-                        .basePath(BASE_PATH + "_other").create();
+    public void testFileLocatorEqualsFalse() {
+        final FileLocator loc1 = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).encoding(ENCODING).fileSystem(fileSystem)
+            .sourceURL(sourceURL).locationStrategy(locationStrategy).create();
+        FileLocator loc2 = FileLocatorUtils.fileLocator(loc1).basePath(BASE_PATH + "_other").create();
         ConfigurationAssert.checkEquals(loc1, loc2, false);
-        loc2 =
-                FileLocatorUtils.fileLocator(loc1)
-                        .fileName(FILE_NAME + "_other").create();
+        loc2 = FileLocatorUtils.fileLocator(loc1).fileName(FILE_NAME + "_other").create();
         ConfigurationAssert.checkEquals(loc1, loc2, false);
-        loc2 =
-                FileLocatorUtils.fileLocator(loc1)
-                        .encoding(ENCODING + "_other").create();
+        loc2 = FileLocatorUtils.fileLocator(loc1).encoding(ENCODING + "_other").create();
         ConfigurationAssert.checkEquals(loc1, loc2, false);
-        loc2 =
-                FileLocatorUtils.fileLocator(loc1)
-                        .fileSystem(EasyMock.createMock(FileSystem.class))
-                        .create();
+        loc2 = FileLocatorUtils.fileLocator(loc1).fileSystem(EasyMock.createMock(FileSystem.class)).create();
         ConfigurationAssert.checkEquals(loc1, loc2, false);
-        loc2 =
-                FileLocatorUtils
-                        .fileLocator(loc1)
-                        .sourceURL(
-                                ConfigurationAssert
-                                        .getTestURL("test.properties"))
-                        .create();
+        loc2 = FileLocatorUtils.fileLocator(loc1).sourceURL(ConfigurationAssert.getTestURL("test.properties")).create();
         ConfigurationAssert.checkEquals(loc1, loc2, false);
-        loc2 =
-                FileLocatorUtils
-                        .fileLocator(loc1)
-                        .locationStrategy(
-                                EasyMock.createMock(FileLocationStrategy.class))
-                        .create();
+        loc2 = FileLocatorUtils.fileLocator(loc1).locationStrategy(EasyMock.createMock(FileLocationStrategy.class)).create();
         ConfigurationAssert.checkEquals(loc1, loc2, false);
     }
 
@@ -200,35 +135,43 @@ public class TestFileLocator
      * Tests equals() with a null object.
      */
     @Test
-    public void testFileLocatorEqualsNull()
-    {
-        final FileLocator loc =
-                FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
-        assertFalse("Wrong result", loc.equals(null));
+    public void testFileLocatorEqualsNull() {
+        final FileLocator loc = FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
+        assertNotEquals("Wrong result", null, loc);
     }
 
     /**
      * Tests equals() with an object from another class.
      */
     @Test
-    public void testFileLocatorEqualsOtherClass()
-    {
-        final FileLocator loc =
-                FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
-        assertFalse("Wrong result", loc.equals(this));
+    public void testFileLocatorEqualsOtherClass() {
+        final FileLocator loc = FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
+        assertNotEquals("Wrong result", loc, this);
+    }
+
+    /**
+     * Tests the equals() implementation of FileLocator if the expected result is true.
+     */
+    @Test
+    public void testFileLocatorEqualsTrue() {
+        FileLocator loc1 = FileLocatorUtils.fileLocator().create();
+        ConfigurationAssert.checkEquals(loc1, loc1, true);
+        FileLocator loc2 = FileLocatorUtils.fileLocator().create();
+        ConfigurationAssert.checkEquals(loc1, loc2, true);
+        loc1 = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).encoding(ENCODING).fileSystem(fileSystem).sourceURL(sourceURL)
+            .locationStrategy(locationStrategy).create();
+        loc2 = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).encoding(ENCODING).fileSystem(fileSystem).sourceURL(sourceURL)
+            .locationStrategy(locationStrategy).create();
+        ConfigurationAssert.checkEquals(loc1, loc2, true);
     }
 
     /**
      * Tests the string representation of a locator.
      */
     @Test
-    public void testFileLocatorToString()
-    {
-        final FileLocator loc =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).encoding(ENCODING)
-                        .fileSystem(fileSystem).sourceURL(sourceURL)
-                        .locationStrategy(locationStrategy).create();
+    public void testFileLocatorToString() {
+        final FileLocator loc = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).encoding(ENCODING).fileSystem(fileSystem)
+            .sourceURL(sourceURL).locationStrategy(locationStrategy).create();
         final String s = loc.toString();
         assertThat(s, containsString("fileName=" + FILE_NAME));
         assertThat(s, containsString("basePath=" + BASE_PATH));
