@@ -35,8 +35,7 @@ import org.junit.rules.TemporaryFolder;
  * Test class for {@code HomeDirectoryLocationStrategy}.
  *
  */
-public class TestHomeDirectoryLocationStrategy
-{
+public class TestHomeDirectoryLocationStrategy {
     /** Constant for a test file name. */
     private static final String FILE_NAME = "test.tst";
 
@@ -51,110 +50,86 @@ public class TestHomeDirectoryLocationStrategy
     private FileSystem fileSystem;
 
     @Before
-    public void setUp() throws Exception
-    {
+    public void setUp() throws Exception {
         fileSystem = EasyMock.createMock(FileSystem.class);
         EasyMock.replay(fileSystem);
     }
 
     /**
-     * Creates a strategy test object which uses the temporary root directory as
-     * its home directory.
+     * Creates a strategy test object which uses the temporary root directory as its home directory.
      *
      * @param withBasePath the base path flag
      * @return the test strategy
      */
-    private HomeDirectoryLocationStrategy setUpStrategy(final boolean withBasePath)
-    {
-        return new HomeDirectoryLocationStrategy(folder.getRoot()
-                .getAbsolutePath(), withBasePath);
+    private HomeDirectoryLocationStrategy setUpStrategy(final boolean withBasePath) {
+        return new HomeDirectoryLocationStrategy(folder.getRoot().getAbsolutePath(), withBasePath);
     }
 
     /**
      * Tests whether default values are correctly set by the constructor.
      */
     @Test
-    public void testInitDefaults()
-    {
-        final HomeDirectoryLocationStrategy strategy =
-                new HomeDirectoryLocationStrategy();
-        assertEquals("Wrong home directory", System.getProperty("user.home"),
-                strategy.getHomeDirectory());
+    public void testInitDefaults() {
+        final HomeDirectoryLocationStrategy strategy = new HomeDirectoryLocationStrategy();
+        assertEquals("Wrong home directory", System.getProperty("user.home"), strategy.getHomeDirectory());
         assertFalse("Wrong base path flag", strategy.isEvaluateBasePath());
     }
 
-    /**
-     * Tests whether a file can be located if the base path is ignored.
-     */
-    @Test
-    public void testLocateSuccessIgnoreBasePath() throws IOException
-    {
-        final File file = folder.newFile(FILE_NAME);
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).create();
-        final HomeDirectoryLocationStrategy strategy = setUpStrategy(false);
-        final URL url = strategy.locate(fileSystem, locator);
-        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils
-                .fileFromURL(url).getAbsoluteFile());
-    }
-
     /**
      * Tests whether the base is actually evaluated if the flag is set.
      */
     @Test
-    public void testLocateFailedWithBasePath() throws IOException
-    {
+    public void testLocateFailedWithBasePath() throws IOException {
         folder.newFile(FILE_NAME);
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).create();
+        final FileLocator locator = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).create();
         final HomeDirectoryLocationStrategy strategy = setUpStrategy(true);
         assertNull("Got a URL", strategy.locate(fileSystem, locator));
     }
 
+    /**
+     * Tests whether a file can be located if the base path is ignored.
+     */
+    @Test
+    public void testLocateSuccessIgnoreBasePath() throws IOException {
+        final File file = folder.newFile(FILE_NAME);
+        final FileLocator locator = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).create();
+        final HomeDirectoryLocationStrategy strategy = setUpStrategy(false);
+        final URL url = strategy.locate(fileSystem, locator);
+        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils.fileFromURL(url).getAbsoluteFile());
+    }
+
     /**
      * Tests whether a file in a sub folder can be located.
      */
     @Test
-    public void testLocateSuccessInSubFolder() throws IOException
-    {
+    public void testLocateSuccessInSubFolder() throws IOException {
         final File sub = folder.newFolder(BASE_PATH);
         final File file = new File(sub, FILE_NAME);
         assertTrue("Could not create file", file.createNewFile());
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH)
-                        .fileName(FILE_NAME).create();
+        final FileLocator locator = FileLocatorUtils.fileLocator().basePath(BASE_PATH).fileName(FILE_NAME).create();
         final HomeDirectoryLocationStrategy strategy = setUpStrategy(true);
         final URL url = strategy.locate(fileSystem, locator);
-        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils
-                .fileFromURL(url).getAbsoluteFile());
+        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils.fileFromURL(url).getAbsoluteFile());
     }
 
     /**
-     * Tests a locate() operation which evaluates the base path if no base path
-     * is set.
+     * Tests a locate() operation which evaluates the base path if no base path is set.
      */
     @Test
-    public void testLocateSuccessNoBasePath() throws IOException
-    {
+    public void testLocateSuccessNoBasePath() throws IOException {
         final File file = folder.newFile(FILE_NAME);
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
+        final FileLocator locator = FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
         final HomeDirectoryLocationStrategy strategy = setUpStrategy(true);
         final URL url = strategy.locate(fileSystem, locator);
-        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils
-                .fileFromURL(url).getAbsoluteFile());
+        assertEquals("Wrong URL", file.getAbsoluteFile(), FileLocatorUtils.fileFromURL(url).getAbsoluteFile());
     }
 
     /**
      * Tests a locate() operation if no file name is specified.
      */
     @Test
-    public void testNoFileName()
-    {
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().basePath(BASE_PATH).create();
+    public void testNoFileName() {
+        final FileLocator locator = FileLocatorUtils.fileLocator().basePath(BASE_PATH).create();
         final HomeDirectoryLocationStrategy strategy = setUpStrategy(true);
         assertNull("Got a URL", strategy.locate(fileSystem, locator));
     }
