@@ -30,42 +30,35 @@ import org.junit.Test;
  * Test class for {@code ProvidedURLLocationStrategy}.
  *
  */
-public class TestProvidedURLLocationStrategy
-{
+public class TestProvidedURLLocationStrategy {
     /** The strategy to be tested. */
     private ProvidedURLLocationStrategy strategy;
 
     @Before
-    public void setUp() throws Exception
-    {
+    public void setUp() throws Exception {
         strategy = new ProvidedURLLocationStrategy();
     }
 
-    /**
-     * Tests a successful locate() operation.
-     */
-    @Test
-    public void testLocateSuccess()
-    {
-        final FileSystem fs = EasyMock.createMock(FileSystem.class);
-        EasyMock.replay(fs);
-        final URL url = ConfigurationAssert.getTestURL("test.xml");
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().sourceURL(url).create();
-        assertSame("Wrong URL", url, strategy.locate(fs, locator));
-    }
-
     /**
      * Tests a failed locate() operation.
      */
     @Test
-    public void testLocateFail()
-    {
+    public void testLocateFail() {
         final FileSystem fs = EasyMock.createMock(FileSystem.class);
         EasyMock.replay(fs);
-        final FileLocator locator =
-                FileLocatorUtils.fileLocator().basePath("somePath")
-                        .fileName("someFile.xml").create();
+        final FileLocator locator = FileLocatorUtils.fileLocator().basePath("somePath").fileName("someFile.xml").create();
         assertNull("Got a URL", strategy.locate(fs, locator));
     }
+
+    /**
+     * Tests a successful locate() operation.
+     */
+    @Test
+    public void testLocateSuccess() {
+        final FileSystem fs = EasyMock.createMock(FileSystem.class);
+        EasyMock.replay(fs);
+        final URL url = ConfigurationAssert.getTestURL("test.xml");
+        final FileLocator locator = FileLocatorUtils.fileLocator().sourceURL(url).create();
+        assertSame("Wrong URL", url, strategy.locate(fs, locator));
+    }
 }
