@@ -32,70 +32,36 @@ import org.junit.Test;
  * Test class for {@code ReloadingController}.
  *
  */
-public class TestReloadingController
-{
+public class TestReloadingController {
+    /**
+     * Creates a mock event listener.
+     *
+     * @return the mock listener
+     */
+    private static EventListener<ReloadingEvent> createListenerMock() {
+        return EasyMock.createMock(EventListener.class);
+    }
+
     /** A mock for the detector. */
     private ReloadingDetector detector;
 
-    @Before
-    public void setUp() throws Exception
-    {
-        detector = EasyMock.createMock(ReloadingDetector.class);
-    }
-
     /**
      * Creates a default test instance.
      *
      * @return the test instance
      */
-    private ReloadingController createController()
-    {
+    private ReloadingController createController() {
         return new ReloadingController(detector);
     }
 
     /**
-     * Tries to create an instance without a detector.
-     */
-    @Test(expected = IllegalArgumentException.class)
-    public void testInitNoDetector()
-    {
-        new ReloadingController(null);
-    }
-
-    /**
-     * Tests that a newly created instance is not in reloading state.
-     */
-    @Test
-    public void testReloadingStateAfterInit()
-    {
-        assertFalse("In reloading state", createController()
-                .isInReloadingState());
-    }
-
-    /**
-     * Creates a mock event listener.
-     *
-     * @return the mock listener
-     */
-    private static EventListener<ReloadingEvent> createListenerMock()
-    {
-        @SuppressWarnings("unchecked")
-        final
-        EventListener<ReloadingEvent> listener =
-                EasyMock.createMock(EventListener.class);
-        return listener;
-    }
-
-    /**
-     * Prepares the given event listener mock to expect an event notification.
-     * The event received is stored in the given mutable object.
+     * Prepares the given event listener mock to expect an event notification. The event received is stored in the given
+     * mutable object.
      *
      * @param l the listener mock
      * @param evRef the reference where to store the event
      */
-    private void expectEvent(final EventListener<ReloadingEvent> l,
-            final MutableObject<ReloadingEvent> evRef)
-    {
+    private void expectEvent(final EventListener<ReloadingEvent> l, final MutableObject<ReloadingEvent> evRef) {
         l.onEvent(EasyMock.anyObject(ReloadingEvent.class));
         EasyMock.expectLastCall().andAnswer(() -> {
             evRef.setValue((ReloadingEvent) EasyMock.getCurrentArguments()[0]);
@@ -103,12 +69,47 @@ public class TestReloadingController
         });
     }
 
+    @Before
+    public void setUp() throws Exception {
+        detector = EasyMock.createMock(ReloadingDetector.class);
+    }
+
+    /**
+     * Tests a reloading check with a negative result.
+     */
+    @Test
+    public void testCheckForReloadingFalse() {
+        final EventListener<ReloadingEvent> l = createListenerMock();
+        EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.FALSE);
+        EasyMock.replay(detector, l);
+        final ReloadingController ctrl = createController();
+        ctrl.addEventListener(ReloadingEvent.ANY, l);
+        assertFalse("Wrong result", ctrl.checkForReloading(null));
+        assertFalse("In reloading state", ctrl.isInReloadingState());
+        EasyMock.verify(detector, l);
+    }
+
+    /**
+     * Tests that no further checks are performed when already in reloading state.
+     */
+    @Test
+    public void testCheckForReloadingInReloadingState() {
+        final EventListener<ReloadingEvent> l = createListenerMock();
+        EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.TRUE);
+        expectEvent(l, new MutableObject<>());
+        EasyMock.replay(detector, l);
+        final ReloadingController ctrl = createController();
+        ctrl.addEventListener(ReloadingEvent.ANY, l);
+        assertTrue("Wrong result (1)", ctrl.checkForReloading(1));
+        assertTrue("Wrong result (2)", ctrl.checkForReloading(2));
+        EasyMock.verify(detector, l);
+    }
+
     /**
      * Tests a reloading check with a positive result.
      */
     @Test
-    public void testCheckForReloadingTrue()
-    {
+    public void testCheckForReloadingTrue() {
         final EventListener<ReloadingEvent> l = createListenerMock();
         final EventListener<ReloadingEvent> lRemoved = createListenerMock();
         final MutableObject<ReloadingEvent> evRef = new MutableObject<>();
@@ -118,8 +119,7 @@ public class TestReloadingController
         final ReloadingController ctrl = createController();
         ctrl.addEventListener(ReloadingEvent.ANY, lRemoved);
         ctrl.addEventListener(ReloadingEvent.ANY, l);
-        assertTrue("Wrong result",
-                ctrl.removeEventListener(ReloadingEvent.ANY, lRemoved));
+        assertTrue("Wrong result", ctrl.removeEventListener(ReloadingEvent.ANY, lRemoved));
         final Object testData = "Some test data";
         assertTrue("Wrong result", ctrl.checkForReloading(testData));
         assertTrue("Not in reloading state", ctrl.isInReloadingState());
@@ -130,46 +130,43 @@ public class TestReloadingController
     }
 
     /**
-     * Tests a reloading check with a negative result.
+     * Tries to create an instance without a detector.
      */
-    @Test
-    public void testCheckForReloadingFalse()
-    {
-        final EventListener<ReloadingEvent> l = createListenerMock();
-        EasyMock.expect(detector.isReloadingRequired())
-                .andReturn(Boolean.FALSE);
-        EasyMock.replay(detector, l);
-        final ReloadingController ctrl = createController();
-        ctrl.addEventListener(ReloadingEvent.ANY, l);
-        assertFalse("Wrong result", ctrl.checkForReloading(null));
-        assertFalse("In reloading state", ctrl.isInReloadingState());
-        EasyMock.verify(detector, l);
+    @Test(expected = IllegalArgumentException.class)
+    public void testInitNoDetector() {
+        new ReloadingController(null);
     }
 
     /**
-     * Tests that no further checks are performed when already in reloading
-     * state.
+     * Tests the event type of the reloading event.
      */
     @Test
-    public void testCheckForReloadingInReloadingState()
-    {
-        final EventListener<ReloadingEvent> l = createListenerMock();
-        EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.TRUE);
-        expectEvent(l, new MutableObject<ReloadingEvent>());
-        EasyMock.replay(detector, l);
-        final ReloadingController ctrl = createController();
-        ctrl.addEventListener(ReloadingEvent.ANY, l);
-        assertTrue("Wrong result (1)", ctrl.checkForReloading(1));
-        assertTrue("Wrong result (2)", ctrl.checkForReloading(2));
-        EasyMock.verify(detector, l);
+    public void testReloadingEventType() {
+        assertEquals("Wrong super event type", Event.ANY, ReloadingEvent.ANY.getSuperType());
+    }
+
+    /**
+     * Tests that a newly created instance is not in reloading state.
+     */
+    @Test
+    public void testReloadingStateAfterInit() {
+        assertFalse("In reloading state", createController().isInReloadingState());
+    }
+
+    /**
+     * Tests that resetReloadingState() has no effect if the controller is not in reloading state.
+     */
+    @Test
+    public void testResetReloadingNotInReloadingState() {
+        EasyMock.replay(detector);
+        createController().resetReloadingState();
     }
 
     /**
      * Tests that the reloading state can be reset.
      */
     @Test
-    public void testResetReloadingState()
-    {
+    public void testResetReloadingState() {
         EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.TRUE);
         detector.reloadingPerformed();
         EasyMock.replay(detector);
@@ -179,25 +176,4 @@ public class TestReloadingController
         assertFalse("In reloading state", ctrl.isInReloadingState());
         EasyMock.verify(detector);
     }
-
-    /**
-     * Tests that resetReloadingState() has no effect if the controller is not
-     * in reloading state.
-     */
-    @Test
-    public void testResetReloadingNotInReloadingState()
-    {
-        EasyMock.replay(detector);
-        createController().resetReloadingState();
-    }
-
-    /**
-     * Tests the event type of the reloading event.
-     */
-    @Test
-    public void testReloadingEventType()
-    {
-        assertEquals("Wrong super event type", Event.ANY,
-                ReloadingEvent.ANY.getSuperType());
-    }
 }
