@@ -30,14 +30,11 @@ import org.junit.Before;
 import org.junit.Test;
 
 /**
- * A base class for testing combiner implementations. This base class provides
- * some functionality for loading the test configurations, which are to be
- * combined. Concrete sub classes only need to create the correct combiner
- * object.
+ * A base class for testing combiner implementations. This base class provides some functionality for loading the test
+ * configurations, which are to be combined. Concrete sub classes only need to create the correct combiner object.
  *
  */
-public abstract class AbstractCombinerTest
-{
+public abstract class AbstractCombinerTest {
     /** Constant for the first test configuration. */
     private static final File CONF1 = ConfigurationAssert.getTestFile("testcombine1.xml");
 
@@ -47,37 +44,18 @@ public abstract class AbstractCombinerTest
     /** The combiner to be tested. */
     protected NodeCombiner combiner;
 
-    @Before
-    public void setUp() throws Exception
-    {
-        combiner = createCombiner();
-    }
-
-    /**
-     * Creates the combiner to be tested. This method is called by
-     * {@code setUp()}. It must be implemented in concrete sub classes.
-     *
-     * @return the combiner to be tested
-     */
-    protected abstract NodeCombiner createCombiner();
-
     /**
      * Constructs a union configuration based on the source configurations.
      *
      * @return the union configuration
      * @throws ConfigurationException if an error occurs
      */
-    protected BaseHierarchicalConfiguration createCombinedConfiguration()
-            throws ConfigurationException
-    {
+    protected BaseHierarchicalConfiguration createCombinedConfiguration() throws ConfigurationException {
         final XMLConfiguration conf1 = new XMLConfiguration();
         new FileHandler(conf1).load(CONF1);
         final XMLConfiguration conf2 = new XMLConfiguration();
         new FileHandler(conf2).load(CONF2);
-        final ImmutableNode cn =
-                combiner.combine(conf1.getNodeModel().getNodeHandler()
-                        .getRootNode(), conf2.getNodeModel().getNodeHandler()
-                        .getRootNode());
+        final ImmutableNode cn = combiner.combine(conf1.getNodeModel().getNodeHandler().getRootNode(), conf2.getNodeModel().getNodeHandler().getRootNode());
 
         final BaseHierarchicalConfiguration result = new BaseHierarchicalConfiguration();
         result.getNodeModel().setRootNode(cn);
@@ -85,14 +63,25 @@ public abstract class AbstractCombinerTest
         return result;
     }
 
+    /**
+     * Creates the combiner to be tested. This method is called by {@code setUp()}. It must be implemented in concrete sub
+     * classes.
+     *
+     * @return the combiner to be tested
+     */
+    protected abstract NodeCombiner createCombiner();
+
+    @Before
+    public void setUp() throws Exception {
+        combiner = createCombiner();
+    }
+
     /**
      * Tests a newly created combiner.
      */
     @Test
-    public void testInit()
-    {
+    public void testInit() {
         assertTrue("Combiner has list nodes", combiner.getListNodes().isEmpty());
-        assertFalse("Node is list node", combiner
-                .isListNode(NodeStructureHelper.createNode("test", null)));
+        assertFalse("Node is list node", combiner.isListNode(NodeStructureHelper.createNode("test", null)));
     }
 }
