@@ -30,8 +30,7 @@ import org.junit.Test;
  * Test class for {@code QueryResult}.
  *
  */
-public class TestQueryResult
-{
+public class TestQueryResult {
     /** Constant for an attribute name. */
     private static final String ATTR = "testAttribute";
 
@@ -45,92 +44,20 @@ public class TestQueryResult
     private static ImmutableNode attributeNode;
 
     @BeforeClass
-    public static void setUpBeforeClass()
-    {
-        resultNode =
-                new ImmutableNode.Builder().name("resultNode").value(42)
-                        .create();
-        attributeNode =
-                new ImmutableNode.Builder().name("attributeNode")
-                        .addAttribute(ATTR, VALUE).create();
-    }
-
-    /**
-     * Tests isAttributeResult() if the expected result is true.
-     */
-    @Test
-    public void testIsAttributeResultTrue()
-    {
-        final QueryResult<ImmutableNode> result =
-                QueryResult.createAttributeResult(attributeNode, ATTR);
-        assertTrue("Not an attribute result", result.isAttributeResult());
-    }
-
-    /**
-     * Tests is attributeResult() if the expected result is false.
-     */
-    @Test
-    public void testIsAttributeResultFalse()
-    {
-        final QueryResult<ImmutableNode> result =
-                QueryResult.createNodeResult(resultNode);
-        assertFalse("An attribute result", result.isAttributeResult());
-    }
-
-    /**
-     * Tests whether the attribute's value can be queried.
-     */
-    @Test
-    public void testGetAttributeValue()
-    {
-        final QueryResult<ImmutableNode> result =
-                QueryResult.createAttributeResult(attributeNode, ATTR);
-        assertEquals("Wrong value", VALUE,
-                result.getAttributeValue(new InMemoryNodeModel()
-                        .getNodeHandler()));
-    }
-
-    /**
-     * Tries to query an attribute value for a non-attribute result.
-     */
-    @Test(expected = IllegalStateException.class)
-    public void testGetAttributeValueNoAttributeResult()
-    {
-        final QueryResult<ImmutableNode> result =
-                QueryResult.createNodeResult(resultNode);
-        result.getAttributeValue(new InMemoryNodeModel().getNodeHandler());
-    }
-
-    /**
-     * Tests equals() if the expected result is true.
-     */
-    @Test
-    public void testEqualsTrue()
-    {
-        QueryResult<ImmutableNode> r1 =
-                QueryResult.createNodeResult(resultNode);
-        checkEquals(r1, r1, true);
-        QueryResult<ImmutableNode> r2 =
-                QueryResult.createNodeResult(resultNode);
-        checkEquals(r1, r2, true);
-        r1 = QueryResult.createAttributeResult(attributeNode, ATTR);
-        r2 = QueryResult.createAttributeResult(attributeNode, ATTR);
-        checkEquals(r1, r2, true);
+    public static void setUpBeforeClass() {
+        resultNode = new ImmutableNode.Builder().name("resultNode").value(42).create();
+        attributeNode = new ImmutableNode.Builder().name("attributeNode").addAttribute(ATTR, VALUE).create();
     }
 
     /**
      * Tests equals() if the expected result is false.
      */
     @Test
-    public void testEqualsFalse()
-    {
-        final QueryResult<ImmutableNode> nodeRes =
-                QueryResult.createNodeResult(resultNode);
-        final QueryResult<ImmutableNode> attrRes =
-                QueryResult.createAttributeResult(attributeNode, ATTR);
+    public void testEqualsFalse() {
+        final QueryResult<ImmutableNode> nodeRes = QueryResult.createNodeResult(resultNode);
+        final QueryResult<ImmutableNode> attrRes = QueryResult.createAttributeResult(attributeNode, ATTR);
         checkEquals(nodeRes, attrRes, false);
-        QueryResult<ImmutableNode> res =
-                QueryResult.createNodeResult(attributeNode);
+        QueryResult<ImmutableNode> res = QueryResult.createNodeResult(attributeNode);
         checkEquals(nodeRes, res, false);
         res = QueryResult.createAttributeResult(attributeNode, "otherAttr");
         checkEquals(attrRes, res, false);
@@ -142,36 +69,79 @@ public class TestQueryResult
      * Tests equals() with other objects.
      */
     @Test
-    public void testEqualsOtherObjects()
-    {
-        final QueryResult<ImmutableNode> result =
-                QueryResult.createNodeResult(resultNode);
+    public void testEqualsOtherObjects() {
+        final QueryResult<ImmutableNode> result = QueryResult.createNodeResult(resultNode);
         checkEquals(result, null, false);
         checkEquals(result, this, false);
     }
 
     /**
-     * Tests the string representation of a node result.
+     * Tests equals() if the expected result is true.
      */
     @Test
-    public void testToStringNodeResult()
-    {
-        final QueryResult<ImmutableNode> result =
-                QueryResult.createNodeResult(resultNode);
-        assertThat(result.toString(),
-                containsString("resultNode=" + resultNode));
+    public void testEqualsTrue() {
+        QueryResult<ImmutableNode> r1 = QueryResult.createNodeResult(resultNode);
+        checkEquals(r1, r1, true);
+        QueryResult<ImmutableNode> r2 = QueryResult.createNodeResult(resultNode);
+        checkEquals(r1, r2, true);
+        r1 = QueryResult.createAttributeResult(attributeNode, ATTR);
+        r2 = QueryResult.createAttributeResult(attributeNode, ATTR);
+        checkEquals(r1, r2, true);
+    }
+
+    /**
+     * Tests whether the attribute's value can be queried.
+     */
+    @Test
+    public void testGetAttributeValue() {
+        final QueryResult<ImmutableNode> result = QueryResult.createAttributeResult(attributeNode, ATTR);
+        assertEquals("Wrong value", VALUE, result.getAttributeValue(new InMemoryNodeModel().getNodeHandler()));
+    }
+
+    /**
+     * Tries to query an attribute value for a non-attribute result.
+     */
+    @Test(expected = IllegalStateException.class)
+    public void testGetAttributeValueNoAttributeResult() {
+        final QueryResult<ImmutableNode> result = QueryResult.createNodeResult(resultNode);
+        result.getAttributeValue(new InMemoryNodeModel().getNodeHandler());
+    }
+
+    /**
+     * Tests is attributeResult() if the expected result is false.
+     */
+    @Test
+    public void testIsAttributeResultFalse() {
+        final QueryResult<ImmutableNode> result = QueryResult.createNodeResult(resultNode);
+        assertFalse("An attribute result", result.isAttributeResult());
+    }
+
+    /**
+     * Tests isAttributeResult() if the expected result is true.
+     */
+    @Test
+    public void testIsAttributeResultTrue() {
+        final QueryResult<ImmutableNode> result = QueryResult.createAttributeResult(attributeNode, ATTR);
+        assertTrue("Not an attribute result", result.isAttributeResult());
     }
 
     /**
      * Tests the string representation of an attribute result.
      */
     @Test
-    public void testToStringAttributeResult()
-    {
-        final QueryResult<ImmutableNode> result =
-                QueryResult.createAttributeResult(attributeNode, ATTR);
+    public void testToStringAttributeResult() {
+        final QueryResult<ImmutableNode> result = QueryResult.createAttributeResult(attributeNode, ATTR);
         final String s = result.toString();
         assertThat(s, containsString("attribute=" + ATTR));
         assertThat(s, containsString("parentNode=" + attributeNode));
     }
+
+    /**
+     * Tests the string representation of a node result.
+     */
+    @Test
+    public void testToStringNodeResult() {
+        final QueryResult<ImmutableNode> result = QueryResult.createNodeResult(resultNode);
+        assertThat(result.toString(), containsString("resultNode=" + resultNode));
+    }
 }
