@@ -30,14 +30,12 @@ import org.junit.Test;
  * Test class for {@code XPathContextFactory}.
  *
  */
-public class TestXPathContextFactory
-{
+public class TestXPathContextFactory {
     /** The factory to be tested. */
     private XPathContextFactory factory;
 
     @Before
-    public void setUp() throws Exception
-    {
+    public void setUp() throws Exception {
         factory = new XPathContextFactory();
     }
 
@@ -45,18 +43,13 @@ public class TestXPathContextFactory
      * Tests whether a correct context is created.
      */
     @Test
-    public void testCreateContext()
-    {
-        final ImmutableNode node =
-                new ImmutableNode.Builder().name("testRoot").create();
-        final NodeHandler<ImmutableNode> handler =
-                new InMemoryNodeModel(node).getNodeHandler();
+    public void testCreateContext() {
+        final ImmutableNode node = new ImmutableNode.Builder().name("testRoot").create();
+        final NodeHandler<ImmutableNode> handler = new InMemoryNodeModel(node).getNodeHandler();
         final JXPathContext context = factory.createContext(node, handler);
 
         assertTrue("No lenient mode", context.isLenient());
-        final ConfigurationNodePointerFactory.NodeWrapper<?> wrapper =
-                (ConfigurationNodePointerFactory.NodeWrapper<?>) context
-                        .getContextBean();
+        final ConfigurationNodePointerFactory.NodeWrapper<?> wrapper = (ConfigurationNodePointerFactory.NodeWrapper<?>) context.getContextBean();
         assertSame("Wrong node", node, wrapper.getNode());
         assertSame("Wrong handler", handler, wrapper.getNodeHandler());
     }
