@@ -32,11 +32,37 @@ import org.junit.Test;
  * Test case for the {@link ServletFilterConfiguration} class.
  *
  */
-public class TestServletFilterConfiguration extends TestAbstractConfiguration
-{
+public class TestServletFilterConfiguration extends TestAbstractConfiguration {
+    private static class MockFilterConfig implements FilterConfig {
+        private final Properties parameters = new Properties();
+
+        @Override
+        public String getFilterName() {
+            return null;
+        }
+
+        @Override
+        public String getInitParameter(final String key) {
+            return parameters.getProperty(key);
+        }
+
+        @Override
+        public Enumeration<?> getInitParameterNames() {
+            return parameters.keys();
+        }
+
+        @Override
+        public ServletContext getServletContext() {
+            return null;
+        }
+
+        public void setInitParameter(final String key, final String value) {
+            parameters.setProperty(key, value);
+        }
+    }
+
     @Override
-    protected AbstractConfiguration getConfiguration()
-    {
+    protected AbstractConfiguration getConfiguration() {
         final MockFilterConfig config = new MockFilterConfig();
         config.setInitParameter("key1", "value1");
         config.setInitParameter("key2", "value2");
@@ -49,56 +75,19 @@ public class TestServletFilterConfiguration extends TestAbstractConfiguration
     }
 
     @Override
-    protected AbstractConfiguration getEmptyConfiguration()
-    {
+    protected AbstractConfiguration getEmptyConfiguration() {
         return new ServletFilterConfiguration(new MockFilterConfig());
     }
 
-    private class MockFilterConfig implements FilterConfig
-    {
-        private final Properties parameters = new Properties();
-
-        @Override
-        public String getFilterName()
-        {
-            return null;
-        }
-
-        @Override
-        public ServletContext getServletContext()
-        {
-            return null;
-        }
-
-        @Override
-        public String getInitParameter(final String key)
-        {
-            return parameters.getProperty(key);
-        }
-
-        @Override
-        public Enumeration<?> getInitParameterNames()
-        {
-            return parameters.keys();
-        }
-
-        public void setInitParameter(final String key, final String value)
-        {
-            parameters.setProperty(key, value);
-        }
-    }
-
     @Override
     @Test(expected = UnsupportedOperationException.class)
-    public void testAddPropertyDirect()
-    {
+    public void testAddPropertyDirect() {
         super.testAddPropertyDirect();
     }
 
     @Override
     @Test(expected = UnsupportedOperationException.class)
-    public void testClearProperty()
-    {
+    public void testClearProperty() {
         super.testClearProperty();
     }
 }
